// FILE: ./assets/js/utilities/ErrorFrontend.js
function ErrorFrontend(ZHPromise){
    
    var CAMPO_VAZIO = 'CAMPO_VAZIO';
    
    /**
     * Retorna um objeto de error para uma promise rejeitada
     */
    this.error = function(code){
        return { 
            data : { error : code } 
        };
    };
    
    /** 
     * error = object
     * params = array()
     * retorna um objeto de erro com parâmetros para uma promise rejeitada
     * */
    this.errorFieldEmpty = function(error, params){
        error.data.messageParams = params;
        return error;
    };
    
    /** 
     * error = object
     * retorna uma promise rejeitada com o objeto error
     * */
    this.rejectedPromise = function(error){
        var deferred = ZHPromise.defer();
        deferred.reject(error);
        return deferred.promise;

    };
    
    /** 
     * error = object
     * retorna uma promise rejeitada com o objeto error
     * */
    this.regectedPromiseFieldEmpty = function(fieldId){
        return this.rejectedPromise(this.errorFieldEmpty(this.error(CAMPO_VAZIO), [fieldId]));
    };
    
}

Configuration(function(ContextRegister) {
    ContextRegister.register('ErrorFrontend', ErrorFrontend);
});

// FILE: ./assets/js/utilities/Messages_Contabil.js
var Messages_Contabil = function Messages_Contabil(){
     /* + ----------------------------------- +
     * | Error messages                      |
     * + ----------------------------------- + */
    this.CATCH_EXCEPTION_ERROR = function(error) {
        return 'Ocorreu um erro inesperado, contate o administrador informando o trecho abaixo: <br><br>' + error + '<br><br>';
    };
    
    this.SALDO_JA_IMPLANTADO = "Saldo já implantado para a Conta Contábil informada.";
    
    /* Sucesso */
    this.CADASTRADO_COM_SUCESSO = "Cadastro realizado com sucesso.";
    
    /*Um ou mais parâmetros (fields) obrigatórios não foram preenchidos*/
    this.FALTA_PARAMETROS = "É necessário preencher todos os parâmetros obrigatórios.";
    
};

Configuration(function(ContextRegister) {
    ContextRegister.register('Messages_Contabil', Messages_Contabil);
});

// FILE: ./assets/js/utilities/TreeManipulator.js
function TreeManipulator(ScreenService, templateManager, ZHPromise){
    
    // Variável de controle para o armazenamento da widget atualmente aberta.
    var windowCurrentlyOpen = false;
    
    /*
     * Função para sair de uma "tela" e retornar à widget principal.
     */
    this.backWindow = function(widget, treeWidget) {
        // Prepara uma promise para esta função.
        var deferred = ZHPromise.defer();

        // Desativa a widget atualmente aberta.
        widget.deactivate();

        // Limpa a variável que indica qual a widget atualmente aberta.
        windowCurrentlyOpen = false;

        // Fecha o swipe.
        ScreenService.goBack().then(function() {
            // Ativa a árvore.
            treeWidget.activate();
            // Finaliza a promise retornada.
            deferred.resolve();
        });
        // Retorna a promise preparada.
        return deferred.promise;
    };
    
    /*
     * Função que verifica o clique em uma das opções disponíveis na árvore.
     * Determina se um swipe será aberto ou não, dependendo da opção
     * selecionada.
     */
    this.selectWindow = function(widget) {
        // Guarda o nome da widget relacionada à opção clicada, se houver.
        var windowToOpen = widget.currentRow.WINDOW;
        // Guarda a propriedade "ENABLED" da opção selecionada.
        var windowEnabled = widget.currentRow.ENABLED;

        // Verifica se há uma widget associada (não for um submenu) e se esta
        // está habilitada (a tela estiver disponível para ser utilizada).
        if (windowToOpen && windowEnabled) {
            // Verifica se já há uma widget aberta e se esta é diferente da
            // selecionada.
            if (windowCurrentlyOpen && windowCurrentlyOpen != windowToOpen) {
                // Fecha o swipe com a widget já aberta.
                this.backWindow(templateManager.container.getWidget(windowCurrentlyOpen)).then(function() {
                    // Abre o swipe na widget selecionada.
                    ScreenService.openSwipe(templateManager.container.getWidget(windowToOpen));
                });
            }
            // Senão, abre o swipe na opção selecionada.
            else {
                // Abre o swipe na widget selecionada.
                ScreenService.openSwipe(templateManager.container.getWidget(windowToOpen));
            }
            // Altera a variável de controle da widget atualmente aberta.
            windowCurrentlyOpen = windowToOpen;
        }
        // Senão, verifica se não há a propriedade "ENABLED" na opção
        // selecionada, indicando que é um submenu.
        else if (windowEnabled !== false) {
            // Altera o estado aberto/fechado do submenu.
            widget.currentRow._opened = !widget.currentRow._opened;
        }
    };
}
Configuration(function(ContextRegister) {
    ContextRegister.register("TreeManipulator", TreeManipulator);
});

// FILE: ./assets/js/utilities/VersionDataLibs.js
function VersionDataLibs(templateManager, eventAggregator, requestDataSourceEngine, ZHPromise){
    var self = this;
    
    self.showErrorMessage = function(error) {
        var message = error;
        if(typeof error === 'object') {
            if(error.message) {
                message = error.message;
            } else if(error.data && error.data.error){
                message = error.data.error;
            }
        }

        if(!message) {
            message = 'Ocorreu um erro inesperado. Entre em contato com o administrador do sistema.';
        } else if(message.indexOf('Exception: Exception: ') != -1) {
            message = message.replace('Exception: Exception: ', '');
        }

        ScreenService.showMessage(message, 'error');
    };

    self.buildVersion = function () {
        var deferred = ZHPromise.defer();
        if(!templateManager.versionData) {
            templateManager.versionData = true;
            var filter = [ {
                name: 'CURRENT_MODULE',
                operator: '=',
                value: 'ctb'
            } ];
            return requestDataSourceEngine.getDataSource('ctb#/lib_getVersionInfo', filter)
            .then(function (response) {
                templateManager.versionData = response.dataset.versionInfo;
                templateManager.versionData.dependencies.changeCurrentVersion = function(newVersion) {
                    templateManager.versionData.dependencies.current = templateManager.versionData.dependencies[newVersion];
                };
            })
            .catch(function(){
                deferred.reject(self.showErrorMessage);
            });
        }else{
            deferred.resolve();
        }
        return deferred.promise;
    };
    
    /*Esta função foi temporariamente criada para corrigir erros na geração do
    reporte em ambiente de produção para corrigir erros de incompatibilidade 
    entre o framework e a libs. Devendo posteriormente ser retirada.*/
    eventAggregator.subscribe("AboutOnClick", this.buildVersion);

    eventAggregator.subscribe("beforeProjectStartup", function() {
        templateManager.updateVersionData = self.buildVersion;
    });
}
Configuration(function(ContextRegister) {
    ContextRegister.register("VersionDataLibs", VersionDataLibs);
});

// FILE: ./assets/js/repositories/Ctb10000_LancamentosContabeis_Repository.js
var Ctb10000_LancamentosContabeis_Repository = function(restEngine) {

    /*
     * Função que valida a data do lançamento inserida pelo usuário.
     */
    this.checkValidDataLancamento = function(row) {
        return restEngine.post("ctb#/checkValidDataLancamento", {
            "requestType": "Row",
            "row": row
        });
    };

    /*
     * Função chamada para excluir um lançamento.
     */
    this.excluirLancamento = function(row) {
        return restEngine.post("ctb#/deleteLanccont", {
            "requestType": "Row",
            "row": row
        });
    };

    /*
     * Função que retorna os dados de um lançamento.
     */
    this.getLancamento = function(row) {
        return restEngine.post("ctb#/getLanccont", {
            "requestType": "Row",
            "row": row
        });
    };

    /*
     * Função que retorna os dados de um lote.
     */
    this.getLote = function(filter) {
        return restEngine.post("ctb#/crud/lanclote", {
            "requestType": "FilterData",
            "filter": filter
        });
    };

    /*
     * Função para chamar a requisição de salvar o lançamento contábil.
     */
    this.saveLancamento = function(row) {
        return restEngine.post("ctb#/saveLanccont", {
            "requestType": "Row",
            "row": row
        });
    };

};


Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb10000_LancamentosContabeis_Repository', Ctb10000_LancamentosContabeis_Repository);
});


// FILE: ./assets/js/repositories/Ctb14000_EncerramentoExercicio_Repository.js
var Ctb14000_EncerramentoExercicio_Repository = function(restEngine){
    this.verificaCdLote = function(Row){
          return restEngine.post('ctb#/rotaVerificaCdLote', {
               "requestType": "Row",
               "row": Row
          }); 
    };
    
    this.geraLote = function(Row){
          return restEngine.post('ctb#/rotaGeraLote', {
               "requestType": "Row",
               "row": Row
          }); 
    };
    
    this.getMask = function(){
         return restEngine.post('ctb#/getMask', {
              "requestType": "Row",
              "row": {}
         });
    };
};


Configuration(function(ContextRegister) {
     ContextRegister.register('Ctb14000_EncerramentoExercicio_Repository', Ctb14000_EncerramentoExercicio_Repository);
});

// FILE: ./assets/js/repositories/Ctb32700_DREAnual_Repository.js
var Ctb32700_DREAnual_Repository = function(restEngine) {
    
    this.geraDREAnual = function(currentRow) {
        return restEngine.post("ctb#/geraDREAnual", {
            "requestType": "Row",
            "row": currentRow
        });
    };

};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb32700_DREAnual_Repository', Ctb32700_DREAnual_Repository);
});


// FILE: ./assets/js/repositories/Ctb44400_DreGerencial_Repository.js
var Ctb44400_DreGerencial_Repository = function(General) {

    //chama a procedure que ira gerar os relatorios e retorna o link do arquivo
    this.geraRelatorio= function (params) {
        return General.callRestEngine("ctb#/gerarRelatoriosDemoCont", "Row", params);
    };
    
};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb44400_DreGerencial_Repository', Ctb44400_DreGerencial_Repository);
});


// FILE: ./assets/js/repositories/Ger06100_Conta_Contabil_Repository.js
var Ger06100_Conta_Contabil_Repository = function(restEngine){

    this.verificaExclusao = function(Row){
          return restEngine.post('ctb#/verificaExclusao', {
               "requestType": "Row",
               "row": Row
          }); 
    };
    
    this.salvarContaContabil = function(row){
          return restEngine.post('ctb#/salvarContaContabil', {
               "requestType": "Row",
               "row": row
          }); 
    };
    
    this.salvarSubContas = function(row){
          return restEngine.post('ctb#/salvarSubContas', {
               "requestType": "Row",
               "row": row
          }); 
    };
    
    this.deletarSubContas = function(row){
          return restEngine.post('ctb#/deletarSubContas', {
               "requestType": "Row",
               "row": row
          }); 
    };
    
    this.verificaContaNivelAnterior = function(filter){
          return restEngine.post('ctb#/verificaContaNivelAnterior', {
               "requestType": "FilterData",
               "filter": filter
          }); 
    };
     
     this.salvarCadastramentoAutomatico = function(row){
          return restEngine.post('ctb#/salvarCadastramentoAutomatico', {
               "requestType": "Row",
               "row": row
          }); 
    };
    
    this.retornaMaiorConta = function(row){
          return restEngine.post('ctb#/retornaMaiorConta', {
               "requestType": "Row",
               "row": row
          }); 
    };
    
};


Configuration(function(ContextRegister) {
     ContextRegister.register('Ger06100_Conta_Contabil_Repository', Ger06100_Conta_Contabil_Repository);
});

// FILE: ./assets/js/repositories/Ger06200_HistoricoPadrao_Repositories.js
var Ger06200_HistoricoPadrao_Repositories = function(restEngine) {

    this.vdHistExiste = function(cdhistpadr){
        var filter = [
            {
                "name": "CDHISTPADR",
                "operator": "=",
                "value": cdhistpadr
            }
        ];
        return restEngine.post('ctb#/crud/histpadr',{
            "requestType":"FilterData",
            "filter": filter
        });
    };

    this.saveHistPadr = function(row){
        return restEngine.post('ctb#/crud/histpadr/save',{
            "requestType":"Row",
            "row": row
        });
    };

};

Configuration(function(ContextRegister){
    ContextRegister.register('Ger06200_HistoricoPadrao_Repositories', Ger06200_HistoricoPadrao_Repositories);
});

// FILE: ./assets/js/repositories/Ger08000_Contador_Repository.js
var Ger08000_Contador_Repository = function(restEngine){
    this.verificaCdContador = function(Row){
          return restEngine.post('ctb#/verificaCdContador', {
               "requestType": "Row",
               "row": Row
          });
    };

    this.save = function(Row){
         return restEngine.post('ctb#/crud/contador/save', {
            "requestType": "Row",
            "row": Row
        });
    };
};


Configuration(function(ContextRegister) {
     ContextRegister.register('Ger08000_Contador_Repository', Ger08000_Contador_Repository);
});

// FILE: ./assets/js/repositories/Ger09400_ParametroContabil_Repository.js
var Ger09400_ParametroContabil_Repository = function(restEngine){
    
    this.cadastrarAutomaticamente = function(row){
        return restEngine.post('ctb#/parametroContabil/cadastroAutomatico',{
            "requestType": "Row",
            "row": row
        });
    };    
    
};

Configuration(function(ContextRegister){
    ContextRegister.register('Ger09400_ParametroContabil_Repository', Ger09400_ParametroContabil_Repository);
});

// FILE: ./assets/js/repositories/Ger17700_Rendimentos_Socios_Repository.js
var Ger17700_Rendimentos_Socios_Repository = function(restEngine){

};


Configuration(function(ContextRegister) {
     ContextRegister.register('Ger17700_Rendimentos_Socios_Repository', Ger17700_Rendimentos_Socios_Repository);
});

// FILE: ./assets/modules/saldos/assets/js/repositories/Ctb17000_Implantacao_Saldo_Repository.js
var Ctb17000_Implantacao_Saldo_Repository = function(restEngine){
    this.getMask = function(){
         return restEngine.post('ctb#/crud/paramgeral', {
              "requestType": "FilterData",
              "row": {}
         });
    };

    this.getSequencial = function(){
         return restEngine.post('ctb#/sequencialImplantSaldo', {
              "requestType": "Row",
              "row": {}
         });
    };

    this.salvar = function(row){
         return restEngine.post('ctb#/implantsaldo_empresa/save', {
              "requestType": "DataSet",
              "dataset": [row]
         });
    };
};


Configuration(function(ContextRegister) {
     ContextRegister.register('Ctb17000_Implantacao_Saldo_Repository', Ctb17000_Implantacao_Saldo_Repository);
});

// FILE: ./assets/modules/saldos/assets/js/repositories/Ctb68000_RecalculoSaldosGerenciais_Repository.js
function Ctb68000_RecalculoSaldosGerenciais_Repository(restEngine){
    
    this.recalcularSaldo = function(row){
        return restEngine.post("ctb_saldos#/recalculo_saldos_gerenciais/recalcularSaldo", {
            "requestType": "Row",
            "row": row
        });
    };
    
    this.validatePeriodoContabil = function(row) {
        return restEngine.post("ctb_saldos#/recalculo_saldos_gerenciais/validatePeriodoContabil", {
            "requestType": "Row",
            "row": row
        });
    };
    
}
Configuration(function(ContextRegister) {
    ContextRegister.register("Ctb68000_RecalculoSaldosGerenciais_Repository", Ctb68000_RecalculoSaldosGerenciais_Repository);
});

// FILE: ./assets/modules/saldos/assets/js/repositories/Ctb72800_RecalculoSaldosComerciais_Repository.js
function Ctb72800_RecalculoSaldosComerciais_Repository(restEngine){
    
    this.recalcularSaldo = function(row){
        return restEngine.post("ctb_saldos#/recalculo_saldos_comerciais/recalcularSaldo", {
            "requestType": "Row",
            "row": row
        });
    };
    
    this.validatePeriodoContabil = function(row) {
        return restEngine.post("ctb_saldos#/recalculo_saldos_comerciais/validatePeriodoContabil", {
            "requestType": "Row",
            "row": row
        });
    };
    
}
Configuration(function(ContextRegister) {
    ContextRegister.register("Ctb72800_RecalculoSaldosComerciais_Repository", Ctb72800_RecalculoSaldosComerciais_Repository);
});

// FILE: ./assets/js/services/Ctb10000_LancamentosContabeis_Service.js
var Ctb10000_LancamentosContabeis_Service = function(Ctb10000_LancamentosContabeis_Repository) {

    /*
     * Função que valida a data do lançamento inserida pelo usuário.
     */
    this.checkValidDataLancamento = function(currentRow) {
        var row = {
            "CDEMPRESA": currentRow.CDEMPRESA,
            "DTLANCCONT": currentRow.DTLANCCONT
        };
        return Ctb10000_LancamentosContabeis_Repository.checkValidDataLancamento(row);
    };

    /*
     * Função chamada para excluir um lançamento.
     */
    this.excluirLancamento = function(row) {
        return Ctb10000_LancamentosContabeis_Repository.excluirLancamento(row);
    };

    /*
     * Função que retorna os dados de um lançamento.
     */
    this.getLancamento = function(cdempresa, nrlanccont) {
        var row = {
            "CDEMPRESA": cdempresa,
            "NRLANCCONT": nrlanccont
        };
        return Ctb10000_LancamentosContabeis_Repository.getLancamento(row);
    };

    /*
     * Função que retorna os dados de um lote.
     * Chamada pelo controller ao exibir a mensagem de erro, informando que não
     * é possível alterar lançamentos de lote.
     */
    this.getLote = function(row) {
        var filter = [
            {
                "name": "CDEMPRESA",
                "operator": "=",
                "value": row.CDEMPRESA
            },
            {
                "name": "NRLANCDEFI",
                "operator": "=",
                "value": row.NRLANCCONT
            }
        ];
        return Ctb10000_LancamentosContabeis_Repository.getLote(filter);
    };

    /*
     * Função para chamar a requisição de salvar o lançamento contábil.
     */
    this.saveLancamento = function(partidas, cabecalho) {
        var row = {
            "partidas": partidas,
            "cabecalho": cabecalho
        };
        return Ctb10000_LancamentosContabeis_Repository.saveLancamento(row);
    };

};


Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb10000_LancamentosContabeis_Service', Ctb10000_LancamentosContabeis_Service);
});


// FILE: ./assets/js/services/Ctb14000_EncerramentoExercicio_Service.js
var Ctb14000_EncerramentoExercicio_Service = function(Ctb14000_EncerramentoExercicio_Repository, ZHPromise){
    this.verificaCdLote = function(row){
         return Ctb14000_EncerramentoExercicio_Repository.verificaCdLote(row);
    };
    
    this.geraLote = function (row){
         return Ctb14000_EncerramentoExercicio_Repository.geraLote(row);
    };
    
    this.getMask = function(){
        return Ctb14000_EncerramentoExercicio_Repository.getMask();
    };
};


Configuration(function(ContextRegister) {
     ContextRegister.register('Ctb14000_EncerramentoExercicio_Service', Ctb14000_EncerramentoExercicio_Service);
});

// FILE: ./assets/js/services/Ctb32700_DREAnual_Service.js
var Ctb32700_DREAnual_Service = function(Ctb32700_DREAnual_Repository) {

    this.geraDREAnual = function(currentRow) {
        return Ctb32700_DREAnual_Repository.geraDREAnual(currentRow);
    };
};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb32700_DREAnual_Service', Ctb32700_DREAnual_Service);
});


// FILE: ./assets/js/services/Ctb44400_DreGerencial_Service.js
var Ctb44400_DreGerencial_Service = function(Ctb44400_DreGerencial_Repository) {

    //Prepara parametros para chamar a procedure que irá gerar o relatorio
    this.geraRelatorio= function (params) {
         
        if (Array.isArray(params.CDEMPRESA)){
            if(params.CDEMPRESA.length == 1){
                params.EMPRESAUNICA = 'S';
                params.CDEMPRESA = params.CDEMPRESA[0];
                params.NMEMPRESA = params.NMEMPRESA[0];
                params.NRINSJUREMPR = params.NRINSJUREMPR[0];
                
            }else{
                params.EMPRESAUNICA = 'N';
                params.CDEMPRESA = params.CDEMPRESA.length > 0 ? this.concatenaStringEmpresa( params.CDEMPRESA) : "T" ;
                params.NMEMPRESA = '';
                params.NRINSJUREMPR = '';
            }
        }else{
             params.EMPRESAUNICA = 'N';
             params.CDEMPRESA =  'T';
             params.NMEMPRESA = '';
             params.NRINSJUREMPR = '';
        }

        
        if(params.IDSALDO != 'A'){
           params.DATAA = null;
           params.DATAB = null;
           params.DATAASS = '31/' + params.DATABINTERB.substr(3);
        }else{
          params.DATAAINTERA = null; 
          params.DATAAINTERB = null;
          params.DATABINTERA = null; 
          params.DATABINTERB = null;
          params.DATAASS = '31/' + params.DATAB.substr(3);
        }
        
        return Ctb44400_DreGerencial_Repository.geraRelatorio(params);
        
    };
    
    //Gera uma String com as empresas separadas por '_'
    this.concatenaStringEmpresa = function (empresas){
        
        
        return empresas.reduce( function( concat , empresa){ 
            return concat + '_' + empresa; 
            
        } , '');
    };

};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb44400_DreGerencial_Service', Ctb44400_DreGerencial_Service);
});


// FILE: ./assets/js/services/Ger06100_Conta_Contabil_Service.js
var Ger06100_Conta_Contabil_Service = function(Ger06100_Conta_Contabil_Repository) {

	//verifica se a data atual for maior que data final da conta contabil (Conta Expirada). Retorna true caso esteja tudo certo.
	this.validaDataContaContabil = function (row, nomeData){
		var dataFinal = row[nomeData];
		var dataAtual = moment();
		if(dataFinal){
			var data  = moment(dataFinal,'DD/MM/YYYY');
			if(dataAtual.isAfter(data))
				return false;
			else
				return true;
		}else{
			return true;
		}	
	};
   
	this.verificaExclusao = function (row){
		return Ger06100_Conta_Contabil_Repository.verificaExclusao(row);
	};
	
	this.salvarContaContabil = function (row){
		return Ger06100_Conta_Contabil_Repository.salvarContaContabil(row);
	};
	
	this.salvarSubContas = function (row){
		return Ger06100_Conta_Contabil_Repository.salvarSubContas(row);
	};
	
	this.deletarSubContas = function (row){
		return Ger06100_Conta_Contabil_Repository.deletarSubContas(row);
	};
	
	this.salvarCadastramentoAutomatico = function (row){
		return Ger06100_Conta_Contabil_Repository.salvarCadastramentoAutomatico(row);
	};
	
	this.retornaMaiorConta = function (row){
		return Ger06100_Conta_Contabil_Repository.retornaMaiorConta(row);
	};
	
	this.verificaContaNivelAnterior = function (row){
		var fiter = [
			{
				"name":"CDCONTCTBL",
				"operator":"=",
				"value":row.CDCONTANTE
			}
		];
		return Ger06100_Conta_Contabil_Repository.verificaContaNivelAnterior(fiter);
	};
	
	/*
		A função ira validar de o campo foi preenchido corretamente de acodor do a mascara
		A variável mascara é um array contendo os niveis e o tamanho de caractres de cada nivel.
	*/
	this.validaPreenchimentonivel = function (cdcontctbl, mascara){
		// array que terá o tamanho referente a cada nível da conta.
		var arrayNivel = [];
		var tamanho = cdcontctbl.length;
		
		mascara.forEach(function(nivel) {
		    arrayNivel.push(nivel.caracteres);
		});
		if( arrayNivel.indexOf( String(tamanho) ) == -1 )
			return false;
		else
			return true;
		
	};
	
	//retorna o nivel da Conta Contábil
	this.retornaNivelConta = function (cdcontctbl, mascara){
		var cdnvcontctbl = '';
		var tamanho = cdcontctbl.length;
		mascara.forEach(function(nivel) {
			if(nivel.caracteres === String(tamanho))
				cdnvcontctbl =  nivel.nivel;
		});
		return cdnvcontctbl;
	};
	
	//retorna a conta pai  da Conta Contábil
	this.retornaContaPai = function (cdcontctbl,nivel, mascara){
		var cdcontante              = null;
		var caracteresNivelAnterior =''; 
		if(nivel>1){
			mascara.forEach(function(nivelAtual) {
				if( parseFloat( nivelAtual.nivel ) === parseFloat(nivel)-1 )
					caracteresNivelAnterior =  nivelAtual.caracteres;
			});
			cdcontante = cdcontctbl.substr(0, caracteresNivelAnterior);
			return cdcontante;
		}else
			return cdcontante;
	};
	
	this.verificaValores = function (row, mascara){
		if(row.IDCONTCCUS ==='R')
			row.CDCONTCTBLANALI ='';
		
		if(row.CDCONTCTBLANALI)
			row.CDCONTCTBLANALI =  row.CDCONTCTBLANALI.replace(/[^0-9]/g,'');
		
		// Utilizado para mostrar o valor 'Não tem' para o usuario caso ele seja null  
		if(row.IDTIPOCOME ===' ')
			row.IDTIPOCOME = null;
		
		
		if( parseFloat(row.CDNVCONTCTBL) === mascara.length)
			row.IDTIPOCONT = 'A';
		else
			row.IDTIPOCONT = 'S';
			
		row.CDCONTCTBL =  row.CDCONTCTBL.replace(/[^0-9]/g,'');
		
	};

	this.validaIntervaloContas = function (contaInicial, contaFinal){
		if( parseFloat ( contaInicial.replace(/[^0-9]/g,'') ) > parseFloat ( contaFinal.replace(/[^0-9]/g,'') ) )
			return false;
		else
			return true;
	};
	
};

Configuration(function(ContextRegister){
    ContextRegister.register('Ger06100_Conta_Contabil_Service', Ger06100_Conta_Contabil_Service);
});

// FILE: ./assets/js/services/Ger06200_HistoricoPadrao_Service.js
var Ger06200_HistoricoPadrao_Service = function(Ger06200_HistoricoPadrao_Repositories) {

    var self = this;
    
   this.vdHistExiste = function(cdhistpadr){
        return Ger06200_HistoricoPadrao_Repositories.vdHistExiste(cdhistpadr); 
    };
    
    this.saveHistPadr = function(row){
        return Ger06200_HistoricoPadrao_Repositories.saveHistPadr(row);

    };
};

Configuration(function(ContextRegister){
    ContextRegister.register('Ger06200_HistoricoPadrao_Service', Ger06200_HistoricoPadrao_Service);
});

// FILE: ./assets/js/services/Ger08000_Contador_Service.js
var Ger08000_Contador_Service = function(Endereco, Ger08000_Contador_Repository, ZHPromise){
     this.verificaCdContador = function(row){
          return Ger08000_Contador_Repository.verificaCdContador(row);
     };
    
     this.save = function(row){
         return Ger08000_Contador_Repository.save(row);
     };
     
          
     /* **************************************************
     * Função que retorna um request de validação de CEP
     * efetuado para a API dos Correios.
     *
     * @param String CEP
     *
     * @return Promise
     */
     this.validateCEP = function(CEP) {
        return Endereco.buscarCep(CEP);
     };

};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ger08000_Contador_Service', Ger08000_Contador_Service);
});

// FILE: ./assets/js/services/Ger09400_ParametroContabil_Service.js
var Ger09400_ParametroContabil_Service  = function(Ger09400_ParametroContabil_Repository){
    
    this.buildDataOfDataSource = function(banco){
        var aux = [];
        var aux2 = [];
        banco.forEach(function(row){
            var obj = new Object({});
            var obj2 = new Object({});
            obj.CDEMPRESA = row.CDEMPRESA;
            obj.NMEMPRESA = row.NMEMPRESA;
            obj.DTINICCONT = moment(row.DTINICCONT, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFINACONT = moment(row.DTFINACONT, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTINICLANC = moment(row.DTINICLANC, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFINALANC = moment(row.DTFINALANC, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTINIINTCONTDFE = moment(row.DTINIINTCONTDFE, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFININTCONTDFE = moment(row.DTFININTCONTDFE, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTINIINTCONTDFS = moment(row.DTINIINTCONTDFS, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFININTCONTDFS = moment(row.DTFININTCONTDFS, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTINICCTBL = moment(row.DTINICCTBL, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFINACCTBL = moment(row.DTFINACCTBL, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTINIINTCONTGPA = moment(row.DTINIINTCONTGPA, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFININTCONTGPA = moment(row.DTFININTCONTGPA, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.NRORG = row.NRORG;
            obj.__is_new = false;
            aux.push(obj);
            obj2.CDEMPRESA = row.CDEMPRESA;
            obj2.IDCONTGERE = row.IDCONTGERE;
            obj2.IDCONTCOME = row.IDCONTCOME;
            obj2.IDUTCUSTESTCONT = row.IDUTCUSTESTCONT;
            obj2.IDSUGRAT = row.IDSUGRAT;
            obj2.IDUTSALDOSOC = row.IDUTSALDOSOC;
            obj2.__is_new = false;
            obj2.IDMSMCONTADBCR = row.IDMSMCONTADBCR;
            obj2.IDCONSVNDDFS = row.IDCONSVNDDFS;
            obj2.IDDESPTRIBDIFAL = row.IDDESPTRIBDIFAL;
            obj2.IDRETESTSETOR = row.IDRETESTSETOR;
            obj2.IDCONSDTMOVIRETEST = row.IDCONSDTMOVIRETEST;
            aux2.push(obj2);
        });

        var back = [aux, aux2];
        return back;
    };
    
    this.cadastrarAutomaticamente = function(row){
        return Ger09400_ParametroContabil_Repository.cadastrarAutomaticamente(row);
    };

    this.comparDate = function(dataInicial, dataFinal){
        var dataIni = moment(dataInicial, 'DD/MM/YYYY');
        var dateFin = moment(dataFinal, 'DD/MM/YYYY');
        if(dataIni.isAfter(dateFin)){
            return true;
        } else {
            return false;
        }
    };

    this.intraPeriodoConta = function(date, dataInicial, dataFinal){
            var dateIni = moment(dataInicial, 'DD/MM/YYYY');
            var data = moment(date, 'DD/MM/YYYY');
            var dateFin = moment(dataFinal, 'DD/MM/YYYY');
            if(!data.isSame(dateIni) && !data.isSame(dateFin) && !data.isBetween(dateIni, dateFin)){
                return true;
            } else {
                return false;
            }
    };
};
Configuration(function(ContextRegister){
    ContextRegister.register('Ger09400_ParametroContabil_Service', Ger09400_ParametroContabil_Service);
});

// FILE: ./assets/js/services/Ger17700_Rendimentos_Socios_Service.js
 var Ger17700_Rendimentos_Socios_Service = function(Endereco, Ger17700_Rendimentos_Socios_Repository, ZHPromise){

};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ger17700_Rendimentos_Socios_Service', Ger17700_Rendimentos_Socios_Service);
});

// FILE: ./assets/js/services/Ger31000_contabilizacao_estoque_Service.js
var Ger31000_contabilizacao_estoque_Service = function(restEngine, ScreenService) {
    
    var self = this;
    
    /*Gera a contabilização de retiradas*/
    this.geraContabilizacaoRetirada = function(row) {
        restEngine.post("ctb#/geraContabilizacaoRetirada", {
            "requestType": "Row",
            "row": row
        }).then(function(response) {
            ScreenService.showMessage(response.dataset.Result[0], 'success');
        }).catch(function(error) {
            ScreenService.showMessage(error.data.error, 'error');
        });
    };
    
    /*Gera a Contabilização de Ajustes e Implantações*/
    this.geraContabilizacaoAjustImpla = function(row) {
        restEngine.post("ctb#/geraContabilizacaoAjustImpla", {
            "requestType": "Row",
            "row": row
        }).then(function(response) {
            ScreenService.showMessage(response.dataset.Result[0], 'success');
        }).catch(function(error) {
            ScreenService.showMessage(error.data.error, 'error');
        });
    };
    
    
    /*Gera o relatórios de Apropriação Contábil Implantações*/
    this.geraRelatorioImplantacao = function(row, widgetRelatorioApr, widgetRelatorioSCC) {
        switch(row.RELATORIO) {
            case 'A':
            case 'S':
                restEngine.post("ctb#/geraRelatorioImplantacao", {
                    "requestType": "Row",
                    "row": row
                }).then(function(response) {
                    // Atribui o datasource gerado no backend
                    widgetRelatorioApr.dataSource.data = response.dataset.data;
                    // Altera a habilitação da widget do relatório e ativa a tab
                    widgetRelatorioApr.enabled = true;
                    widgetRelatorioApr.label = "Apropriação Contábil " + (row.RELATORIO == 'A' ? "Analítica " : "Sintética ") + (row.IDTPLANC == 'I' ? "Implantações" : "Ajustes");
                    widgetRelatorioApr.getField("QTLANCTOEST").isVisible = row.RELATORIO == 'A'; //Para o relatório sintético estes campos não devem aparecer
                    widgetRelatorioApr.getField("VRUNIT").     isVisible = row.RELATORIO == 'A';
                    widgetRelatorioApr.activate();
                }).catch(function(error) {
                    ScreenService.showMessage(error.data.error, 'error');
                });
                break;
            case 'C':
                restEngine.post("ctb#/geraRelatorioImplantacao", {
                    "requestType": "Row",
                    "row": row
                }).then(function(response) {
                    // Atribui o datasource gerado no backend
                    widgetRelatorioSCC.dataSource.data = response.dataset.data;
                    // Altera a habilitação da widget do relatório e ativa a tab
                    widgetRelatorioSCC.enabled = true;
                    widgetRelatorioSCC.activate();
                }).catch(function(error) {
                    ScreenService.showMessage(error.data.error, 'error');
                });
                break;
        }
    };
    
    self.geraRelatorioAjusteApurcao = function(widget) {
        var row = widget.currentRow;
        var widgetRelatorio = widget.getParent().widgets[2];
        
        restEngine.post("ctb#/geraRelatorioContabImpostos", {
            "requestType": "Row",
            "row": row
        }).then(function(response) {
            widgetRelatorio.dataSourceFilter[0].value = row.CDINSCESTA;
            widgetRelatorio.activate();
            widgetRelatorio.reload();
        }, function(error) {
            ScreenService.showMessage(error.data.error, 'error');
            widgetRelatorio.dataSourceFilter[0].value = "";
            widgetRelatorio.reload();
        });
    };
    
    self.geraRelatorioAjusteApurcaoFiscal = function(linhasEditaveis) {

        return restEngine.post("ctb#/geraRelatorioAjusteApuracaoFis", {
            "requestType": "DataSet",
            "dataset": linhasEditaveis
        });
    };
    
    self.salvarAjustesContabFiscal = function(linhasEditaveis) {
        return restEngine.post("ctb#/salvarAjustesContabFiscal", {
            "requestType": "DataSet",
            "dataset": linhasEditaveis
        });
    };
};


Configuration(function(ContextRegister) {
    ContextRegister.register('Ger31000_contabilizacao_estoque_Service', Ger31000_contabilizacao_estoque_Service);
});


// FILE: ./assets/js/services/Ger95200_Representante_Legal_Service.js
var Ger95200_Representante_Legal_Service = function(Endereco, ZHPromise){

     var self = this;

     /* **************************************************
     * Função que retorna um request de validação de CEP
     * efetuado para a API dos Correios.
     *
     * @param String CEP
     *
     * @return Promise
     */
     this.validaCEP = function(CEP) {
        return Endereco.buscarCep(CEP);
     };
     

};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ger95200_Representante_Legal_Service', Ger95200_Representante_Legal_Service);
});

// FILE: ./assets/modules/saldos/assets/js/services/Ctb17000_Implantacao_Saldo_Service.js
var Ctb17000_Implantacao_Saldo_Service = function(Ctb17000_Implantacao_Saldo_Repository, ZHPromise){
    this.getMask = function(){
        return Ctb17000_Implantacao_Saldo_Repository.getMask();
    };
    
    this.getSequencial = function(){
        return Ctb17000_Implantacao_Saldo_Repository.getSequencial();
    };
    
    this.salvar = function(row){
        return Ctb17000_Implantacao_Saldo_Repository.salvar(row).then(function(row){
            return row;
        });
    };
};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ctb17000_Implantacao_Saldo_Service', Ctb17000_Implantacao_Saldo_Service);
});

// FILE: ./assets/modules/saldos/assets/js/services/Ctb68000_RecalculoSaldosGerenciais_Service.js
function Ctb68000_RecalculoSaldosGerenciais_Service(ErrorFrontend, Ctb68000_RecalculoSaldosGerenciais_Repository){
    
    function checkSaldoRow(row){
        if(isEmpty(row.CDEMPRESA)){
            return ErrorFrontend.regectedPromiseFieldEmpty('CDEMPRESA');
        }
        else{
            if(isEmpty(row.DTSALDO)){
                return ErrorFrontend.regectedPromiseFieldEmpty('DTSALDO');
            }
        }
        return null;
    }
    
    function isEmpty(value){
        return (value === undefined || value === null);
    }
    
    this.recalcularSaldo = function(row){
        var promise = checkSaldoRow(row);
        if(promise === null){
            return Ctb68000_RecalculoSaldosGerenciais_Repository.recalcularSaldo(row);
        }
        else{
            return promise;
        }
    };
    
    this.validatePeriodoContabil = function(row){
        var promise = checkSaldoRow(row);
        if(promise === null){
            return Ctb68000_RecalculoSaldosGerenciais_Repository.validatePeriodoContabil(row);
        }
        else{
            return promise;
        }
    };
    
}

Configuration(function(ContextRegister) {
    ContextRegister.register("Ctb68000_RecalculoSaldosGerenciais_Service", Ctb68000_RecalculoSaldosGerenciais_Service);
});

// FILE: ./assets/modules/saldos/assets/js/services/Ctb72800_RecalculoSaldosComerciais_Service.js
function Ctb72800_RecalculoSaldosComerciais_Service(ErrorFrontend, Ctb72800_RecalculoSaldosComerciais_Repository){
    
    function checkSaldoRow(row){
        if(isEmpty(row.CDEMPRESA)){
            return ErrorFrontend.regectedPromiseFieldEmpty('CDEMPRESA');
        }
        else{
            if(isEmpty(row.DTSALDO)){
                return ErrorFrontend.regectedPromiseFieldEmpty('DTSALDO');
            }
        }
        return null;
    }
    
    function isEmpty(value){
        return (value === undefined || value === null);
    }
    
    this.recalcularSaldo = function(row){
        var promise = checkSaldoRow(row);
        if(promise === null){
            return Ctb72800_RecalculoSaldosComerciais_Repository.recalcularSaldo(row);
        }
        else{
            return promise;
        }
    };
    
    this.validatePeriodoContabil = function(row){
        var promise = checkSaldoRow(row);
        if(promise === null){
            return Ctb72800_RecalculoSaldosComerciais_Repository.validatePeriodoContabil(row);
        }
        else{
            return promise;
        }
    };
    
}
Configuration(function(ContextRegister) {
    ContextRegister.register("Ctb72800_RecalculoSaldosComerciais_Service", Ctb72800_RecalculoSaldosComerciais_Service);
});

// FILE: ./assets/js/controllers/Ctb00001_RelatorioCustomizavelDeFaturamento_Controller.js
var Ctb00001_RelatorioCustomizavelDeFaturamento_Controller = function(ScreenService, templateManager, General, ZhFilterPreferences) {
    
    var self = this;
    
    self.filtroRazPorInscrEstad = function(widget, preference){
        var currentRowFiltro = preference.FILTER_ROW;

        var cdcontctbl = "_";
        var cdempresa = currentRowFiltro.CDEMPRESA;
        var dtemissao = currentRowFiltro.DATA_EMISSAO.start;
        var dtfinal = currentRowFiltro.DATA_EMISSAO.end;
        // var cdtipooper = "_";
        var cdtipooper = currentRowFiltro.CDTIPOOPER;
        
        widget.dataSourceFilter.forEach(function (filtro) {
            switch(filtro.name){
                case 'P_CDEMPRESA': filtro.value = cdempresa;
                    break;
                case 'P_CDCONTCTBL': 
                    currentRowFiltro.CDCONTCTBL.forEach(function(valor){
                        cdcontctbl = cdcontctbl.concat(valor.concat("_"));
                    });
                    filtro.value = cdcontctbl;
                    break;
                case 'P_DATAINI':
                    filtro.value = dtemissao;
                    break;
                case 'P_DATAFIN':
                    filtro.value = dtfinal;
                    break;
                case 'P_CDTIPOOPER': 
                    filtro.value = cdtipooper;
                    break;
                /*case 'P_CDTIPOOPER': 
                    currentRowFiltro.CDTIPOOPER.forEach(function(valor){
                        cdtipooper = cdtipooper.concat(valor.concat("_"));
                    });
                    filtro.value = cdtipooper;
                    break;*/
            }
        });
    };
    
};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb00001_RelatorioCustomizavelDeFaturamento_Controller', Ctb00001_RelatorioCustomizavelDeFaturamento_Controller);
});


// FILE: ./assets/js/controllers/Ctb00002_RelatorioFaturamentoContabil_Controller.js
var Ctb00002_RelatorioFaturamentoContabil_Controller = function(ScreenService, templateManager, General, ZhFilterPreferences) {
    
    var self = this;
    
    self.filtroFaturamentoContabil = function(widget, preference){
        var currentRowFiltro = preference.FILTER_ROW;

        var cdempresa = currentRowFiltro.CDEMPRESA;
        var cdcontctblini = currentRowFiltro.CDCONTCTBLINI;
        var cdcontctblfin = currentRowFiltro.CDCONTCTBLFIN;
        var dtinicio = currentRowFiltro.DTLANCCONT.start;
        var dtfinal = currentRowFiltro.DTLANCCONT.end;
        
        widget.dataSourceFilter.forEach(function (filtro) {
            switch(filtro.name){
                case 'P_CDEMPRESA': 
                    filtro.value = cdempresa;
                    break;
                case 'P_CDCONTINI':
                    filtro.value = cdcontctblini;
                    break;
                case 'P_CDCONTFIN':
                    filtro.value = cdcontctblfin;
                    break;
                case 'P_DTINICIAL':
                    filtro.value = dtinicio;
                    break;
                case 'P_DTFINAL':
                    filtro.value = dtfinal;
                    break;
            }
        });
        
        preference.CUSTOM_FILTER_ROW = currentRowFiltro;
        delete preference.CUSTOM_FILTER_ROW.CDEMPRESA;
        delete preference.CUSTOM_FILTER_ROW.DTLANCCONT;
        
        
    };
    
};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb00002_RelatorioFaturamentoContabil_Controller', Ctb00002_RelatorioFaturamentoContabil_Controller);
});


// FILE: ./assets/js/controllers/Ctb00700_documentos_contabeis_Controller.js
function ctb00700_documentos_contabeis_Controller(General, ScreenService, templateManager, localStorageEngine) {
    var self = this;
     /**
    * Seta na tela o nome do fieldGrup para cada tipo de apuração selecionada
    *
    * @param {object} widget widget de
    * Documentos Fiscais
    */
    this.setLabel = function(widget) {
        var WdgDocumentoFiscais = templateManager.container.widgets[0];
        var tipo = widget.widget.currentRow.TIPODEAPURACAO;
        WdgDocumentoFiscais.fieldGroups[1].label = "Escolha Apuração";
        WdgDocumentoFiscais.currentRow.REPORT_NAME = null;
        this.limpaTela(WdgDocumentoFiscais);
        this.limpaCampos(WdgDocumentoFiscais);
    };

    this.setFiltroImposto = function(tipo,widget) {
         if(tipo == "1"){
            widget.getField("SGIMPOSTONFE").dataSourceFilter[0].value = "F";
        }else
            if(tipo == "2"){
                widget.getField("SGIMPOSTONFE").dataSourceFilter[0].value = "E";
            }else{
                widget.getField("SGIMPOSTONFE").dataSourceFilter[0].operator = "IN";
                widget.getField("SGIMPOSTONFE").dataSourceFilter[0].value = ["M", "E"];
            }

     };

     /**
    * Fecha o popupa de tipo de Apuração
    *
    * @param {object} widget widget de
    * tipoRelatorioApuracao
    */
    this.fecharPesquisa = function(widget) {
        ScreenService.closePopup();
    };

    /**
    *  Seta a listas de relatorios para cada tipo de apuração
    *
    * @param {object} widget widget de
    * Documentos Fiscais
    */
    this.setDataRelatorio = function(widget) {
        var tipoApuracao = widget.currentRow.TIPODEAPURACAO;
        var WdgDocumentos = templateManager.container.getWidget("ctb00700_documentos_contabeis");
        var data = this.datasRelatorio(tipoApuracao);
        this.setFiltroImposto(tipoApuracao, WdgDocumentos);

        WdgDocumentos.fields.forEach(function(field) {
            if(field.name == "REPORT_NAME"){
                field.dataSource.data  = data;
            }
        });
        this.fecharPesquisa(widget);
    };
     /**
    *  Torna visível os campos para o relatório selecionado
    *
    * @param {object} widget widget de
    * Documentos Fiscais
    */
    this.abreCamposRelatorio = function(widget){
        this.limpaCampos(widget);
        var campos = [];
        var camposNaoObrigat = [];
        var relatorio = widget.currentRow.REPORT_CODE;
        this.layoutRelatorio(relatorio, widget, campos, camposNaoObrigat);
    };
     /**
    *  Recarrega o popup para cada campo select simples
    *
    * @param {object} field da widget de
    * Documentos Fiscais
    */

    this.reloadData = function(campo){
        campo.reload();
    };
     /**
    *  Reseta os campo de cada relatorio apos selecionar novo relatório
    *
    * @param {object} widget da widget de
    * Documentos Fiscais
    */
    this.limpaCamposPoEmpresa = function(widget){
         widget.fields.forEach(function(field){
         if(field.name != "REPORT_NAME"){
             if(field.name != "SGIMPOSTONFE"){
                 if(field.isVisible){
                    this.clearCampo(field);
                 }
             }
         }
        }.bind(this));
        //this.setFiltroCampoDTINIPERIODO(widget);
    };

    this.limpaCampos = function(widget){
        widget.fields.forEach(function(field){
         if(field.name != "REPORT_NAME"){
            this.clearCampo(field);
         }
        }.bind(this));
    };
      /**
    *  Limpa os campo para qualquer tipo de field
    *
    * @param {object} widget da widget de
    * Documentos Fiscais
    */
    this.clearCampo = function(field) {
			field.widget.currentRow[field.name] = "";
			field.formattedValue = "";
			field.currentDate = moment().startOf('month').startOf('day');
			if (field.change) {
				field.change();
			}
	};
      /**
    * Configura o campo obrigatorio por tipo de relatório
    *
    * @param {object, string, string} widget da widget de
    * Documentos Fiscais
    */
    this.configCampos = function(relatorio, field, camposNaoObrigat){
        var isRequired = camposNaoObrigat.includes(field.name);
         if(!isRequired){
            field.validations = {"required": true};
         }
    };
      /**
    *  Seta campo de acordo com a regras para cada relatório
    *
    * @param {object, object, array, int} widget da widget de
    * Documentos Fiscais
    */
    this.setaCampos = function(campos, widget, camposNaoObrigat = []){
        var relatorio = widget.currentRow.REPORT_CODE;
        if(relatorio){
         campos.forEach(function(campo) {
            widget.fields.forEach(function(field) {
                if(campo == field.name){
                    field.isVisible = true;
                    this.configCampos(relatorio, field, camposNaoObrigat);
                    //this.layoutRelatorio(widget);
                }
            }.bind(this));
        }.bind(this));
     }else{
         this.limpaTela(widget);
     }
    };

     /**
    *  Realiza um tratamento e string retirando espaços em branco
    *
    * @param {string} variavel da função do
    * setFiltroIsento
    */
    this.trataString = function(string){
        var novaString = "";
        for (var i = 0; i < string.length; i++) {
            if(string[i] != " ")
            novaString = novaString + (string[i]);
        }
        return novaString;
    };
      /**
    * Seta o filtro dos fields de acordo com o relatorio selecionado
    *
    * @param {object} widget da widget de
    * Documentos Fiscais
    */
    this.setFiltroNacSimpEstadual = function(widget, campo){
        if(widget.getField(campo).dataSource.name != "fis#/crud/mapa_Estadual"){
            widget.getField(campo).dataSource.name = "fis#/crud/mapa_Estadual";
            widget.getField(campo).dataSourceFilter = [];
            var name = ["CDEMPRESA","CDIMPOSTO","CDINSCESTA"];
            var operator = ["=","=","=",];
            var campoFiltro = ['CDEMPRESA','CDIMPOSTONFE','CDINSCESTA'];
            this.sintetizaFiltro(widget, campo, name, operator, campoFiltro);
        }
    };
      /**
    * Seta o filtro dos fields de acordo com o relatorio selecionado
    *
    * @param {object} widget da widget de
    * Documentos Fiscais
    */
    this.setFiltroMunicipal = function(widget, campo){
        if(widget.getField(campo).dataSource.name != "fis#/crud/mapa_Municipal"){
            widget.getField(campo).dataSource.name = "fis#/crud/mapa_Municipal";
            widget.getField(campo).dataSourceFilter = [];
            var name = ["CDEMPRESA"];
            var operator = ["="];
            var campoFiltro = ['CDEMPRESA'];
            this.sintetizaFiltro(widget, campo, name, operator, campoFiltro);
        }
    };
      /**
    * Seta o filtro dos fields de acordo com o relatorio selecionado
    *
    * @param {object} widget da widget de
    * Documentos Fiscais
    */
    this.setFiltroSimples = function(widget, campo){
        if(widget.getField(campo).dataSource.name != "fis#/crud/mapa_NacionalSimples"){
            widget.getField(campo).dataSource.name = "fis#/crud/mapa_NacionalSimples";
            widget.getField(campo).dataSourceFilter = [];
            var name = ["CDEMPRESA"];
            var operator = ["="];
            var campoFiltro = ['CDEMPRESA'];
            this.sintetizaFiltro(widget, campo, name, operator, campoFiltro);
        }
    };

     this.sintetizaFiltro = function(widget, campo, name, operator, campoFiltro){
        var filtro = [];
        var str1 = "@General.getFieldValue(";
        var str2 = ", 'fis00700_documentos_fiscais')@";
        for (var i = 0; i < name.length; i++) {
            filtro = {
                "name": name[i],
                "operator": operator[i],
                "value": str1.concat('"'+campoFiltro[i]+'"').concat(str2)
            };
            widget.getField(campo).dataSourceFilter.push(filtro);
            filtro = [];
        }
    };

    this.setFiltroDTFINAL = function(widget){
        var qtdFiltro = widget.getField("DTFINAL").dataSourceFilter.length;
        if(widget.getField("DTFINAL").dataSourceFilter[qtdFiltro-1].name == "DTFIMPERIODO"){
            widget.getField("DTFINAL").dataSourceFilter.pop();
        }
        var name = ["DTFIMPERIODO"];
        var operator = [">"];
        var campoFiltro = ['DTINICIO'];
        this.sintetizaFiltro(widget, "DTFINAL", name, operator, campoFiltro);
    };
      /**
    * Seta o filtro dos fields de acordo com o relatorio selecionado
    *
    * @param {object} widget da widget de
    * Documentos Fiscais
    */
    this.setFiltroPadrao = function(widget, campo){
        //if(widget.getField(campo).dataSource.name != "fis#/crud/mapa_padrao"){
            widget.getField(campo).dataSource.name = "fis#/crud/mapa_padrao";
            widget.getField(campo).dataSourceFilter = [];
            var name = ["P_CDEMPRESA","P_CDLIVROMAG"];
            var operator = ["=", "="];
            var campoFiltro = ['CDEMPRESA',"CDLIVROMAG"];
            this.sintetizaFiltro(widget, campo, name, operator, campoFiltro);
        //}
    };
      /**
    * Retira dos os fields se nenhum relatório for selecionado
    *
    * @param {object} widget da widget de
    * Documentos Fiscais
    */
    this.limpaTela = function(widget){
        widget.fields.forEach(function(field) {
            if(field.name != "REPORT_NAME"){
                field.isVisible = false;
                field.validations = {};
                field.readOnly = false;
            }
        });
    };
      /**
    * Abre o popup para selecionar o tipo de apuração
    *
    * @param {null}
    */
    this.abriFiltro = function(){
        var fltro = templateManager.container.getWidget("tipoRelatorioApuracao");
        fltro.isVisible = true;
        ScreenService.openPopup(fltro);
    };

      /**
    * Trata o formato da data retirando a parte de horas
    *
    * @param {object} widget da widget de
    * Documentos Fiscais
    */
    this.formataDataInicio = function(widget){
     	var data = widget.currentRow.DTINICIO;
     	var corte = data.substring(0, 10);
     	widget.currentRow.DTINICIO = corte;
    };
       /**
    * Trata o formato da data retirando a parte de horas
    *
    * @param {object} widget da widget de
    * Documentos Fiscais
    */
    this.formataDataFinal = function(widget){
     	var data = widget.currentRow.DTFINAL;
     	var corte = data.substring(0, 10);
     	widget.currentRow.DTFINAL = corte;
     };
    /**
    * Verifica se a datra inicial é maior que a data final
    *
    * @param {object} widget da widget de
    * Documentos Fiscais
    */
    this.validaData = function (currentRow) {
		var dataInicial = currentRow.DTINIPERIODO ? moment(currentRow.DTINIPERIODO, 'DD/MM/YYYY').format("DD/MM/YYYY") : null;
		var dataFinal = currentRow.DTFIMPERIODO ? moment(currentRow.DTFIMPERIODO, 'DD/MM/YYYY').format("DD/MM/YYYY") : null;
		var mensagem = "A data inicial deve ser menor ou igual a data final.";

		if (dataInicial && dataFinal && dataFinal < dataInicial) {
			ScreenService.showMessage(mensagem);
			return false;
		}
		return true;
	};
	 /**
    * Realisa validação dos fiels da widget
    *
    * @param {object, object, object} widget da widget de
    * Documentos Fiscais
    */
    this.validaCampos = function(currentRow, widget, args) {
		if (this.validaData(currentRow)) {
			if(widget.isValid()) {
            	var row = currentRow.REPORT_CODE;
			    General.openReportPopup(widget, this.abreRelatorio, [currentRow, args]);
				//this.abreRelatorio(currentRow, args);
			}
		}
	};
     /**
    * Gera o relatorio em PDF
    *
    * @param {object, object widget da widget de
    * Documentos Fiscais
    */
    this.abreRelatorio = function(currentRow, args) {
    	var relatorio  = currentRow.REPORT_CODE;
    	var camposComDefault = [];
    	var WdgDocumentos = templateManager.container.getWidget("ctb00700_documentos_contabeis");
    	args.row.NRORG = getLocalVar('NRORG');
    	switch (relatorio) {
            case 'CTB23000':
                break;
            case 'CTB21000':
                camposComDefault =  ["NRPAGINA",  'DIARIO', 'ULTPAGINA'];
                this.aplicaDefault(WdgDocumentos, camposComDefault);
                break;
    	}
    	General.openReport('ctb#/relatorios_contabeis', relatorio, args.row);
    }.bind(this);


  /**
    *  Seta Default campo de acordo com a regras para cada relatório
    *
    * @param {object, object, array, int} widget da widget de
    * Documentos Fiscais
    */
    this.aplicaDefault = function(WdgDocumentos, camposComDefault){

        camposComDefault.forEach(function(campoName) {
            var campo = WdgDocumentos.getField(campoName);

            WdgDocumentos.currentRow[campoName] = WdgDocumentos.currentRow[campoName] != "" ? WdgDocumentos.currentRow[campoName] : campo.defaultValue;
        }.bind(this));
    };


     /**
    * Configurações do realtorio por tipo de apuiração
    *
    * @param {object, object, object}, object} widget da widget de
    * Documentos Fiscais
    */
    this.layoutRelatorio = function(relatorio, widget, campos, camposNaoObrigat = []) {
        switch (relatorio) {
            case 'CTB23000':
            case 'CTB23004':
                this.limpaTela(widget);
                campos = ["NMEMPRESA","DTINIPERIODO","DTFIMPERIODO","NRPAGINA", 'NMCONTCTBLINI', 'NMCONTCTBLFIN', 'TIPODESALDO', 'DESCONSIDERA'];
                this.setaCampos(campos, widget, camposNaoObrigat);
                break;
            case 'CTB21000':

               this.limpaTela(widget);
                campos = ["NMEMPRESA","DTINIPERIODO","DTFIMPERIODO", "NRPAGINA",  'DIARIO', 'ULTPAGINA'];
                camposNaoObrigat =  ["NRPAGINA",  'DIARIO', 'ULTPAGINA'];
                this.setaCampos(campos, widget, camposNaoObrigat);
                break;

            case 'CTB21002':
               this.limpaTela(widget);
                campos = ["NMEMPRESA","DTINIPERIODO","DTFIMPERIODO", "NRPAGINA",  'DIARIO'];
                camposNaoObrigat =  ["NRPAGINA",  'DIARIO'];
                this.setaCampos(campos, widget, camposNaoObrigat);
                break;

            case 'CTB23001':
                this.limpaTela(widget);
                campos = ["NMEMPRESA","DTINIPERIODO","DTFIMPERIODO", 'NMCONTCTBLINI', 'NMCONTCTBLFIN', 'TIPODESALDO'];
                this.setaCampos(campos, widget, camposNaoObrigat);
    	        widget.getField('DTFIMPERIODO').readOnly = true;
                break;

            default:
                this.limpaTela(widget);
        }
    };

    //Troca a data final com base na inicial, dependendo de alguma regra do relatorio
    this.DTINIPERIODOOnChange = function(widget) {
        var relatorio  = widget.currentRow.REPORT_CODE;
        var DTFIMPERIODOField = widget.getField("DTFIMPERIODO");
        var DTINIPERIODOField = widget.getField("DTINIPERIODO");
        if(DTINIPERIODOField.value()){
            switch (relatorio) {
                case 'CTB23001':
                    let umAnoDepois = moment(DTINIPERIODOField.value(), "DD/MM/YYYY");
                    umAnoDepois = umAnoDepois.add(1, 'y');
                    DTFIMPERIODOField.setValue(umAnoDepois.format("DD/MM/YYYY"));
                    break;
                default:
            }
        }else{
            DTFIMPERIODOField.setValue(null);
        }
    };


    self.setContctblMask = function() {
       General.callRestEngine("cadCtb#/crud/paramgeral", "FilterData", []).then(function(response) {
            var paramgeral = response.dataset.paramgeral[0];
            localStorageEngine.setLocalVar('CDPICTCCTB', paramgeral.CDPICTCCTB);
       });
    };
}
Configuration(function(ContextRegister)
{
    ContextRegister.register('ctb00700_documentos_contabeis_Controller', ctb00700_documentos_contabeis_Controller);
});

// FILE: ./assets/js/controllers/Ctb10000_LancamentosContabeis_Controller.js
var Ctb10000_LancamentosContabeis_Controller = function(ScreenService, templateManager, General, restEngine, Ctb10000_LancamentosContabeis_Service, maskEngine, ZhFilterPreferences) {
    
    var self = this;
    
    /**************************************
    *          Funções do filtro          *
    ***************************************/

    /*
     * Função auxiliar para montar as listas de parâmetros de Cliente, Fornecedor e Banco,
     * uma vez que essas são definidas por um único campo na tabela.
     */
    var addListsFilter = function(filter, row) {
        // Variável que controla quais tipos foram considerados no filtro.
        var idlanccome = [];
        // Variáveis para a verificação dos valores parametrizados ou se é para buscar todos (indicado por 'T').
        var clienteValue = 'T';
        var fornecedValue = 'T';
        var bancoValue = 'T';
        var histpadrValue = 'T';
        var centcustValue = 'T';
        var filialValue = 'T';

        // Verifica se foi inserido algum cliente e cria a lista dele.
        if (Array.isArray(row.CDCLIENTE) && row.CDCLIENTE.length > 0) {
            clienteValue = "_" + row.CDCLIENTE.join("_") + "_";
            // Adiciona este tipo à lista de filtros.
            idlanccome.push("C");
        }
        filter.push(
            {
                "name": "P_CDCLIENTE",
                "operator": "=",
                "value": clienteValue
            }
        );

        // Verifica se foi inserido algum fornecedor e cria a lista dele.
        if (Array.isArray(row.CDFORNECED) && row.CDFORNECED.length > 0) {
            fornecedValue = "_" + row.CDFORNECED.join("_") + "_";
            // Adiciona este tipo à lista de filtros.
            idlanccome.push("F");
        }
        filter.push(
            {
                "name": "P_CDFORNECED",
                "operator": "=",
                "value": fornecedValue
            }
        );

        // Verifica se foi inserido algum banco e cria a lista dele.
        if (Array.isArray(row.CDREDUCONT) && row.CDREDUCONT.length > 0) {
            bancoValue = "_" + row.CDREDUCONT.join("_") + "_";
            // Adiciona este tipo à lista de filtros.
            idlanccome.push("B");
        }
        filter.push(
            {
                "name": "P_CDBANCO",
                "operator": "=",
                "value": bancoValue
            }
        );

        // Verifica se foi inserido algum histórico padrão e cria a lista dele.
        if (Array.isArray(row.CDHISTPADR) && row.CDHISTPADR.length > 0) {
            histpadrValue = "_" + row.CDHISTPADR.join("_") + "_";
        }
        filter.push(
            {
                "name": "P_CDHISTPADR",
                "operator": "=",
                "value": histpadrValue
            }
        );

        // Verifica se foi inserido algum centro de custo e cria a lista dele.
        if (Array.isArray(row.CDCENTCUST) && row.CDCENTCUST.length > 0) {
            centcustValue = "_" + row.CDCENTCUST.join("_") + "_";
        }
        filter.push(
            {
                "name": "P_CDCENTCUST",
                "operator": "=",
                "value": centcustValue
            }
        );

        // Verifica se foi inserido alguma unidade e cria a lista dela.
        if (Array.isArray(row.CDFILIAL) && row.CDFILIAL.length > 0) {
            filialValue = "_" + row.CDFILIAL.join("_") + "_";
        }
        filter.push(
            {
                "name": "P_CDFILIAL",
                "operator": "=",
                "value": filialValue
            }
        );

        // Verifica se houve filtro adicionado, indicando por T caso não haja.
        idlanccome = (idlanccome.length > 0) ? "_" + idlanccome.join("_") + "_" : 'T';
        filter.push(
            {
                "name": "P_IDLANCCOME",
                "operator": "=",
                "value": idlanccome
            }
        );
    };

    /*
     * Função para adicionar os parâmetros adicionais remanescentes no filtro.
     */
    var addRemaninigFilterValues = function(filter, row) {
        // Variáveis para a verificação dos valores parametrizados ou se é para buscar todos (indicado por 'T').
        var tvalor = 'T';
        var tcdcont = 'T';

        // Adiciona o campo TVALOR, que controla se é para exibir lançamentos
        // de todos os valores.
        // Verifica se foi inserido o filtro de intervalo de valores.
        if (row.VRINICIAL) {
            // Altera o filtro, indicando que há um intervalo inserido.
            tvalor = 'I';
        }
        filter.push(
            {
                "name": "P_TVALOR",
                "operator": "=",
                "value": tvalor
            }
        );

        // Adiciona o campo TCDCONT, que controla se é para exibir lançamentos
        // de todas as contas contábeis.
        // Verifica se foi inserido o filtro de intervalo de contas contábeis.
        if (row.CDCONTINI) {
            // Altera o filtro, indicando que há um intervalo inserido.
            tcdcont = 'I';
        }
        filter.push(
            {
                "name": "P_TCDCONT",
                "operator": "=",
                "value": tcdcont
            }
        );
    };

    /*
     * Função utilizada para colocar todos os parâmetros necessários no
     * dataSourceFilter. Também monta as listas compostas em Strings.
     */
    this.changeFilter = function(gridWidget, preference) {
        var currentRow = preference.FILTER_ROW;
        var dataSourceFilter = gridWidget.dataSourceFilter;
        var partidasWidget = templateManager.container.getWidget("partidas");
        var rateiosTabbedWidget = templateManager.container.getWidget("rateiosTabbed");

        // Se houver filtro por número de lançamento, altera a requisição e o filtro,
        // para que seja filtrado somente pelo lançamento e pela empresa.
        if (currentRow.NRLANCCONT) {
            gridWidget.dataSource.name = "ctb#/crud/lanccont_contctbl";
            // Altera o filtro, para que tenha somente dois parâmetros.
            dataSourceFilter = [
                {
                    "name": "CDEMPRESA",
                    "operator": "=",
                    "value": currentRow.CDEMPRESA
                },
                {
                    "name": "NRLANCCONT",
                    "operator": "=",
                    "value": currentRow.NRLANCCONT
                }
            ];
        }
        // Caso contário, o filtro é preparado de acordo com os parâmetros aceitos na query.
        else {
            gridWidget.dataSource.name = "ctb#/crud/lanccont_filtro";
            // Parâmetros a que devem ser removidos do filtro, para que possam ser preparados.
            var deleteKeys = ["CDCONTREDU", "CDREDUCONT", "CDFORNECED", "CDCLIENTE", "CDFILIAL", "CDCENTCUST", "P_CDCLIENTE", "P_CDFORNECED", "P_CDBANCO", "P_CDHISTPADR", "P_CDCENTCUST", "P_CDFILIAL", "P_IDLANCCOME", "P_TVALOR", "P_TCDCONT", "DTLANCCONT", "DTINICIAL", "DTFINAL", "CDEMPRESA"];
            // Parâmetros que devem aparecer no filtro, mesmo que o usuário não tenha inserido.
            var mustHaveKeys = ["CDCONTFIN", "VRFINAL", "CDCONTINI", "VRINICIAL", "CDDOCUCONT", "DSHISTLANC"];

            // Retorna somente os filtros fora da deleteKeys.
            dataSourceFilter = dataSourceFilter.filter(function(filter) {
                // Verifica se o filtro atual está na lista dos obrigatórios.
                var index = mustHaveKeys.indexOf(filter.name);
                if (index != -1) {
                    // Se estiver, elimina a necessidade de inclui-lo novamente.
                    mustHaveKeys.splice(index, 1);
                }
                return deleteKeys.indexOf(filter.name) === -1;
            });

            // Inclui todos os parâmetros obrigatórios que já não tenham sido incluídos.
            mustHaveKeys.forEach(function(key) {
                dataSourceFilter.push({
                    "name": key,
                    "operator": "=",
                    "value": "T"
                });
            });

            // Inclui o filtro por data, que está armazenado em um objeto na currentRow.
            dataSourceFilter.push(
                {
                    "name": "CDEMPRESA",
                    "operator": "=",
                    "value": currentRow.CDEMPRESA
                },
                {
                    "name": "DTINICIAL",
                    "operator": "=",
                    "value": currentRow.DTLANCCONT.start
                },
                {
                    "name": "DTFINAL",
                    "operator": "=",
                    "value": currentRow.DTLANCCONT.end
                }
            );

            // Funções de complementação do filtro.
            addListsFilter(dataSourceFilter, currentRow);
            addRemaninigFilterValues(dataSourceFilter, currentRow);
        }

        // Altera o dataSourceFilter da widget.
        gridWidget.dataSourceFilter = dataSourceFilter;

        // Altera a visibilidade dos campos conforme parametrização.
        gridWidget.getField("CDCONTCOME").isVisible = utilizaCodigoComercial;
        gridWidget.getField("IDLANCCOME").isVisible = utilizaCodigoComercial;
        partidasWidget.getField("CDCONTCOME").isVisible = utilizaCodigoComercial;
        partidasWidget.getField("IDLANCCOME").isVisible = utilizaCodigoComercial;

        // Altera a visibilidade da widget de Rateios conforme parametrização.
        rateiosTabbedWidget.isVisible = utilizaRateios;

        // Seta a variável auxiliar para indicar o código da empresa filtrada.
        cdempresa = currentRow.CDEMPRESA;

        // Ativa a widget principal
        gridWidget.activate();
    };

    /*
     * Função chamada ao alterar a data do lançamento.
     * Chama uma função do backend que lançará um erro caso a data esteja fora
     * do período contábil.
     */
    this.checkValidDataLancamento = function(partidasTabbedWidget) {
        // Verifica se há data informada.
        if (partidasTabbedWidget.currentRow.DTLANCCONT) {
            Ctb10000_LancamentosContabeis_Service.checkValidDataLancamento(partidasTabbedWidget.currentRow)
            .then(function(){}, function(error) {
                // Retira o valor inserido.
                partidasTabbedWidget.currentRow.DTLANCCONT = "";

                // Mensagem padrão em caso de timeout.
                var errorMessage = 'Timeout';

                // Verifica se houve alguma resposta da requisição.
                if (error.data) {
                    // Caso haja alguma resposta, atribui a mensagem de erro.
                    errorMessage = error.data.error;
                }


                // Imprime a mensagem.
                ScreenService.showMessage(errorMessage);

            });
        }
    };

    /*
     * Função para alterar o código final concatenando 'z's ao final deste. Isso é necessário para
     * buscar todas as contas contábeis do nível, então a comparação irá verificar os 'z's.
     * Exemplo: '123' < '12zzzzzzzz' é verdadeiro, logo buscaria a conta fictícia com código '123'.
     */
    this.contaFinalOnChange = function(filterWidget) {
        var currentRow = filterWidget.currentRow;
        // Armazena o valor antes de ser alterado, para que possa ser utilizado na validação do filtro.
        currentRow.CDCONTFIN_INICIAL = currentRow.CDCONTFIN;
        // Utilizado somente quando há uma conta contábil final selecionada.
        if (currentRow.CDCONTFIN) {
            currentRow.CDCONTFIN = (currentRow.CDCONTFIN + "zzzzzzzzzzzzzzzzzzz").substring(0, 20);
        }
    };

    /*
     * Função que altera o estado readOnly dos campos de Cliente e Centro de Custo no filtro
     * e seta as variáveis de controle de rateios/código comercial.
     */
    this.empresaOnChange = function(filterWidget) {
        var currentRow = filterWidget.currentRow;

        // As variáveis de controle são definidas de acordo com os parâmetros
        // que são trazidos na query de empresa.
        utilizaRateios = currentRow.IDCONTGERE == 'S';
        utilizaCodigoComercial = currentRow.IDCONTCOME == 'S';

        // Reseta os valores inseridos para os campos que dependem da empresa.
        currentRow.CDFILIAL = [];
        currentRow.NMFILIAL = [];
        currentRow.CDCENTCUST = [];
        currentRow.NMCENTCUST = [];

        currentRow.CDREDUCONT = [];
        currentRow.DSCONTCORR = [];
        currentRow.CDFORNECED = [];
        currentRow.NMRAZSOCFORN = [];
        currentRow.CDCLIENTE = [];
        currentRow.NMRAZSOCCLIE = [];

        // Muda a possibilidade de alterar esses campos de acordo com a parametrização.
        filterWidget.getField("CDREDUCONT").readOnly = !utilizaCodigoComercial;
        filterWidget.getField("CDCLIENTE").readOnly = !utilizaCodigoComercial;
        filterWidget.getField("CDFORNECED").readOnly = !utilizaCodigoComercial;

        filterWidget.getField("CDFILIAL").readOnly = !utilizaRateios;
        // O select de Centro de Custo, como depende dos valores inseridos para CDFILIAL,
        // tem o readOnly setado para true, uma vez que os valores foram resetados.
        filterWidget.getField("CDCENTCUST").readOnly = true;
    };

    /*
     * Função que altera o readOnly do campo de centro de custo, se houver unidade
     * selecionada.
     */
    this.filialFiltroOnChange = function(filterWidget) {
        var centcustField = filterWidget.getField("CDCENTCUST");
        var cdfilial = filterWidget.currentRow.CDFILIAL;

        // Verifica se há unidade(s) selecionada(s).
        var filialIsSet = Array.isArray(cdfilial) && cdfilial.length > 0;

        // Altera a propriedade readOnly do field.
        centcustField.readOnly = filialIsSet ? false : true;

        // Reseta quaisquer valores de centros de custo selecionados.
        filterWidget.currentRow.CDCENTCUST = [];
        filterWidget.currentRow.NMCENTCUST = [];
    };

    /*
     * Função para retornar o defaultValue do field interval do filtro.
     */
    this.getDefaultValueInterval = function() {
        return {
            "start": moment().format("DD/MM/YYYY"),
            "end": moment().format("DD/MM/YYYY")
        };
    };

    /*
     * Função que altera a validação required da data caso o número de lançamento
     * seja informado pelo usuário, já que não haveria necessidade de filtrar por data.
     */
    this.lancamentoFiltroOnChange = function(filterWidget) {
        var dataField = filterWidget.getField("DTLANCCONT");

        // Verifica se há um valor para o número de lançamento.
        var lancamentoIsSet = !!filterWidget.currentRow.NRLANCCONT;

        // Altera a necessidade de preenchimento do campo.
        dataField.validations = lancamentoIsSet ? {} : {required: true};
    };

    /*
     * Função para a abertura do filtro.
     */
    this.openFilter = function(gridWidget) {
        ZhFilterPreferences.setOriginalFilter(gridWidget.id);
        ZhFilterPreferences.openFilterWidget(gridWidget);
    };

    /*
     * Função para validar as entradas no filtro. Caso haja algo inválido,
     * uma mensagem correspondente será exibida para o usuário.
     */
    this.validateFilter = function(args, preference) {
        var currentRow = preference.FILTER_ROW;
        var valid = true;

        // Valida o filtro de valor
        if (currentRow.VRINICIAL && !currentRow.VRFINAL) {
            ScreenService.showMessage("Valor final deve ser informado.");
            valid = false;
        }
        else if (!currentRow.VRINICIAL && currentRow.VRFINAL) {
            ScreenService.showMessage("Valor inicial deve ser informado.");
            valid = false;
        }
        // O caso de ambos não estarem definidos não irá causar problemas aqui.
        else if (parseFloat(currentRow.VRINICIAL) > parseFloat(currentRow.VRFINAL)) {
            ScreenService.showMessage("Valor final deve ser igual ou maior que o valor inicial.");
            valid = false;
        }

        // Valida o filtro de conta contábil
        if (currentRow.CDCONTINI && !currentRow.CDCONTFIN) { /*CDCONTFIN_INICIAL*/
            ScreenService.showMessage("Conta contábil final deve ser informada.");
            valid = false;
        }
        else if (!currentRow.CDCONTINI && currentRow.CDCONTFIN ) { /*CDCONTFIN_INICIAL*/
            ScreenService.showMessage("Conta contábil inicial deve ser informada.");
            valid = false;
        }
        // O caso de ambos não estarem definidos não irá causar problemas aqui.
        else if (currentRow.CDCONTINI > currentRow.CDCONTFIN ) { /*CDCONTFIN_INICIAL*/
            ScreenService.showMessage("Conta contábil final deve ser igual ou maior que a conta contábil inicial.");
            valid = false;
        }

        // Caso esteja inválido, impede o filtro de continuar.
        if (!valid) {
            args.e.preventDefault();
        }
    };


    /**************************************
    *           Funções da tela           *
    ***************************************/

    // Variável que armazena a empresa filtrada pelo usuário.
    var cdempresa = null;

    // Variável para o controle do cabecalho de um lancamento, armazenando os dados deste.
    var cabecalho = {};

    // Variável que armazena a máscara de conta contábil.
    var contctblMask = "";

    // Variável de controle para que a função de prevenção de ativação não seja
    // chamada ao fechar o swipe.
    var isClosingSwipe = false;

    // Variável de controle, indicando se o lançamento foi alterado.
    var lancamentoAlterado = false;
    var lancamentoNovo = false;

    // Variáveis de controle das partidas e rateios excluídos.
    var partidasExcluidas = [];

    // Variável que armazena a parametrização referente à utilização de rateios.
    var utilizaRateios = false;

    // Variável que armazena a parametrização referente à utilização de código comercial.
    var utilizaCodigoComercial = false;

    /*
     * Função para cancelar as alterações feitas em um lançamento, retornando ao estado original.
     * Caso seja um lançamento novo, exclui tudo e retorna para a widget principal.
     * Caso contrário, retorna o lançamento para o estado em que estava antes das alterações.
     */
    this.cancelEditLancamento = function(tabbedWidget) {
        // Muda o modo de exibição da tabbed, cancelando a edição.
        tabbedWidget.list();

        // Se for um lançamento novo, cancela e retorna para o grid principal.
        if (lancamentoNovo) {
            this.goBackToMain();
        }
        // Senão, retorna ao estado anterior.
        else {
            // Retorna os dados originais do lançamento.
            var partidasWidget = templateManager.container.getWidget("partidas");
            Util.extend(partidasWidget.dataSource.data, partidasWidget.backupLancamento);
            delete partidasWidget.backupLancamento;

            // Reseta as variáveis de controle associadas.
            partidasExcluidas = [];
            lancamentoAlterado = false;

            // Contabiliza novamente os valores de crédito e débito.
            setTotalizacaoCabecalho();
        }
    };

    /*
     * Função para cancelar as alterações feitas em uma partida, retornando ao estado original.
     */
    this.cancelEditPartida = function(partidasWidget) {
        var rateiosTabbedWidget = templateManager.container.getWidget("rateiosTabbed");
        var rateiosWidget = templateManager.container.getWidget("rateios");

        // Se for uma partida nova sendo incluída, retira-a do dataSource.data.
        // Verifica também se a partida já foi salva, através da propriedade "partidaAlterada".
        if (partidasWidget.currentRow.partidaNova && !partidasWidget.currentRow.partidaAlterada) {
            // Reseta a partida inserida..
            partidasWidget.dataSource.data.pop();
            partidasWidget.currentRow = {};

            // Retorna as widgets ao modo de exibição.
            rateiosTabbedWidget.list();
            partidasWidget.list();

            // Volta para o grid.
            this.goBackToPartidasTabbed();
        }
        // Senão, volta ao estado anterior da partida.
        else {
            // Retorna os dados originais da currentRow.
            Util.extend(partidasWidget.currentRow, partidasWidget.backupRow);
            delete partidasWidget.backupRow;

            // Retorna as widgets ao modo de exibição.
            rateiosTabbedWidget.list();
            partidasWidget.view();
            partidasWidget.active = true;
            //partidasWidget.activate();

            // Efetua rollback nos rateios.
            rateiosWidget.dataSource.data = partidasWidget.currentRow.rateios;

            // Altera a widget atualmente selecionada, caso o usuário esteja na widget de rateios.
            partidasWidget.currentWidget = partidasWidget;

            // Verifica a parametrização anterior para a ativação da tab de rateios.
            toggleRateiosTabEnabled(partidasWidget);
        }
    };

    /*
     * Função para cancelar as alterações feitas em um rateio, retornando ao estado original.
     */
    this.cancelEditRateio = function(rateiosWidget) {
        // Se for um rateio novo sendo incluído, retira-o do dataSource.data.
        if (rateiosWidget.currentRow.rateioNovo && !rateiosWidget.currentRow.rateioAlterado) {
            // Reseta a partida inserida..
            rateiosWidget.dataSource.data.pop();
            rateiosWidget.currentRow = {};

            // Retorna a widget ao modo lista.
            rateiosWidget.list();

            // Volta para o grid.
            this.goBackToRateiosTabbed();
        }
        // Senão, volta ao estado anterior da partida.
        else {
            // Retorna os dados originais da currentRow.
            Util.extend(rateiosWidget.currentRow, rateiosWidget.backupRow);
            delete rateiosWidget.backupRow;

            // Retorna a widget ao modo view.
            rateiosWidget.view();
        }
    };

    /*
     * Função que verifica a necessidade de efetuar reload em um field select
     * que depende de outro campo na currentRow.
     * O primeiro parâmetro é o field em si, enquanto o segundo é o nome do campo
     * do qual o field depende. Se nada for inserido, assume-se o default sendo o
     * valor da variável cdempresa.
     */
    this.checkReloadNeed = function(field, codeName) {
        var currentRow = field.widget.currentRow;
        var currentCode = codeName ? Util.clone(currentRow[codeName]) : cdempresa;
        // Se o código no field não for o mesmo do especificado ou se não tiver
        // sido setado ainda, o field é recarregado e tem o código atualizado.
        if (field.lastCode != currentCode) {
            field.reload();
            field.lastCode = currentCode;
        }
    };

    /*
     * Função auxiliar que cria um backup do lançamento.
     * É chamada antes que qualquer alteração no lançamento possa ocorrer.
     */
    var createLancamentoBackup = function() {
        // Variável será alterada por métodos que efetivamente alterem algo no lançamento.
        if (!lancamentoAlterado) {
            var partidasWidget = templateManager.container.getWidget("partidas");
            partidasWidget.backupLancamento = Util.clone(partidasWidget.dataSource.data);
        }
    };

    /*
     * Função auxiliar que cria um backup de uma partida.
     * É chamada antes que qualquer alteração na partida ou em seus rateios
     * possa ocorrer.
     */
    var createPartidaBackup = function() {
        // Verifica a necessidade de criar um backup geral do lançamento.
        createLancamentoBackup();
        var partidaWidget = templateManager.container.getWidget("partidas");
        // Propriedade será alterada por métodos que efetivamente alterem algo na partida.
        if (!partidaWidget.currentRow.partidaEdicao) {
            partidaWidget.backupRow = Util.clone(partidaWidget.currentRow);
            partidaWidget.currentRow.partidaEdicao = true;
        }
    };

    /*
     * Função de verificação se a tab de rateios ficará habilitada e se os campos
     * de lançamento comercial ficarão habilitados, uma vez que ambos dependem da
     * empresa e da conta contábil em questão.
     */
    this.contaContabilOnChange = function(partidaWidget) {
        toggleRateiosTabEnabled(partidaWidget);
        // Reseta o valor de conta comercial.
        partidaWidget.currentRow.CDCONTCOME = null;
        // Chama a função com o escopo atual.
        toggleLancamentoComercialFields.call(this, partidaWidget);
    };

    /*
     * Função para colocar máscara ao exibir a diferença de valores para o usuário.
     * @return String
     *   Retorna o valor com a máscara do tipo currency.
     */
    var currencyMask = function(value) {
        // Cria a parametrização da máscara.
        var params = {
            type: "currency",
            params: {
                showSymbol: false,
                precision: 2,
                thousands: ".",
                decimal: ","
            }
        };
        // Aplica a máscara no valor.
        return Util.applyMask(value, params, maskEngine);
    };

    /*
     * Função para editar uma partida.
     */
    this.editarPartida = function(partidaWidget) {
        // Cria o backup da partida em questão.
        createPartidaBackup();

        // Coloca as widgets pertinentes em modo de edição.
        setPartidaAlterada();

        // Chama a função com o escopo atual.
        toggleLancamentoComercialFields.call(this, partidaWidget);
    };

    /*
     * Função para editar um rateio.
     */
    this.editarRateio = function(rateiosWidget) {
        // Verifica a necessidade de criar o backup dos dados da partida.
        createPartidaBackup();

        // Cria o backup do rateio atual.
        rateiosWidget.backupRow = Util.clone(rateiosWidget.currentRow);

        // Chama a função para verificar a propriedade readOnly do campo de Centro de Custo.
        this.filialRateioOnChange(rateiosWidget, true);

        // Coloca a widget do rateio em modo de edição.
        rateiosWidget.edit();
    };

    /*
     * Função para excluir um lançamento.
     * Há a confirmação se o usuário deseja realmente excluir.
     * Volta para o grid principal automaticamente.
     */
    this.excluirLancamento = function() {
        // Bloqueia a operação se o lançamento for de lote.
        if (cabecalho.IDLANCINTE == 'L') {
            // Função retorna o código do lote a ser exibido na mensagem para o usuário.
            Ctb10000_LancamentosContabeis_Service.getLote(cabecalho).then(function(lote) {
                var cdlote = lote.dataset.lanclote[0].CDLOTE;
                ScreenService.showMessage("Operação bloqueada! Lançamento contábil referente a lote. Favor realizar a reversão do lote " + cdlote + " para as devidas alterações.");
            });
        }

        // Guarda a referência ao escopo atual.
        var self = this;
        ScreenService.confirmMessage(ScreenService.i18n('Deseja excluir todo o lançamento contábil?'), 'question', function () {
            Ctb10000_LancamentosContabeis_Service.excluirLancamento(cabecalho)
            .then(function() {
                // Recarrega o grid principal.
                var lancamentosGeraisWidget = templateManager.container.getWidget("lancamentosGerais");
                //lancamentosGeraisWidget.reload();

                // Retorna para a widget de lançamentos, em modo de edição.
                //self.goBackToMain();
                ScreenService.closePopup();
                //ScreenService.goBack();
                lancamentosGeraisWidget.reload();
                self.goBackToMain();
                
            })
            // Função é executada caso ocorra algum erro na requisição.
            .catch(function(error) {
                // Mensagem padrão em caso de timeout.
                var errorMessage = 'Timeout';

                // Verifica se houve alguma resposta da requisição.
                if (error.data) {
                    // Caso haja alguma resposta, atribui a mensagem de erro.
                    errorMessage = error.data.error;
                }

                // Imprime a mensagem.
                ScreenService.showMessage(errorMessage);
            });
        });
    };

    /*
     * Função para excluir uma partida.
     * Há a confirmação se o usuário deseja realmente excluir.
     * Coloca o lançamento em modo de edição automaticamente.
     */
    this.excluirPartida = function(partidasWidget) {
        // Guarda a referência ao escopo atual.
        var self = this;
        // Verifica a necessidade de criar o backup dos dados da partida.
        createPartidaBackup();
        ScreenService.confirmMessage(ScreenService.i18n('Excluir partida?'), 'question', function () {
            // Verifica se a partida já existia anteriormente.
            if (!partidasWidget.currentRow.partidaNova) {
                // Armazena a partida excluída no array.
                partidasExcluidas.push(partidasWidget.currentRow);
            }

            // Remove a partida atual do dataSource.data.
            var index = partidasWidget.dataSource.data.indexOf(partidasWidget.currentRow);
            partidasWidget.dataSource.data.splice(index, 1);

            // Soma novamente os valores totais do lançamento.
            setTotalizacaoCabecalho();
            // Indica que o lançamento foi alterado e o altera para modo de edição.
            setLancamentoAlterado();
            // Retorna para a widget de lançamentos, em modo de edição.
            self.goBackToPartidasTabbed();
        });
    };

    /*
     * Função para excluir um rateio de uma partida.
     * Há a confirmação se o usuário deseja realmente excluir.
     * Coloca a partida em modo de edição automaticamente.
     */
    this.excluirRateio = function(rateiosWidget) {
        // Guarda a referência ao escopo atual.
        var self = this;
        // Verifica a necessidade de criar o backup dos dados do lançamento.
        createPartidaBackup();
        ScreenService.confirmMessage(ScreenService.i18n('Excluir rateio?'), 'question', function () {
            var partidasWidget = templateManager.container.getWidget("partidas");

            // Armazena o rateio excluído no array se ele não tiver sido
            // inserido na alteração atual (se ele não for novo).
            if (!rateiosWidget.currentRow.rateioNovo) {
                partidasWidget.currentRow.rateiosExcluidos.push(rateiosWidget.currentRow);
            }

            // Remove o rateio atual do dataSource.data.
            var index = rateiosWidget.dataSource.data.indexOf(rateiosWidget.currentRow);
            rateiosWidget.dataSource.data.splice(index, 1);

            // Indica que a partida foi alterado e muda as widgets pertinentes
            // para modo de edição.
            setPartidaAlterada();
            // Retorna para a widget de lançamentos, em modo de edição.
            self.goBackToRateiosTabbed();
        });
    };

    /*
     * Função que altera o readOnly do campo de centro de custo, se houver unidade
     * selecionada.
     */
    this.filialRateioOnChange = function(rateiosWidget, editRateio) {
        var centcustField = rateiosWidget.getField("CDCENTCUST");
        var cdfilial = rateiosWidget.currentRow.CDFILIAL;

        // Altera a propriedade readOnly do field, sendo false se houver CDFILIAL setada.
        centcustField.readOnly = !cdfilial;

        // Verifica se a função foi chamada pela função de editar o rateio.
        if (!editRateio) {
            // Reseta quaisquer valores de centros de custo selecionados.
            rateiosWidget.currentRow.CDCENTCUST = null;
            rateiosWidget.currentRow.NMCENTCUST = null;
        }
    };

    /*
     * Função chamada por fields de conta contábil.
     * Retorna a máscara de conta contábil.
     */
    this.getContctblMask = function() {
        return contctblMask;
    };

    /*
     * Função chamada pelo field de unidade para realizar o filtro por empresa.
     * Retorna o código da empresa filtrada pelo usuário.
     */
    this.getCdempresa = function() {
        return cdempresa;
    };

    /*
     * Função para retornar à widget principal.
     */
    this.goBackToMain = function() {
        var partidasdWidget = templateManager.container.getWidget("partidas");
        ScreenService.closeSwipe().then(function() {
            // Ativa a widget principal.
            partidasdWidget.getAction('salvarLancamento').isVisible = false;
            templateManager.container.getWidget("lancamentosGerais").activate();
        });
    };

    /*
     * Função para retornar à widget de partidas, ativando a widget tabbed.
     */
    this.goBackToPartidasTabbed = function() {
        var partidasTabbedWidget = templateManager.container.getWidget("partidas");

        // Fecha o swipe aberto.
        isClosingSwipe = true;
        ScreenService.closePopup();
        ScreenService.closeSwipe().then(function() {
            var currentWidget = templateManager.container.getActiveWidget();

            // Ativa a widget tabbed.
            partidasTabbedWidget.active = true;
            partidasTabbedWidget.activate();
            // Verifica se a tabbed deve ser exibida em modo de edição, no caso do lançamento ter sido alterado.
            //templateManager.container.mode = lancamentoAlterado ? "edit" : "list";

            // Reseta a variável de controle do swipe.
            isClosingSwipe = false;
        });
    };

    /*
     * Função para retornar à widget de rateios, ativando a widget tabbed.
     */
    this.goBackToRateiosTabbed = function() {
        var rateiosTabbedWidget = templateManager.container.getWidget("rateiosTabbed");

        // Fecha o swipe aberto.
        isClosingSwipe = true;
        ScreenService.closeSwipe().then(function() {
            var currentWidget = templateManager.container.getActiveWidget();

            // Ativa a tabbed.
            rateiosTabbedWidget.active = true;
            //rateiosTabbedWidget.activate();

            // Faz o container (footer) ficar no mesmo modo da tabbed.
            templateManager.container.mode = rateiosTabbedWidget.mode;

            // Reseta a variável de controle do swipe.
            isClosingSwipe = false;
        });
    };

    /*
     * Função para adicionar um novo lançamento.
     * Altera os campos de documento e data do cabeçalho para que sejam editáveis.
     */
    this.newLancamentoContabil = function() {
        // Verifica se uma empresa foi filtrada.
        if (!cdempresa) {
            ScreenService.showMessage("É necessário filtrar por uma empresa.");
            return;
        }

        var partidasTabbedWidget = templateManager.container.getWidget("partidasTabbed");
        var partidasWidget = templateManager.container.getWidget("partidas");
        var rateiosWidget = templateManager.container.getWidget("rateios");

        var documentoField = partidasTabbedWidget.getField("CDDOCUCONT");
        var dataField = partidasTabbedWidget.getField("DTLANCCONT");

        // Altera a propriedade readOnly dos fields do cabeçalho.
        documentoField.readOnly = false;
        dataField.readOnly = false;

        // Altera o modo de exibição do field de data do cabeçalho.
        dataField.template = dataField.formTemplate;

        // Abre o swipe com a inserção de um novo lançamento.
        //partidasTabbedWidget.newRow();
        //ScreenService.openSwipe(partidasTabbedWidget);
        //partidasTabbedWidget.mode = 'edit';
        partidasWidget.editing = true;
        ScreenService.openSwipe(partidasTabbedWidget);

        // Seta as variáveis de controle da edição do lançamento.
        lancamentoNovo = true;
        lancamentoAlterado = true;
        partidasExcluidas = [];

        // Seta os dataSources.data das widgets de partidas e rateios.
        partidasWidget.dataSource.data = [];
        rateiosWidget.dataSource.data = [];

        // Reseta a variável cabecalho, que armazena os dados do cabeçalho do lançamento.
        cabecalho = {lancamentoNovo: true};

        // Seta os valores iniciais do cabeçalho.
        cabecalho.DTLANCCONT = moment().format('DD/MM/YYYY');
        cabecalho.CDEMPRESA = cdempresa;
        setTotalizacaoCabecalho();
    };

    /*
     * Função para adicionar uma partida a um lançamento.
     */
    this.newPartida = function(partidaWidget) {
        // Bloqueia a operação se o lançamento for de lote.
        if (cabecalho.IDLANCINTE == 'L') {
            // Função retorna o código do lote a ser exibido na mensagem para o usuário.
            Ctb10000_LancamentosContabeis_Service.getLote(cabecalho).then(function(lote) {
                var cdlote = lote.dataset.lanclote[0].CDLOTE;
                ScreenService.showMessage("Operação bloqueada! Lançamento contábil referente a lote. Favor realizar a reversão do lote " + cdlote + " para as devidas alterações.");
            });
        }
        // Exibe a mensagem se o Documento não estiver preenchido.
        else if (!cabecalho.CDDOCUCONT) {
            ScreenService.showMessage("Documento deve ser informado.");
        }
        // Exibe a mensagem se a Data não estiver preenchida.
        else if (!cabecalho.DTLANCCONT) {
            ScreenService.showMessage("Data do lançamento contábil deve ser informada.");
        }
        // Abre o swipe para adicionar uma partida caso tudo esteja correto.
        else {
            
            partidaWidget.newRow();
            partidaWidget.applyDefaultValue();
            
            var totalCredito = 0;
            var totalDebito = 0;
            var diferenca = 0;
            
            var partidas = partidaWidget.dataSource.data;
            
            partidas.forEach(function (data) {
                
                if(data.CREDITO != null && data.CREDITO != ""){
                    totalCredito = parseFloat(totalCredito) + parseFloat(data.CREDITO);
                }
                if(data.DEBITO != null && data.DEBITO != ""){
                    totalDebito = parseFloat(totalDebito) + parseFloat(data.DEBITO);
                }
                
            });
            
            if(totalDebito > totalCredito){
                diferenca = parseFloat(totalDebito) - parseFloat(totalCredito);
                partidaWidget.currentRow.VALORABS = diferenca;
                partidaWidget.currentRow.IDDEBCRE = "CR";
            }else if(totalDebito < totalCredito){
                diferenca = parseFloat(totalCredito) - parseFloat(totalDebito);
                partidaWidget.currentRow.VALORABS = diferenca;
                partidaWidget.currentRow.IDDEBCRE = "DB";
            }

            // Propriedade para indicar que a partida foi inserida pelo usuário.
            partidaWidget.currentRow.partidaNova = true;
            partidaWidget.currentRow.rateios = [];
            partidaWidget.currentRow.rateiosExcluidos = [];

            // Seta o dataSource.data da widget de rateios como uma referência
            // aos rateios da partida.
            templateManager.container.getWidget("rateios").dataSource.data = partidaWidget.currentRow.rateios;

            // Altera a widget de rateios para o modo de edição.
            //templateManager.container.getWidget("rateiosTabbed").edit();

            toggleLancamentoComercialFields.call(this, partidaWidget);
        }
    };

    /*
     * Função para adicionar um rateio a uma partida.
     * Essa função será chamada pela action de adicionar da widget de rateios,
     * sendo que a última só estará visível e habilitada se a empresa permitir
     * rateios e a conta contábil da partida for de um tipo gerencial.
     */
    this.newRateio = function(rateiosWidget) {
        // Cria o backup da partida em questão.
        var partidasWidget = templateManager.container.getWidget("partidas");
        createPartidaBackup();

        rateiosWidget.newRow();
        rateiosWidget.applyDefaultValue();
        // Propriedade para indicar que o rateio foi inserida pelo usuário.
        rateiosWidget.currentRow.rateioNovo = true;

        // Chama a função para resetar a propriedade readOnly do campo de Centro de Custo.
        this.filialRateioOnChange(rateiosWidget);
        
        var valorRateio = 0;

        rateiosWidget.dataSource.data.forEach(function(rateio) {
            if(rateio.VALORABS != ''){
                valorRateio = parseFloat(valorRateio) + parseFloat(rateio.VALORABS);
            }
        });
        
        if(valorRateio > 0){
            rateiosWidget.currentRow.VALORABS = partidasWidget.currentRow.VALORABS - valorRateio;
        }else{
            rateiosWidget.currentRow.VALORABS = partidasWidget.currentRow.VALORABS;
        }
        
    };

    /*
     * Função para a abertura e carregamento dos dados das partidas de um dado lançamento.
     */
    this.openLancamentosSwipe = function(gridWidget) {
        // Verifica se não é um novo lançamento.
        if (!gridWidget.isNewRow()) {
            // Reseta a variável de armazenamento do cabeçalho.
            cabecalho = {};

            var partidasTabbedWidget = templateManager.container.getWidget("partidasTabbed");
            var self = this;
            // Abre o swipe do lançamento.
            ScreenService.openSwipe(partidasTabbedWidget).then(function() {
                // Carrega os dados do lançamento.
                self.reloadLancamentoData(true);
            });
        }
    };

    /*
     * Função de auxílio que remove quaisquer casas decimais extras em um valor
     * e executa um parse para que seja númerico.
     */
    var parseFloatWithDecimals = function(value) {
        return parseFloat(parseFloat(value).toFixed(2));
    };

    /*
     * Função que controla a exibição da widget de rateios e seta os dados dos rateios da partida.
     */
    this.partidaAfterMoveRow = function(partidasWidget) {
        var rateiosWidget = templateManager.container.getWidget("rateios");

        // Seta os dados dos rateios da partida.
        // Como a atribuição é feita por referência, qualquer alteração feita
        // na widget de rateios irá ser replicada para o array de rateios da
        // partida e vice-versa.
        rateiosWidget.dataSource.data = partidasWidget.currentRow.rateios || [];

        // Altera a possibilidade de selecionar a widget de rateios conforme parametrização.
        toggleRateiosTabEnabled(partidasWidget);
    };

    /*
     * Função de prevenção ao comportamento padrão das tabbeds, fazendo com que
     * a tabbed possa ser ativada sem ativar a widget filha.
     * É utilizada quando a tabbed está em modo de edição, para que o footer
     * assuma a forma de edição e as respectivas actions apareçam, em vez de
     * exibir as actions da widget filha.
     */
    this.preventActivation = function(childWidget) {
        // Verifica se a widget atual está em modo list, significando que a tabbed está visível no momento.
        if (childWidget.mode == 'list' && !isClosingSwipe) {
            var parentWidget = childWidget.getParent();

            // Ativa a tabbed.
            parentWidget.active = true;
            //parentWidget.activate();
            // Faz o container (footer) ficar no mesmo modo da tabbed..
            templateManager.container.mode = parentWidget.mode;
        }
    };

    /*
     * Função que realiza o (re)carregamento dos dados de um lançamento que
     * já esteja aberto no swipe. A função é chamada ao salvar um lançamento,
     * ao abrir o swipe de um lançamento e pela action de reload do floatingControl.
     */
    this.reloadLancamentoData = function(openingSwipe) {
        var partidasTabbedWidget = templateManager.container.getWidget("partidasTabbed");
        if (partidasTabbedWidget.mode != "edit") {
            var gridWidget = templateManager.container.getWidget("lancamentosGerais");
            var currentRow = Util.isEmptyObject(cabecalho)? gridWidget.currentRow : cabecalho;
            var partidasWidget = templateManager.container.getWidget("partidas");
            var rateiosWidget = templateManager.container.getWidget("rateios");

            var documentoField = partidasTabbedWidget.getField("CDDOCUCONT");
            var dataField = partidasTabbedWidget.getField("DTLANCCONT");

            // Altera a propriedade readOnly dos fields do cabeçalho.
            documentoField.readOnly = true;
            dataField.readOnly = true;

            // Altera o modo de exibição do field de data do cabeçalho.
            //dataField.template = dataField.viewTemplate;

            // Reseta variáveis de controle da edição do lançamento.
            //partidasTabbedWidget.view();
            lancamentoNovo = false;
            lancamentoAlterado = false;
            partidasExcluidas = [];

            // Carrega os dados do lançamento.
            Ctb10000_LancamentosContabeis_Service.getLancamento(currentRow.CDEMPRESA, currentRow.NRLANCCONT)
            .then(function(response) {
                // Armazena os dados retornados.
                var rateios = response.dataset.rateios;
                var partidas = response.dataset.partidas;

                // Configura cada rateio com suas propriedades de controle.
                rateios.forEach(function(rateio) {
                    // Propriedade para a verificação se o rateio foi editado.
                    rateio.rateioAlterado = false;
                    // Propriedade para a verificação se o rateio é novo.
                    rateio.rateioNovo = false;
                });

                // Configura cada partida com seus rateios e propriedades de controle.
                partidas.forEach(function(partida) {
                    // Propriedade para a verificação se a partida foi editada.
                    partida.partidaAlterada = false;
                    // Propriedade para a verificação se a partida é nova.
                // Armazena o array de rateios associados à partida.
                    partida.partidaNova = false;

                    partida.rateios = rateios.filter(function(rateio) {
                        return rateio.NRSEQLANC == partida.NRSEQLANC;
                    });

                    // Propriedade para o armazenamento de quaisquer rateios que tenham sido excluidos.
                    partida.rateiosExcluidos = [];
                });

                // Altera os dados exibidos no grid de partidas e no grid de rateios.
                partidasWidget.dataSource.data = partidas;
                rateiosWidget.dataSource.data = rateios;

                // Configura as informações do cabeçalho.
                // Como as informações são as mesmas para todas as partidas, copia os dados do primeiro registro.
                cabecalho = Util.clone(partidas[0]);
                cabecalho.lancamentoNovo = false;

                // Seta os valores totais de créditos e débitos.
                setTotalizacaoCabecalho();

                // Se a função foi chamada pela função de abrir o swipe, seta a
                // currentWidget como a widget de partidas.
                if (openingSwipe) {
                    partidasTabbedWidget.currentWidget = partidasWidget;
                }
            });
        }
    };

    /*
     * Função para salvar as alterações de um lançamento.
     * Executa a maior parte das validações básicas necessárias para enviar
     * a requisição para o backend.
     */
    this.saveLancamento = function() {
        var lancamentosGeraisWidget = templateManager.container.getWidget("lancamentosGerais");
        // Exibe a mensagem se o Documento não estiver preenchido.
        if (!cabecalho.CDDOCUCONT) {
            ScreenService.showMessage("Documento deve ser informado.");
            return;
        }
        // Exibe a mensagem se a Data não estiver preenchida.
        if (!cabecalho.DTLANCCONT) {
            ScreenService.showMessage("Data do lançamento contábil deve ser informada.");
            return;
        }
        // Exibe a mensagem se não houver partida de débito.
        if (!cabecalho.DEBITOTOTAL) {
            ScreenService.showMessage("Partida de débito deve ser realizada.");
            return;
        }
        // Exibe a mensagem se não houver partida de crédito.
        if (!cabecalho.CREDITOTOTAL) {
            ScreenService.showMessage("Partida de crédito deve ser realizada.");
            return;
        }
        // Exibe a mensagem se o valor de crédito for diferente do valor de débito.
        if (cabecalho.CREDITOTOTAL != cabecalho.DEBITOTOTAL) {
            var valorDiferenca = currencyMask(cabecalho.CREDITOTOTAL - cabecalho.DEBITOTOTAL);
            ScreenService.showMessage("Valor total de crédito difere do total de débito.<br><br>Diferença: " + valorDiferenca);
            return;
        }
        // Variável para guardar o escopo atual nas promises.
        var self = this;
        var partidasWidget = templateManager.container.getWidget("partidas");
        var partidas = partidasWidget.dataSource.data;

        cabecalho.partidasExcluidas = partidasExcluidas;

        Ctb10000_LancamentosContabeis_Service.saveLancamento(partidas, cabecalho)
        .then(function(response) {
            var partidasTabbedWidget = templateManager.container.getWidget("partidasTabbed");
            var rateiosTabbedWidget = templateManager.container.getWidget("rateiosTabbed");
            var nrlanccont = response.dataset.columnsToReturn.NRLANCCONT;

            // Atribui o número do lançamento atual, retornado pelo backend.
            cabecalho.NRLANCCONT = nrlanccont;

            // Muda o modo de exibição das widgets tabbeds.
            partidasTabbedWidget.list();
            rateiosTabbedWidget.list();

            // Recarrega os dados do lançamento.
            self.reloadLancamentoData();
            
            ScreenService.closePopup();
            //ScreenService.goBack();
            self.goBackToMain();
            partidasWidget.reload();
            //ScreenService.closePopup();
            lancamentosGeraisWidget.reload();
        })
        // Função é executada caso ocorra algum erro na requisição.
        .catch(function(error) {
            // Mensagem padrão em caso de timeout.
            var errorMessage = 'Timeout';

            // Verifica se houve alguma resposta da requisição.
            if (error.data) {
                // Caso haja alguma resposta, atribui a mensagem de erro.
                errorMessage = error.data.error;
            }

            // Imprime a mensagem.
            ScreenService.showMessage(errorMessage);
        });
    };

    /*
     * Função para salvar a partida.
     * Coloca o lançamento em modo de edição, se já não estiver.
     */
    this.savePartida = function(partidasWidget) {
        var lancamentosGeraisWidget = templateManager.container.getWidget("lancamentosGerais");
        if (partidasWidget.isValid()) {
            var currentRow = partidasWidget.currentRow;

            // Verifica se a conta contábil é de um tipo gerencial, controlando rateios.
            var rateiosEnabled = currentRow.IDCONTCCUS == 'R' || currentRow.IDCONTCCUS == 'G';

            // Executa um parse no valor da partida e remove quaisquer decimais.
            currentRow.VALORABS = parseFloatWithDecimals(currentRow.VALORABS);

            // Se a conta contábil for gerencial e a empresa controlar rateios, faz as validações.
            if (utilizaRateios && rateiosEnabled) {
                var rateiosWidget = templateManager.container.getWidget("rateios");
                var rateiosTabbedWidget = templateManager.container.getWidget("rateiosTabbed");

                // Se a partida não tiver rateios, exibe mensagem de erro.
                if (!Array.isArray(currentRow.rateios) || currentRow.rateios.length === 0) {
                    ScreenService.showMessage("Rateio deve ser informado para as contas do tipo Gerencial ou Oficial/Gerencial.");
                    rateiosTabbedWidget.activate();
                    return;
                }
                else {
                    // Variável auxiliar para armazenar o valor total dos rateios.
                    var valorRateio = 0;

                    rateiosWidget.dataSource.data.forEach(function(rateio) {
                        // Executa um parse no valor do rateio e remove quaisquer decimais extras.
                        rateio.VALORABS = parseFloatWithDecimals(rateio.VALORABS);

                        // Soma o valor de cada rateio.
                        valorRateio += rateio.VALORABS;

                        // Seta o valor real do rateio de acordo com o identificador do tipo da partida.
                        rateio.VRLANCCUST = currentRow.IDDEBCRE == 'CR' ? rateio.VALORABS : -rateio.VALORABS;
                    });

                    // Se o valor total dos rateios não coincidir com o valor da partida, exibe mensagem de erro.
                    if (valorRateio != currentRow.VALORABS) {
                        var valorDiferenca = currencyMask(currentRow.VALORABS - valorRateio);
                        ScreenService.showMessage("A soma dos rateios deve ser igual ao valor da partida.<br><br>Diferença: " + valorDiferenca);
                        return;
                    }
                }

                // Muda a tabbed de rateios para o modo list e a desativa.
                rateiosTabbedWidget.list();
                //rateiosTabbedWidget.deactivate();
            }
            // Reseta propriedade que indica que a partida estava sendo editada.
            currentRow.partidaEdicao = false;

            // Reseta ou seta os valores de acordo com o identificador do tipo da partida.
            currentRow.CREDITO = currentRow.IDDEBCRE == 'CR' ? currentRow.VALORABS : null;
            currentRow.DEBITO = currentRow.IDDEBCRE == 'DB' ? currentRow.VALORABS : null;

            // Seta o valor real do lançamento de acordo com o identificador do tipo da partida.
            currentRow.VRLANCAMENT = currentRow.IDDEBCRE == 'CR' ? currentRow.VALORABS : -currentRow.VALORABS;

            // Indica que o lançamento foi alterado e o altera para modo de edição.
            setLancamentoAlterado();

            // Muda a tab atual para a tab da partida e a ativa.
            partidasWidget.currentWidget = partidasWidget;
            partidasWidget.active = true;
            partidasWidget.activate();
            //partidasWidget.view();
            //lancamentosGeraisWidget.reload();
            self.goBackToPartidasTabbed();


            // Soma novamente os valores totais do lançamento.
            setTotalizacaoCabecalho();
            partidasWidget.getAction('salvarLancamento').isVisible = true;
        }
        // Caso os dados obrigatórios da partida não tenham sido inseridos,
        // seta a widget da partida como a atual.
        else {
            partidasWidget.currentWidget = partidasWidget;
            //partidasWidget.active = true;
            partidasWidget.activate();
        }
    };

    /*
     * Função para salvar o rateio.
     * Coloca a partida em modo de edição, se já não estiver.
     */
    this.saveRateio = function(rateiosWidget) {
        // Verifica se todos os campos obrigatórios foram preenchidos.
        if (rateiosWidget.isValid()) {
            var currentRateio =  rateiosWidget.currentRow;
            // Retorna um array com quaisquer rateios que tenham sido cadastrados
            // com a mesma unidade e centro de custo do rateio atual.
            var sameFilialCentcust = rateiosWidget.dataSource.data.filter(function(rateio) {
                return rateio.CDFILIAL == currentRateio.CDFILIAL && rateio.CDCENTCUST == currentRateio.CDCENTCUST;
            });

            // Como o rateio atual vai estar presente no dataSource.data, é necessário
            // verificar se há um registro além do atual com a mesma unidade e centro
            // de custo do rateio atual, além dele mesmo.
            if (sameFilialCentcust.length > 1) {
                ScreenService.showMessage("Rateio já informado para a unidade e centro de custo informados.");
            }
            // Se não houver, salva o rateio atual normalmente.
            else {
                // Seta a propriedade de controle de rateio alterado para true.
                currentRateio.rateioAlterado = true;

                // Chama a função responsável por indicar que houve alteração na partida.
                setPartidaAlterada();


                // Muda o modo de exibição da widget, salvando rateio dado alterado.
                rateiosWidget.view();
                ScreenService.goBack();
                
                //ScreenService.closePopup();
                //ScreenService.goBack();
                //lancamentosGeraisWidget.reload();
                //self.goBackToMain();
            }
        }
    };

    /*
     * Função chamda ao abrir a tela.
     * Seta a máscara de conta contábil na variável.
     */
    this.setContctblMask = function() {
        General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []).then(function(response) {
            var paramgeral = response.dataset.paramgeral[0];
            contctblMask = paramgeral.CDPICTCCTB;
        });
    };

    /*
     * Função para setar o valor dos campos select com o CDCONTCOME, uma vez que
     * o outData não permite que o valor de um campo preencha mais de um outro campo.
     */
    this.setDescriptionValuesCdcontcome = function(partidaWidget) {
        var currentRow = partidaWidget.currentRow;

        // Seta a propriedade como nula caso não exista.
        currentRow.CDCONTCOME = currentRow.CDCONTCOME || null;

        // Seta os códigos nos fields selects para a exibição, caso algum esteja visível.
        currentRow.CDREDUCONT = currentRow.CDCONTCOME;
        currentRow.CDCLIENTE = currentRow.CDCONTCOME;
        currentRow.CDFORNECED = currentRow.CDCONTCOME;
    };

    /*
     * Função chamada por outras funções ao alterar algum dado da partida.
     * O lançamento é colocado em modo de edição, salvando as alterações somente ao salvar o lançamento.
     */
    var setLancamentoAlterado = function() {
        if (!lancamentoAlterado) {
            var partidasTabbedWidget = templateManager.container.getWidget("partidasTabbed");
            lancamentoAlterado = true;
            partidasTabbedWidget.editing = true;
            //partidasTabbedWidget.edit();
        }
    };

    /*
     * Função chamada por outras funções ao alterar algum rateio da partida
     * ou ao editar a partida.
     * A widget de rateios e a da partida são colocadas em modo de edição,
     * salvando as alterações somente ao salvar a partida.
     */
    var setPartidaAlterada = function() {
        var partidaWidget = templateManager.container.getWidget("partidas");
        partidaWidget.currentRow.partidaAlterada = true;
        // Verifica se a alteração já foi feita.
        if (!partidaWidget.editing) {
            // Coloca as widgets dos rateios e da partida em modo de edição.
            partidaWidget.edit();
            templateManager.container.getWidget("rateiosTabbed").edit();
        }
    };

    /*
     * Função que deve ser chamada sempre que houver uma atualização em um lançamento
     * ou na chamada do afterMoveRow, contabilizando os valores totais do mesmo.
     */
    var setTotalizacaoCabecalho = function() {
        var partidasTabbedWidget = templateManager.container.getWidget("partidasTabbed");
        // Busca os dados das partidas da widget que contém o grid.
        var partidas = templateManager.container.getWidget("partidas").dataSource.data;

        // Somatório de créditos e débitos.
        var creditos = 0;
        var debitos = 0;
        partidas.forEach(function(partida) {
            // Verifica se o valor é nulo na partida, somando somente o correspondente.
            creditos += parseFloat(partida.CREDITO) || 0;
            debitos += parseFloat(partida.DEBITO) || 0;
        });
        cabecalho.CREDITOTOTAL = creditos;
        cabecalho.DEBITOTOTAL = debitos;

        // Seta o data do dataSource da tabbed.
        partidasTabbedWidget.dataSource.data = [cabecalho];

        // Seta a currentRow como o primeiro dado do dataSource.data, o objeto "cabecalho".
        partidasTabbedWidget.moveToFirst();
    };

    /*
     * Função chamada quando uma partida entra em modo de edição ou a conta contábil é alterada.
     * Altera o campo que é exibido para o usuário conforme parametrização da conta contábil e da empresa.
     */
    var toggleLancamentoComercialFields = function(partidaWidget) {
        var currentRow = partidaWidget.currentRow;
        var idlanccome = currentRow.IDLANCCOME;

        // Verifica qual campo ficará visível.
        // Considera sempre se a empresa utiliza código comercial.
        var bancoIsVisible = idlanccome == 'B' && utilizaCodigoComercial;
        var clienteIsVisible = idlanccome == 'C' && utilizaCodigoComercial;
        var fornecedorIsVisible = idlanccome == 'F' && utilizaCodigoComercial;
        var cdcontcomeIsVisible = !idlanccome && utilizaCodigoComercial;

        // Edita a visibilidade dos fields no form conforme parametrização.
        // Altera também a validação required dos campos.
        partidaWidget.getField("CDREDUCONT").showOnForm = bancoIsVisible;
        partidaWidget.getField("CDREDUCONT").validations = bancoIsVisible ? {"required": true} : {};

        partidaWidget.getField("CDCLIENTE").showOnForm = clienteIsVisible;
        partidaWidget.getField("CDCLIENTE").validations = clienteIsVisible ? {"required": true} : {};

        partidaWidget.getField("CDFORNECED").showOnForm = fornecedorIsVisible;
        partidaWidget.getField("CDFORNECED").validations = fornecedorIsVisible ? {"required": true} : {};

        partidaWidget.getField("CDCONTCOME").showOnForm = cdcontcomeIsVisible;

        // Funções temporárias chamadas para que os campos sejam atualizados.
        // Aguardando correção do framework.
        partidaWidget.redraw();
        templateManager.updateTemplate();

        // Seta os códigos nos fields selects para a exibição, caso algum esteja visível.
        this.setDescriptionValuesCdcontcome(partidaWidget);
    };

    /*
     * Altera a propriedade "enabled" da widget de rateios de acordo com
     * parâmetro da conta contábil selecionada.
     */
    var toggleRateiosTabEnabled = function(partidasWidget) {
        var rateiosTabbedWidget = templateManager.container.getWidget("rateiosTabbed");
        // Verifica se a conta contábil da partida é de um tipo gerencial.
        var idcontccus = partidasWidget.currentRow.IDCONTCCUS;

        // Altera a possibilidade de selecionar a widget de rateios de acordo com o parâmetro.
        rateiosTabbedWidget.enabled = idcontccus == 'R' || idcontccus == 'G';
    };
    
    
    this.openContabil = function(){
	    var widget = templateManager.container.getWidget('lancamentosGerais');
	    var dataSet = [
            widget.currentRow.CDEMPRESA,
            widget.currentRow.NRLANCCONT
        ];
        General.callRestEngine('ctb#/rastreioContabil', 'Row', dataSet).then(function (result) {
            //console.log(result);
            var rastreio = result.dataset.rastreioContabil[0];
            delete rastreio.__isSelected;
            delete rastreio.__rightActions;
            delete rastreio.__leftActions;
            delete rastreio.__proto;
            var origem = rastreio.ORIGEM;
            var nrdocu;
            var vrdocu;
            if(origem == 'BAIXA_REC' || origem == 'BAIXA_PAG'){
                nrdocu = '';
                vrdocu = rastreio.VRDOCU;
                
            }else{
                nrdocu = rastreio.NRDOCU;
                vrdocu = '';
            }
            var datalanc = rastreio.DATA;
            var cdempresa = rastreio.CDEMPRESA;
            var nmempresa = rastreio.NMEMPRESA;
            var cdcliente = rastreio.CDCLIENTE;
            var cdforneced = rastreio.CDFORNECED;
            
            
            switch(origem) {
            case 'REC':
            case 'AJUS_REC':
            case 'BAIXA_REC':
                sessionStorage.setItem('DASHBOARD_NAME', 'rastreioContabil');
                if(origem == 'BAIXA_REC'){
                    sessionStorage.setItem('VRBAXINICIAL', vrdocu);    
                    sessionStorage.setItem('VRBAXFINAL', vrdocu);  
                    sessionStorage.setItem('DTBAIXAREC', datalanc);  
                }else{
                    sessionStorage.setItem('NRNOTAFISCINI', nrdocu);    
                    sessionStorage.setItem('NRNOTAFISCFIN', nrdocu); 
                }
                sessionStorage.setItem('CDEMPRESA', cdempresa); 
                sessionStorage.setItem('NMEMPRESA', nmempresa); 
                sessionStorage.setItem('CDCLIENTE', cdcliente);
                self.openWindow('fin_contaReceber#rec00001_titulos_a_receber');  
                break;
            case 'PAG':
            case 'AJUS_PAG':
            case 'BAIXA_PAG':
                sessionStorage.setItem('DASHBOARD_NAME', 'rastreioContabil');
                if(origem == 'BAIXA_PAG'){
                    sessionStorage.setItem('VRBAIXAPAGINI', vrdocu);    
                    sessionStorage.setItem('VRBAIXAPAGFIN', vrdocu); 
                    sessionStorage.setItem('DTBAIXAPAG', datalanc);
                }else{
                    sessionStorage.setItem('NRNOTAFISCINI', nrdocu);    
                    sessionStorage.setItem('NRNOTAFISCFIN', nrdocu); 
                }
                sessionStorage.setItem('CDEMPRESA', cdempresa);  
                sessionStorage.setItem('NMEMPRESA', nmempresa); 
                sessionStorage.setItem('CDFORNECED', cdforneced);
                sessionStorage.setItem('ORIGEM', origem);
                self.openWindow('fin_contaPagar#pag00001_titulos_a_pagar');  
                break;
            case 'MOVICRED_BCO':
            case 'MOVIDEB_BCO':
            case 'TRANSF_BCO':
                sessionStorage.setItem('DASHBOARD_NAME', 'rastreioContabil');
                sessionStorage.setItem('NRNOTAFISCINI', nrdocu);    
                sessionStorage.setItem('NRNOTAFISCFIN', nrdocu);   
                sessionStorage.setItem('CDEMPRESA', cdempresa);  
                sessionStorage.setItem('CDFORNECED', cdforneced);
                sessionStorage.setItem('CDCLIENTE', cdcliente);
                self.openWindow('fin_movimentacaoBancaria#bco11100_movimentacaoContaCorrente');  
                break;
            case 'DFS':
                sessionStorage.setItem('DASHBOARD_NAME', 'rastreioContabil');
                sessionStorage.setItem('NRNOTAFISCINI', nrdocu);    
                sessionStorage.setItem('NRNOTAFISCFIN', nrdocu);   
                sessionStorage.setItem('CDEMPRESA', cdempresa);  
                sessionStorage.setItem('CDFORNECED', cdforneced);
                sessionStorage.setItem('CDCLIENTE', cdcliente);
                self.openWindow('df_saida#dfs11000_lancamento_saida');  
                break;
            case 'DFE':
                sessionStorage.setItem('DASHBOARD_NAME', 'rastreioContabil');
                sessionStorage.setItem('NRNOTAFISCINI', nrdocu);    
                sessionStorage.setItem('NRNOTAFISCFIN', nrdocu);   
                sessionStorage.setItem('CDEMPRESA', cdempresa);  
                sessionStorage.setItem('CDFORNECED', cdforneced);
                sessionStorage.setItem('CDCLIENTE', cdcliente);
                self.openWindow('df_entrada#dfe11000_lancamento_entrada');  
                break;
            default:
                
        }
            
           
        }).catch(function(erro){
            ScreenService.showMessage(erro.data.error);
        });
	    
	};

    requestModulesMetadata = function () {
        var modulesPackage = window.modulesPackage || "modules";
        return restEngine.requestMetaData(modulesPackage + "#json/modules.json").then(function (response) {
            return response.data;
        });
    };
	
	self.openWindow = function(windowName) {
        requestModulesMetadata().then(function (modules) {
            var subModule = windowName.split('#')[0];
            var module = subModule.split('_')[0];
            var url = window.location.origin + '/' + modules[module].baseUrl + "/#/" + windowName;
            ScreenService.openLink(url, true);
        });
    };

};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb10000_LancamentosContabeis_Controller', Ctb10000_LancamentosContabeis_Controller);
});


// FILE: ./assets/js/controllers/Ctb12000_Manutencao_Lote_Controller.js
var Ctb12000_Manutencao_Lote_Controller = function(ScreenService, templateManager, General, restEngine, Ctb10000_LancamentosContabeis_Service, maskEngine, ZhFilterPreferences, ZHPromise) {

    var self = this;

    // Variável que armazena a máscara de conta contábil.
    var contctblMask = "";
    var utilizaCodigoComercial = false;
    var utilizaRateio = false;
    var lancamentoLoteAdd = false;

    var currencyMask = function(value) {
        // Cria a parametrização da máscara.
        var params = {
            type: "currency",
            params: {
                showSymbol: false,
                precision: 2,
                thousands: ".",
                decimal: ","
            }
        };
        // Aplica a máscara no valor.
        return Util.applyMask(value, params, maskEngine);
    };

    var parseFloatWithDecimals = function(value) {
        return parseFloat(parseFloat(value).toFixed(2));
    };

    self.openFilterManutencaoLote = function(widgetManutencaoLote){
        var rowSetFilter = {};
        rowSetFilter = {
            //'DTVENBOLPAG': {start : '', end : ''},
            'CDEMPRESA': sessionStorage.getItem('CDEMPRESA'),
            'NMEMPRESA': sessionStorage.getItem('NMEMPRESA'),
        };

        ZhFilterPreferences.setOriginalFilter(widgetManutencaoLote.id, rowSetFilter);
        ZhFilterPreferences.openFilterWidget(widgetManutencaoLote, rowSetFilter);
    };

    /**
     * Filtro
     * @param widget
     */
    self.filtroManutencaoLote = function(args){
        var widget = templateManager.container.getWidget("CapaLoteGrid");
		var rowFilter = args.e.preference.FILTER_ROW;

		var filtro = [
			{
				"name": "P_CDEMPRESA",
				"operator": "=",
				"value": rowFilter.CDEMPRESA
			}
        ];
	    widget.dataSourceFilter = filtro;
    };

    self.recarregaDadosLancamentoGrid = function(){
        var widget = templateManager.container.getWidget("DadosLancamentoGrid");
		widget.reload();
    };

    self.controlaActions = function(){
        var capaLote = templateManager.container.getWidget("CapaLoteGrid");
        var dados = templateManager.container.getWidget('DadosLancamentoGrid');
        var folha = templateManager.container.getWidget('FolhaLancamentoGrid');
        var rateio = templateManager.container.getWidget("RateioGrid");

        if(capaLote.currentRow.IDLOTE == "L"){
            //capaLote.getAction('edit').isVisible = false;
            //capaLote.getAction('delete').isVisible = false;

            //folha.getAction('new').isVisible = false;
            //folha.getAction('delete').isVisible = false;

            //dados.getAction('new').isVisible = false;
            //dados.getAction('deleteAll').isVisible = false;
            //dados.getAction('delete').isVisible = false;
            //dados.getAction('edit').isVisible = false;

            //rateio.getAction('adicionarRateio').isVisible = false;
            //rateio.getAction('editarRateio').isVisible = false;
            //rateio.getAction('excluirRateio').isVisible = false;
        }else{
            capaLote.getAction('edit').isVisible = true;
            capaLote.getAction('delete').isVisible = true;

            folha.getAction('new').isVisible = true;
            folha.getAction('delete').isVisible = true;

            dados.getAction('new').isVisible = true;
            dados.getAction('deleteAll').isVisible = false;
            dados.getAction('delete').isVisible = true;
            dados.getAction('edit').isVisible = true;

            rateio.getAction('adicionarRateio').isVisible = true;
            rateio.getAction('editarRateio').isVisible = true;
            rateio.getAction('excluirRateio').isVisible = true;
        }



        templateManager.updateTemplate();
    };

    self.controlaActionsRateio = function(){
        var capaLote = templateManager.container.getWidget("CapaLoteGrid");
        var dados = templateManager.container.getWidget('DadosLancamentoGrid');
        var folha = templateManager.container.getWidget('FolhaLancamentoGrid');
        var rateio = templateManager.container.getWidget("RateioGrid");

        var rateiosEnabled = dados.currentRow.IDCONTCCUS != 'O';

        var usaRateio = self.verificaUsaRateio();

        if(rateiosEnabled && usaRateio){
            //rateio.isVisible = true;
            rateio.getAction('saveLancamento').isVisible = false;
        }else{
            //rateio.isVisible = false;
            rateio.getAction('saveLancamento').isVisible = false;
        }



        templateManager.updateTemplate();
    };

    self.verificaUsaRateio = function(){
        var widgetCapaLote = templateManager.container.getWidget("CapaLoteGrid");
        var cdempresa = widgetCapaLote.currentRow.CDEMPRESA;

        var filter = [
            {
                "name": "CDEMPRESA",
                "operator": "=",
                "value": cdempresa
            }
        ];

        General.callRestEngine('ctb#/contopectbl_empresa', 'FilterData', filter).then(function (response) {
            var contopectbl_empresa = response.dataset.contopectbl_empresa[0];
            var idcontgere = contopectbl_empresa.IDCONTGERE; //rateio
            var idcontcome = contopectbl_empresa.IDCONTCOME; //cod. comercial

            utilizaCodigoComercial = idcontgere == 'S';
            utilizaRateio = idcontcome == 'S';

        });
        return utilizaRateio;
    };

    self.reloadRateio = function(){
        //var dados = templateManager.container.getWidget('DadosLancamentoGrid');
        var rateio = templateManager.container.getWidget("RateioGrid");

        //var currentRow = rateio.currentRow;

        rateio.reload();


    };



    self.abreFolhaLancamentos = function(args){
        var widget = templateManager.container.getWidget("FolhaLancamentoGrid");
		var rowFilter = args.e.preference.FILTER_ROW;

		var filtro = [
			{
				"name": "P_CDEMPRESA",
				"operator": "=",
				"value": rowFilter.CDEMPRESA
			},
			{
				"name": "P_CDLOTE",
				"operator": "=",
				"value": rowFilter.CDLOTE
			}
        ];
	    widget.dataSourceFilter = filtro;
    };

    self.carregaCabecalho = function(){
        var widgetFolhaLancamento = templateManager.container.getWidget('FolhaLancamentoGrid');
        var widgetLancamentoLote = templateManager.container.getWidget('LancamentoLoteGrid');

        widgetLancamentoLote.currentRow.NRDOCULOTE = widgetFolhaLancamento.currentRow.NRDOCULOTE;
        widgetLancamentoLote.currentRow.DTLANCLOTE = widgetFolhaLancamento.currentRow.DTLANCLOTE;


    };

    /**
     * Novo Capa Lote
     */
    self.novoCapaLote = function(widget){
        if(!templateManager.container.getWidget('CapaLoteGrid').appliedFilter.FILTER_ROW.CDEMPRESA) {
            ScreenService.showMessage('Operação bloqueada. Empresa não selecionada no filtro.');
            return;
        }
       /* var widgetCapaLote = templateManager.container.getWidget("CapaLoteGrid");
        if(widgetCapaLote.currentRow.IDLOTE == 'L') {
            ScreenService.showMessage('Operação bloqueada. Lote Liberado.');
            return;
        }
        */
        widget.getField('CDLOTE').readOnly = false;
        this.widgetNewRow(widget).then(function(widget){
            widget.currentRow.CDEMPRESA = templateManager.container.getWidget('CapaLoteGrid').appliedFilter.FILTER_ROW.CDEMPRESA;
            widget.currentRow.NNEMPRESA = templateManager.container.getWidget('CapaLoteGrid').appliedFilter.FILTER_ROW.NMEMPRESA;
            widget.getField('NMEMPRESA').setValue(widget.currentRow.NNEMPRESA);
        });


    };


    self.widgetNewRow = function(widget) {
        var deferred = ZHPromise.defer();

        General.widgetNewRow(widget);

        deferred.resolve(widget);

        return deferred.promise;
    };

    /**
     * Edita Capa Lote
     */
    self.editaCapaLote = function(widget){
        if(!templateManager.container.getWidget('CapaLoteGrid').appliedFilter.FILTER_ROW.CDEMPRESA) {
            ScreenService.showMessage('Operação bloqueada. Empresa não selecionada no filtro.');
            return;
        }
        var widgetCapaLote = templateManager.container.getWidget("CapaLoteGrid");
        if(widgetCapaLote.currentRow.IDLOTE == 'L') {
            ScreenService.showMessage('Operação bloqueada. Lote Liberado.');
            return;
        }

        widget.getField('CDLOTE').readOnly = true;
        General.widgetEdit(widget);

    };

    /**
     * Deleta Capa Lote
     */
    self.deletaCapaLote = function(widget){
        if(!templateManager.container.getWidget('CapaLoteGrid').appliedFilter.FILTER_ROW.CDEMPRESA) {
            ScreenService.showMessage('Operação bloqueada. Empresa não selecionada no filtro.');
            return;
        }
        var widgetCapaLote = templateManager.container.getWidget("CapaLoteGrid");
        if(widgetCapaLote.currentRow.IDLOTE == 'L') {
            ScreenService.showMessage('Operação bloqueada. Lote Liberado.');
            return;
        }

        General.deleteCrud(widget);

    };

    /**
     * Salva Capa Lote
     */
    self.salvaCapaLote = function(widget){
        if(!templateManager.container.getWidget('CapaLoteGrid').appliedFilter.FILTER_ROW.CDEMPRESA) {
            ScreenService.showMessage('Operação bloqueada. Empresa não selecionada no filtro.');
            return;
        }

        General.widgetSave(widget).then(function(){
            ScreenService.showMessage('Registro salvo com sucesso.', 'checked');
                widget.reload();
        }).catch(function(erro){
            ScreenService.showMessage(erro.data.error);
        });

         //General.widgetSave(widget);

    };

    self.abreLancamentoLoteVisu = function(){
        var dados = templateManager.container.getWidget('DadosLancamentoGrid');
        var folha = templateManager.container.getWidget('FolhaLancamentoGrid');
        var cabecalho = templateManager.container.getWidget('LancamentoLoteGrid');


        cabecalho.currentRow.NRDOCULOTE = folha.currentRow.NRDOCULOTE;
        cabecalho.currentRow.DTLANCLOTE = folha.currentRow.DTLANCLOTE;

        cabecalho.getField('NRDOCULOTE').readOnly = true;
        cabecalho.getField('DTLANCLOTE').readOnly = true;

        dados.dataSourceFilter.forEach(function(filtro){
            if (filtro.name == 'P_NRDOCULOTE'){
                filtro.value = dados.getParent().currentRow.NRDOCULOTE;
            }else if (filtro.name == 'P_DTLANCLOTE') {
                filtro.value = dados.getParent().currentRow.DTLANCLOTE;
            }
        });

        lancamentoLoteAdd = false;

        ScreenService.openSwipe(cabecalho);
        //widgetLancamentoLote.newRow();
        dados.activate();
        dados.reload();

    };

    /**
     * Abre Lancamento Lote
     */
    self.abreLancamentoLoteAdd = function(){
        var widgetCapaLote = templateManager.container.getWidget("CapaLoteGrid");
        if(widgetCapaLote.currentRow.IDLOTE == 'L') {
            ScreenService.showMessage('Operação bloqueada. Lote Liberado.');
            return;
        }
        var dados = templateManager.container.getWidget('DadosLancamentoGrid');
        var folha = templateManager.container.getWidget('FolhaLancamentoGrid');
        var cabecalho = templateManager.container.getWidget('LancamentoLoteGrid');


        cabecalho.currentRow.NRDOCULOTE = "";
        cabecalho.currentRow.DTLANCLOTE = "";

        cabecalho.getField('NRDOCULOTE').readOnly = false;
        cabecalho.getField('DTLANCLOTE').readOnly = false;

        dados.dataSourceFilter.forEach(function(filtro){
            if (filtro.name == 'P_NRDOCULOTE'){
                filtro.value = "";
            }else if (filtro.name == 'P_DTLANCLOTE') {
                filtro.value = "";
            }
        });

        dados.data = [];

        lancamentoLoteAdd = true;

        ScreenService.openSwipe(cabecalho);
        //widgetLancamentoLote.newRow();
        dados.activate();
        dados.reload();

    };

    /**
     * Abre Lancamento Dados Lote
     */
    self.abreLancamentoDadosLote = function(){
        var widgetCapaLote = templateManager.container.getWidget("CapaLoteGrid");
        if(widgetCapaLote.currentRow.IDLOTE == 'L') {
            ScreenService.showMessage('Operação bloqueada. Lote Liberado.');
            return;
        }

        var cabecalho = templateManager.container.getWidget('LancamentoLoteGrid');
        var rateioWidget = templateManager.container.getWidget("RateioGrid");
        //rateioWidget.getAction('saveLancamento').isVisible = true;
        rateioWidget.isVisible = false;
        if(cabecalho.currentRow.NRDOCULOTE != "" && cabecalho.currentRow.DTLANCLOTE != ""){
            //var widgetCapaLote = templateManager.container.getWidget("CapaLoteGrid");
            var widgetLancamentoLote = templateManager.container.getWidget('DadosLancamentoGrid');
            var qtdlancamentos = widgetLancamentoLote.dataSource.data.length;
            widgetLancamentoLote.newRow();
            widgetLancamentoLote.currentRow.NRSEQLANLOTE = parseInt(qtdlancamentos + 1);
            //console.log(widgetLancamentoLote.currentRow.NRSEQLANLOTE = parseInt(qtdlancamentos + 1));
            //widgetAjusteTituloBaixa.getField('NRORG').setValue(widgetTitulosBaixa.currentRow.NRORG);
            //widgetLancamentoLote.activate();
            //toggleLancamentoComercialFields.call(this, widgetLancamentoLote);
            var cdempresa = widgetCapaLote.currentRow.CDEMPRESA;

            var filter = [
                {
                    "name": "CDEMPRESA",
                    "operator": "=",
                    "value": cdempresa
                }
            ];

            General.callRestEngine('ctb#/contopectbl_empresa', 'FilterData', filter).then(function (response) {
                var contopectbl_empresa = response.dataset.contopectbl_empresa[0];
                var idcontgere = contopectbl_empresa.IDCONTGERE; //rateio
                var idcontcome = contopectbl_empresa.IDCONTCOME; //cod. comercial

                utilizaCodigoComercial = idcontgere == 'S';
                utilizaRateio = idcontcome == 'S';

                //rateioWidget.isVisible = utilizaRateio;

            });
        }else{
            ScreenService.showMessage('Operação bloqueada. Cabeçalho não preenchido.');
        }
    };

    self.excluirDadoLancamento = function(args){
        var widgetCapaLote = templateManager.container.getWidget("CapaLoteGrid");
        if(widgetCapaLote.currentRow.IDLOTE == 'L') {
            ScreenService.showMessage('Operação bloqueada. Lote Liberado.');
            return;
        }
        //var dadosLancamentoWidget = templateManager.container.getWidget('DadosLancamentoGrid');
        var widget = args.owner.widget;
        var folha = templateManager.container.getWidget('FolhaLancamentoGrid');

        //var widgetTitulosAReceber = templateManager.container.getWidget('TitulosAReceberGrid');

        var row = widget.currentRow;

            if (!widget.currentRow.__createdLocal) {

                ScreenService.confirmMessage('Deseja realmente excluir?', 'question', function () {


                    General.callRestEngine('ctb#/dadosLancamento/delete', 'Row', row).then(function () {
                        ScreenService.showMessage('Registro excluido com sucesso.');
                        ScreenService.closeSwipe();

                        widget.reload();
                        folha.reload();
                    }).catch(function(erro){
                        ScreenService.showMessage(erro.data.error);
                    });

                });
            } else General.backOrCancel(args);
    };

    self.excluirTodosDadoLancamento = function(args){
        var widgetCapaLote = templateManager.container.getWidget("CapaLoteGrid");
        if(widgetCapaLote.currentRow.IDLOTE == 'L') {
            ScreenService.showMessage('Operação bloqueada. Lote Liberado.');
            return;
        }
        //var dadosLancamentoWidget = templateManager.container.getWidget('DadosLancamentoGrid');
        var widget = args.owner.widget;
        var folha = templateManager.container.getWidget('FolhaLancamentoGrid');

        //var widgetTitulosAReceber = templateManager.container.getWidget('TitulosAReceberGrid');

        var rows = widget.dataSource.data;
        if (!widget.currentRow.__createdLocal) {
            ScreenService.confirmMessage('Deseja realmente excluir?', 'question', function () {

                General.callRestEngine('ctb#/todosdadosLancamento/delete', 'Row', rows[0]).then(function () {

                    ScreenService.showMessage('Registro excluido com sucesso.');
                    ScreenService.closeSwipe();
                    widget.reload();
                    folha.reload();
                }).catch(function(erro){
                    ScreenService.showMessage(erro.data.error);
                });
            });
        } else General.backOrCancel(args);
    };


    self.setDescriptionValuesCdcontcome = function(widget) {
        //var currentRow = widget.currentRow;

        // Seta a propriedade como nula caso não exista.
        //currentRow.CDLLOTCOME = null;

        // Seta os códigos nos fields selects para a exibição, caso algum esteja visível.
        /*currentRow.CDREDUCONT = currentRow.CDLLOTCOME;
        currentRow.CDCLIENTE = currentRow.CDLLOTCOME;
        currentRow.CDFORNECED = currentRow.CDLLOTCOME;*/
    };

    self.filialRateioOnChange = function(rateiosWidget, editRateio) {
        var centcustField = rateiosWidget.getField("CDCENTCUST");
        var cdfilial = rateiosWidget.currentRow.CDFILIAL;

        // Altera a propriedade readOnly do field, sendo false se houver CDFILIAL setada.
        centcustField.readOnly = !cdfilial;

        // Verifica se a função foi chamada pela função de editar o rateio.
        if (!editRateio) {
            // Reseta quaisquer valores de centros de custo selecionados.
            rateiosWidget.currentRow.CDCENTCUST = null;
            rateiosWidget.currentRow.NMCENTCUST = null;
        }
    };

    self.novoRateio = function(rateiosWidget) {
        var widgetCapaLote = templateManager.container.getWidget("CapaLoteGrid");
        if(widgetCapaLote.currentRow.IDLOTE == 'L') {
            ScreenService.showMessage('Operação bloqueada. Lote Liberado.');
            return;
        }
        // Cria o backup da partida em questão.
        //createPartidaBackup();
        var widgetLancamentoLote  = templateManager.container.getWidget('LancamentoLoteGrid');
        var widgetDadoLancamento = templateManager.container.getWidget('DadosLancamentoGrid');
        rateiosWidget.newRow();
        rateiosWidget.applyDefaultValue();
        rateiosWidget.currentRow.DTCOMPCUSTO = widgetLancamentoLote.currentRow.DTLANCLOTE;
        var valorRateio = 0;
        rateiosWidget.dataSource.data.forEach(function(rateio) {
            if(rateio.VRLANCLOTE != ""){
                valorRateio = valorRateio + parseFloat(rateio.VRLANCLOTE);
            }
        });

        if(rateiosWidget.dataSource.data[0].VRLANCLOTE == ""){
            rateiosWidget.currentRow.VRLANCLOTE = widgetDadoLancamento.currentRow.VRLANCLOTE;
        }else{
            rateiosWidget.currentRow.VRLANCLOTE = widgetDadoLancamento.currentRow.VRLANCLOTE - valorRateio;
        }
        // Propriedade para indicar que o rateio foi inserida pelo usuário.
        //rateiosWidget.currentRow.rateioNovo = true;

        // Chama a função para resetar a propriedade readOnly do campo de Centro de Custo.
        //this.filialRateioOnChange(rateiosWidget);
    };

    self.editaRateio = function(widget){
        var widgetCapaLote = templateManager.container.getWidget("CapaLoteGrid");
        if(widgetCapaLote.currentRow.IDLOTE == 'L') {
            ScreenService.showMessage('Operação bloqueada. Lote Liberado.');
            return;
        }
        General.widgetEdit(widget);
    };

    this.salvaRateio = function(rateiosWidget) {
        // Verifica se todos os campos obrigatórios foram preenchidos.
        if (rateiosWidget.isValid()) {
            var currentRateio =  rateiosWidget.currentRow;
            // Retorna um array com quaisquer rateios que tenham sido cadastrados
            // com a mesma unidade e centro de custo do rateio atual.
            var sameFilialCentcust = rateiosWidget.dataSource.data.filter(function(rateio) {
                return rateio.CDFILIAL == currentRateio.CDFILIAL && rateio.CDCENTCUST == currentRateio.CDCENTCUST;
            });

            // Como o rateio atual vai estar presente no dataSource.data, é necessário
            // verificar se há um registro além do atual com a mesma unidade e centro
            // de custo do rateio atual, além dele mesmo.
            if (sameFilialCentcust.length > 1) {
                ScreenService.showMessage("Rateio já informado para a unidade e centro de custo informados.");
            }
            // Se não houver, salva o rateio atual normalmente.
            else {
                // Seta a propriedade de controle de rateio alterado para true.
                currentRateio.rateioAlterado = true;

                // Chama a função responsável por indicar que houve alteração na partida.
                //setPartidaAlterada();


                // Muda o modo de exibição da widget, salvando rateio dado alterado.
                rateiosWidget.view();
                ScreenService.closeSwipe();
                //ScreenService.closePopup();
                //ScreenService.goBack();
                //lancamentosGeraisWidget.reload();
                //self.goBackToMain();
            }
            rateiosWidget.getAction('saveLancamento').isVisible = true;
        }
    };

    self.cancelRateio = function(args){
        General.backOrCancel(args);
    };

    /**
     * Salva Lancamento Dados Lote
     */
    self.salvaLancamentoDadosLote = function(args){
        var widgetDadoLancamento = templateManager.container.getWidget('DadosLancamentoGrid');
        var rateiosWidget = templateManager.container.getWidget("RateioGrid");
        if(widgetDadoLancamento.isValid()) {
            var widget = widgetDadoLancamento;

             var currentRow = widget.currentRow;

            // Verifica se a conta contábil é de um tipo gerencial, controlando rateios.
            var rateiosEnabled = currentRow.IDCONTCCUS == 'R' || currentRow.IDCONTCCUS == 'G';


            if (rateiosEnabled && utilizaRateio) {


                if (rateiosWidget.dataSource.data.length == 0) {
                    ScreenService.showMessage("Rateio deve ser informado para as contas do tipo Gerencial ou Oficial/Gerencial.");
                    rateiosWidget.activate();
                    return;
                }
                else {

                    var valorRateio = 0;

                    rateiosWidget.dataSource.data.forEach(function(rateio) {

                        rateio.VRLANCLOTE = parseFloatWithDecimals(rateio.VRLANCLOTE);

                        valorRateio += rateio.VRLANCLOTE;

                        // Seta o valor real do rateio de acordo com o identificador do tipo da partida.
                        rateio.VRLANCCUST = currentRow.IDDEBCRE == 'CR' ? rateio.VRLANCLOTE : -rateio.VRLANCLOTE;
                    });

                    if (valorRateio != currentRow.VRLANCLOTE) {
                        var valorDiferenca = currencyMask(currentRow.VRLANCLOTE - valorRateio);
                        ScreenService.showMessage("A soma dos rateios deve ser igual ao valor da partida.<br><br>Diferença: " + valorDiferenca);
                        return;
                    }
                }


            }



            rateiosWidget.getAction('saveLancamento').isVisible = false;
            self.habilitaFinalizacaoLancamentoDadosLote(widget);

            widget.view();
            ScreenService.goBack();
        }
    };

    self.voltarRateio = function(){
        var rateio = templateManager.container.getWidget('RateioGrid');
        var dados = templateManager.container.getWidget('DadosLancamentoGrid');
        rateio.getAction('saveLancamento').isVisible = false;
         ScreenService.goBack();
         dados.dataSource.data.pop();
         dados.currentRow = {};
    };

    self.habilitaFinalizacaoLancamentoDadosLote = function(widget){
         widget.getAction('finalizarLancamentoDadosLote').isVisible = true;
         widget.getAction('cancelarLancamentoDadosLote').isVisible = true;
         widget.getAction('back_list').isVisible = false;
         widget.parent.editing = true;
    };

    self.desabilitaFinalizacaoLancamentoDadosLote = function(args){
        args.owner.getAction('finalizarLancamentoDadosLote').isVisible = false;
        args.owner.getAction('cancelarLancamentoDadosLote').isVisible = false;
        args.owner.getAction('back_list').isVisible = true;
        args.owner.parent.editing = false;

        var widgets = [
            templateManager.container.getWidget('TitulosAPagarGrid'),
            templateManager.container.getWidget('AjusteGrid'),
            templateManager.container.getWidget('DocumentosGrid'),
            templateManager.container.getWidget('CnabTabbed'),
            templateManager.container.getWidget('ContaDocumentosGrid'),
            templateManager.container.getWidget('BaixaTituloForm')
        ];

        General.changeWidgetAcessibility(widgets, true);
        templateManager.updateTemplate();
    };

    self.finalizaLancamentoDadosLote = function(widget){
        var widgetFolhaLancamento = templateManager.container.getWidget('FolhaLancamentoGrid');
        var widgetLancamentoLote  = templateManager.container.getWidget('LancamentoLoteGrid');
        var widgetDadosLancamento = templateManager.container.getWidget('DadosLancamentoGrid');
        var widgetRateioGrid      = templateManager.container.getWidget('RateioGrid');

        var dataSet = [
            widgetLancamentoLote.currentRow,
            widgetDadosLancamento.dataSource.data,
            widgetRateioGrid.dataSource.data,
            widgetFolhaLancamento.dataSource.data,
            [lancamentoLoteAdd]
        ];

        if(widgetDadosLancamento.dataSource.data.length > 0){
            General.callRestEngine('ctb#/finalizaLancamentoDadosLote/save', 'DataSet', dataSet).then(function () {
                ScreenService.showMessage('Registro salvo com sucesso.');
                ScreenService.closeSwipe();

                widgetFolhaLancamento.reload();
            }).catch(function(erro){
                ScreenService.showMessage(erro.data.error);
            });
        }else{
            ScreenService.showMessage("Não há dados a serem salvos.");
        }
    };

    self.cancelaLancamentoDadosLote = function(args){
        General.backOrCancel(args).then(function(){
            //var widget = args.owner.widget;
            //if(widget.currentRow.NRPARCBOLPAG == '01' && widget.dataSource.data.length == 1)
               // widget.reload();
        });
    };

    self.cancelaLancamento = function(args){
        General.backOrCancel(args);
    };


    /**
     * Seta Data Souce Stripe
     * @param widget
     */
    self.setStripeData = function(widget) {
        var currentRow = widget.appliedFilter.FILTER_ROW;
        //currentRow.DTVENBOLPAG = (currentRow.DTVENBOLPAG) ? currentRow.DTVENBOLPAG : {'start': '', 'end': ''};
        var stripeWidget = templateManager.container.getWidget("stripe");

        stripeWidget.currentRow = {};
        stripeWidget.currentRow.NMEMPRESA   = currentRow.CDEMPRESA + ' - ' + currentRow.NMEMPRESA;
       // stripeWidget.currentRow.DTVENBOLPAG = 'De ' + currentRow.DTVENBOLPAG.start + ' até ' + currentRow.DTVENBOLPAG.end;
    };

    self.getContctblMask = function() {
        return contctblMask;
    };

    self.setContctblMask = function() {
        General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []).then(function(response) {
            var paramgeral = response.dataset.paramgeral[0];
            contctblMask = paramgeral.CDPICTCCTB;
        });
    };

    self.contaContabilOnChange = function(partidaWidget) {
        toggleRateiosTabEnabled(partidaWidget);
        // Reseta o valor de conta comercial.
        partidaWidget.currentRow.CDCONTCOME = null;
        // Chama a função com o escopo atual.
        toggleLancamentoComercialFields.call(this, partidaWidget);
    };

    var toggleRateiosTabEnabled = function(partidasWidget) {
        var rateiosTabbedWidget = templateManager.container.getWidget("RateioGrid");
        // Verifica se a conta contábil da partida é de um tipo gerencial.
        var idcontccus = partidasWidget.currentRow.IDCONTCCUS;

        // Altera a possibilidade de selecionar a widget de rateios de acordo com o parâmetro.
        rateiosTabbedWidget.enabled = idcontccus == 'R' || idcontccus == 'G';
    };

    var toggleLancamentoComercialFields = function(partidaWidget) {
        //var currentRow = partidaWidget.currentRow;
        //var idllotcome = currentRow.IDLLOTCOME;

        // Verifica qual campo ficará visível.
        // Considera sempre se a empresa utiliza código comercial.
       /* var bancoIsVisible = idllotcome == 'B';
        var clienteIsVisible = idllotcome == 'C';
        var fornecedorIsVisible = idllotcome == 'F';
        var cdcontcomeIsVisible = !idllotcome;

        partidaWidget.getField("CDREDUCONT").showOnForm = bancoIsVisible;
        partidaWidget.getField("CDREDUCONT").validations = bancoIsVisible ? {"required": true} : {};

        partidaWidget.getField("CDCLIENTE").showOnForm = clienteIsVisible;
        partidaWidget.getField("CDCLIENTE").validations = clienteIsVisible ? {"required": true} : {};

        partidaWidget.getField("CDFORNECED").showOnForm = fornecedorIsVisible;
        partidaWidget.getField("CDFORNECED").validations = fornecedorIsVisible ? {"required": true} : {};

        partidaWidget.getField("CDLLOTCOME").showOnForm = cdcontcomeIsVisible;

        partidaWidget.redraw();
        templateManager.updateTemplate();

        this.setDescriptionValuesCdcontcome(partidaWidget);*/
    };

    self.tipoOnChange = function(widget) {
        var rateioWidget = templateManager.container.getWidget("RateioGrid");
        var currentRow = widget.currentRow;
        var idllotcome = currentRow.IDLLOTCOME;

        var rateiosEnabled = currentRow.IDCONTCCUS != 'O';

        // Verifica qual campo ficará visível.   IDLLOTCOME
        // Considera sempre se a empresa utiliza código comercial.

        var bancoIsVisible = idllotcome == 'B' && utilizaCodigoComercial;
        var clienteIsVisible = idllotcome == 'C' && utilizaCodigoComercial;
        var fornecedorIsVisible = idllotcome == 'F' && utilizaCodigoComercial;
        var cdcontcomeIsVisible = !idllotcome && utilizaCodigoComercial;

        widget.getField("NMBANCO").showOnForm = bancoIsVisible;
        widget.getField("NMBANCO").validations = bancoIsVisible ? {"required": true} : {};
        widget.getField("NMBANCO").setValue("");

        widget.getField("NMRAZSOCCLIE").showOnForm = clienteIsVisible;
        widget.getField("NMRAZSOCCLIE").validations = clienteIsVisible ? {"required": true} : {};
        widget.getField("NMRAZSOCCLIE").setValue("");

        widget.getField("NMRAZSOCFORN").showOnForm = fornecedorIsVisible;
        widget.getField("NMRAZSOCFORN").validations = fornecedorIsVisible ? {"required": true} : {};
        widget.getField("NMRAZSOCFORN").setValue("");

        widget.getField("CDLLOTCOME").showOnForm = cdcontcomeIsVisible;
        widget.getField("CDLLOTCOME").setValue("");
        widget.getField("CDLLOTCOME").readOnly = idllotcome == "";

        // Muda a possibilidade de alterar esses campos de acordo com a parametrização.
        widget.getField("NMBANCO").readOnly = !utilizaCodigoComercial;
        widget.getField("NMRAZSOCCLIE").readOnly = !utilizaCodigoComercial;
        widget.getField("NMRAZSOCFORN").readOnly = !utilizaCodigoComercial;

        var usaRateio = self.verificaUsaRateio();

        if(!utilizaCodigoComercial || idllotcome == null)
            widget.getField("CDLLOTCOME").readOnly = true;

        if(usaRateio && rateiosEnabled){
            rateioWidget.isVisible = true;
            //General.changeWidgetAcessibility(rateioWidget, true);
        }else{
            rateioWidget.isVisible = false;
            //General.changeWidgetAcessibility(rateioWidget, false);
        }

        widget.redraw();
        templateManager.updateTemplate();

        //this.setDescriptionValuesCdcontcome(widget);
    };

    self.conferirLote = function(widget){
        var checkedrows = widget.getCheckedRows();

       var dataSet = widget.getCheckedRows().filter(function(lotes){
            return (lotes.IDLOTE == 'D');
        });
       if(checkedrows.length > 0){
           General.callRestEngine('ctb#/conferirLote', 'DataSet', dataSet).then(function (resul) {
               if(resul.dataset.resul[0] == false){
                   ScreenService.showMessage('Lotes conferidos, erros foram encontrados.');
               }else{
                   ScreenService.showMessage('Lotes conferidos com sucesso.');
               }
               widget.dataSource.unSelectAll();
               widget.reload();
           }).catch(function(erro){
               ScreenService.showMessage(erro.data.error);
           });
       }else{
           ScreenService.showMessage("Não há dados.");
       }
    };

    self.liberarLote = function(widget){
        var checkedrows = widget.getCheckedRows();
        var dataSet = widget.getCheckedRows().filter(function(lotes){
            return (lotes.IDLOTE == 'C' && lotes.QTERROLOTE == 0);
        });
       if(checkedrows.length > 0){
           General.callRestEngine('ctb#/liberarLote', 'DataSet', dataSet).then(function () {
               ScreenService.showMessage('Lotes liberados com sucesso.');
               widget.dataSource.unSelectAll();
               widget.reload();
           }).catch(function(erro){
               ScreenService.showMessage(erro.data.error);
           });
       }else{
           ScreenService.showMessage("Não há dados.");
       }
    };

    self.reverterLote = function(widget){
        var checkedrows = widget.getCheckedRows();
        var dataSet = widget.getCheckedRows().filter(function(lotes){
            return (lotes.IDLOTE == 'L');
        });
       if(checkedrows.length > 0){
           General.callRestEngine('ctb#/reverterLote', 'DataSet', dataSet).then(function () {
               ScreenService.showMessage('Lotes Revertidos com sucesso.');
               widget.dataSource.unSelectAll();
               widget.reload();
           }).catch(function(erro){
               ScreenService.showMessage(erro.data.error);
           });
       }else{
           ScreenService.showMessage("Não há dados.");
       }
    };

    self.habilitaActionsCapaLote = function(){
        var widget = templateManager.container.getWidget('CapaLoteGrid');
        var checkedrows = widget.getCheckedRows();
        var cont_assoc = 0;

        var actions = {
            conferenciaLote : false,
            liberacaoLote : false,
            reversaoLote : false
        };

        if(checkedrows.length > 0) {
            for (var i in checkedrows){

                actions = self.validaActionsSituacaoCapaLote(checkedrows[i], actions);

            }
        }

        widget.getAction('conferenciaLote').isVisible   = actions.conferenciaLote;
        widget.getAction('liberacaoLote').isVisible     = actions.liberacaoLote;
        widget.getAction('reversaoLote').isVisible      = actions.reversaoLote;
    };

    self.validaActionsSituacaoCapaLote = function(checkedrows, actions){
        if (checkedrows.IDLOTE == 'D') {
            actions.conferenciaLote = true;
        }else if (checkedrows.IDLOTE == 'C'){
            if(checkedrows.QTERROLOTE == 0)
                actions.liberacaoLote = true;
        }else if (checkedrows.IDLOTE == 'L'){
            actions.reversaoLote   = true;
        }

        return actions;
    };

    self.habilitaAbaErros = function(){
        var widgetCapaLoteGrid = templateManager.container.getWidget('CapaLoteGrid');
        var widgetErros = templateManager.container.getWidget('widgetErros');
        if(widgetCapaLoteGrid.currentRow.QTERROLOTE > 0){
            widgetErros.isVisible = true;
        }else{
            widgetErros.isVisible = false;
        }
    };


};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb12000_Manutencao_Lote_Controller', Ctb12000_Manutencao_Lote_Controller);
});


// FILE: ./assets/js/controllers/Ctb14000_EncerramentoExercicio_Controller.js
var Ctb14000_EncerramentoExercicio_Controller = function(ScreenService, templateManager, General, Ctb14000_EncerramentoExercicio_Service){
    
    var self = this;
    
    var contctblMask = "";
    
    this.abreSwipeContas = function(args){
          var widgetPai = args.owner.widget;
          try{
              if (widgetPai.isValid()){
                  var widgetContasResultado = widgetPai.container.getWidget('widgetContas');
                  ScreenService.openSwipe(widgetContasResultado);
                  this.setFilterWidgetContas(widgetContasResultado);
                  this.setDataSourceName(widgetContasResultado);
              }
          }finally{
              ScreenService.closePopup(); 
          }
     };
     
     this.setMask = function(args){
         Ctb14000_EncerramentoExercicio_Service.getMask().then(function(success){
            var stMask = success.dataset.dataSetMask.CDPICTCCTB;
            var container = templateManager.container; 
            var widgetPai = container.getWidget('widgetEncerramento');
            
            /* Atualiza a máscara da tela principal */
            widgetPai.getField('NMCONTCTBL').fields[0].mask.params.mask = stMask;
            
            /* Atualiza a máscara do grid com os saldos */
            var widgetContas = container.getWidget('widgetContas');
            widgetContas.getField('CDCONTCTBL').mask.params.mask = stMask;
            contctblMask = stMask;
            
            widgetContas.getField('CDCONTCTBL').fields[1].mask.params.mask = stMask;
         });
     };
     
     this.getCurrentField = function(widgetName, fieldName) {
          return General.getFieldValue(fieldName,widgetName);
     };
     
     this.atualizaData = function(args){
         var widget = args.owner.field.widget;
         var dtEncerramento = this.getDataEncerramento();
         widget.currentRow.DTENCERRAMENTO = dtEncerramento; 
     };
     
    this.getDataEncerramento = function(){
        var dtEncerramento = General.getFieldValue('DTENCERRAMENTO', 'widgetEncerramento');
        if (dtEncerramento) {
            dtEncerramento = moment(dtEncerramento, "DD/MM/YYYY");
            dtEncerramento = dtEncerramento.endOf("month").format("DD/MM/YYYY");
        }
        return dtEncerramento;
    };
     
     this.setFilterWidgetContas = function(widget) {
         if (General.getFieldValue('IDTIPOSALDO', 'widgetEncerramento') == 'F'){
            widget.dataSourceFilter = [
               {
                    name: "P_CDEMPRESA",
                    operator: "=",
                    value: General.getFieldValue('CDEMPRESA', 'widgetEncerramento')
               },
               {
                    name: "P_DTSALDEMPR",
                    operator: "=",
                    value: this.getDataEncerramento()
               },
               {
                    name: "P_CDCONTDESTINO",
                    operator: "=",
                    value: General.getFieldValue('CDCONTCTBL', 'widgetEncerramento')
               }
         ];
         }else{
             widget.dataSourceFilter = [
               {
                    name: "P_CDEMPRESA",
                    operator: "=",
                    value: General.getFieldValue('CDEMPRESA', 'widgetEncerramento')
               },
               {
                    name: "P_DTSALDOSOCIET",
                    operator: "=",
                    value: this.getDataEncerramento()
               },
               {
                    name: "P_CDCONTDESTINO",
                    operator: "=",
                    value: General.getFieldValue('CDCONTCTBL', 'widgetEncerramento')
               }
         ];
         }
     };
     
     this.setDataSourceName = function(widget){
        if (General.getFieldValue('IDTIPOSALDO', 'widgetEncerramento') == 'F'){
            widget.dataSource.name = 'ctb#/saldempr_contctbl';
        }else{
            widget.dataSource.name = 'ctb#/saldosociet_contctbl';
        }
     };
     
     this.verificaCdLote = function(args){
         var widget = args.owner.widget;
         if (widget.isValid()){
             widget.currentRow.DTENCERRAMENTO = this.getDataEncerramento();
             Ctb14000_EncerramentoExercicio_Service.verificaCdLote(widget.currentRow).then(function(geraLote){
                Ctb14000_EncerramentoExercicio_Service.geraLote(widget.currentRow).then(function(succcess){
                    ScreenService.showMessage("Lote de encerramento gerado com sucesso!");
                });
             })
            .catch(function(erroLoteCadasrado){
                var errorMessage = 'Timeout';
                if (erroLoteCadasrado.data) {
                    errorMessage = erroLoteCadasrado.data.error;
                }
                ScreenService.showMessage(errorMessage);
            })
            .finally(function() {
                ScreenService.closePopup();
            }); 
         }
     };
     
     this.campoDefault = function(args){
        var widget = args.owner;
        widget.applyDefaultValue();
     };
     
    self.novaContaResultado = function() {
        var widgetContas = templateManager.container.getWidget("widgetContas");
        
        General.widgetNewRow(widgetContas);

    };
    
    self.salvaContaResultado = function(args){
        var widgetContas = templateManager.container.getWidget("widgetContas");
        var widgetEncerramento = templateManager.container.getWidget("widgetEncerramento");
        
        var dataSet = [
            widgetContas.currentRow,
            widgetEncerramento.currentRow
        ];
        
        General.backOrCancel(args);
        
        General.callRestEngine('ctb#/novaContaResultado/save', 'DataSet', dataSet).then(function (result) {
            
            var contas = result.dataset.saveContResul;
            var i = 0;
            var arrayContas = [];
            var verific = false;
            if(widgetContas.dataSource.data.length > 0){
                widgetContas.dataSource.data.forEach(function(conta) {
                    arrayContas.push(conta.CDCONTCTBL);
                });
            }else{
                verific = true;
            }
            
            contas.forEach(function(conta) {
                if(verific || !arrayContas.includes(conta.CDCONTCTBL)){
                    widgetContas.dataSource.data.push(conta);
                    i++;
                }
            });
            ScreenService.showMessage('Registro salvo com sucesso.');
            ScreenService.closeSwipe();
            
            self.controlaActions(true);
            
            
        }).catch(function(erro){
            ScreenService.showMessage(erro.data.error);
        });
        widgetEncerramento.reload();
        widgetContas.reload();
        templateManager.updateTemplate();
    };
    
    self.excluirContaResultado = function(args){
        var widgetContas = templateManager.container.getWidget("widgetContas");
        //var widgetEncerramento = templateManager.container.getWidget("widgetEncerramento");
        
        var row = widgetContas.currentRow;
        
        ScreenService.confirmMessage('Deseja realmente excluir?', 'question', function () {
            var i = row.__index;
            delete widgetContas.dataSource.data[i];
            widgetContas.dataSource.data.length = widgetContas.dataSource.data.length -1;
            ScreenService.closeSwipe();
            if(widgetContas.dataSource.data.length == 0){
                self.controlaActions(false);
            }
        });
        widgetContas.reload();
        templateManager.updateTemplate();
    };
    
    self.finalizaContaResultado = function(args){
        var widgetContas = templateManager.container.getWidget("widgetContas");
        var widgetEncerramento = templateManager.container.getWidget("widgetEncerramento");
        
        var dataSet = [
            widgetContas.dataSource.data,
            widgetEncerramento.currentRow
        ];
        
        General.callRestEngine('ctb#/finalizaContaResultado/save', 'DataSet', dataSet).then(function () {
            
            //var contas = resul.dataset.saveContResul;
            
            ScreenService.showMessage('Registro finalizado com sucesso.');
            ScreenService.closeSwipe();
            
            self.controlaActions(false);
            delete widgetContas.dataSource.data;
            
        }).catch(function(erro){
            ScreenService.showMessage(erro.data.error);
        });
    };
    
    self.voltarContas = function(){
         ScreenService.goBack();
    };
    
    self.cancelContaResultado = function(args){
        General.backOrCancel(args);
    };
    
    self.controlaActions = function(modo){
        var widgetContas = templateManager.container.getWidget("widgetContas");
        if(modo){
            widgetContas.getAction('saveContaResultado').isVisible = true;
        }else{
            widgetContas.getAction('saveContaResultado').isVisible = false;
        }

        templateManager.updateTemplate();
    };
    
    this.getContctblMask = function() {
    return contctblMask;
  };
    
};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ctb14000_EncerramentoExercicio_Controller', Ctb14000_EncerramentoExercicio_Controller);
});

// FILE: ./assets/js/controllers/Ctb17000_RelatorioRazaoContrapartida_Controller.js
var ctb17000_RelatorioRazaoContrapartida_Controller = function(ScreenService, General) {
    
    var self = this;
    
    self.filtroRazaoContrapartida = function(widget, preference){
        var currentRowFiltro = preference.FILTER_ROW;
        
        currentRowFiltro.DTINICIAL = currentRowFiltro.DTPERIODO.start;
        currentRowFiltro.DTFINAL   = currentRowFiltro.DTPERIODO.end;

        General.callRestEngine('ctb#/geraRazaoOficial', 'Row', currentRowFiltro).then(
            function (result) {
                var nrrazao = result.dataset.nrrazao[0];
                
                widget.dataSourceFilter = [
                    {
                        "name": "P_NRRAZAO",
                        "operator": "=",
                        "value": nrrazao
                    },
                    {
                        "name": "P_DTINICIAL",
                        "operator": "=",
                        "value": currentRowFiltro.DTINICIAL
                    }
                ];
                
                widget.reload();
            }).catch(function(erro){
                ScreenService.showMessage(erro.data.error);
            }
        );
    };
    
};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb17000_RelatorioRazaoContrapartida_Controller', ctb17000_RelatorioRazaoContrapartida_Controller);
});


// FILE: ./assets/js/controllers/Ctb23000_BalanceteGerencial_Controller.js
var Ctb23000_BalanceteGerencial_Controller = function(ScreenService, templateManager, metaDataFactory, Messages_Contabil, restEngine, General, ZhFilterPreferences){
    
    var self = this;
    
    var mensagens = {
        empresasDiferem: 'Todas as filiais selecionadas devem estar relacionadas a mesma empresa!',
        valorInvalido: 'Conta Contábil Inicial deve ser menor que a Conta Contábil Final'
    };

    this.setDefautlFilialAndOpenFilter = function(widget) {
        var row = Util.clone(widget.currentRow);
        var filter = [
            {   
                "name": "CDFILIAL",
                "operator": "=",
                "value": "FILIAL_LOGADA"
            }  
        ];
        General.callRestEngine("ctb#/crud/filial_empresa", "FilterData", filter).then(function(success) {
            
            var date = new Date();
            var primeiroDia = new Date(date.getFullYear(), date.getMonth(), 1);
            var ultimoDia = new Date(date.getFullYear(), date.getMonth() + 1, 0);
            primeiroDia = formatarData(primeiroDia);
            ultimoDia = formatarData(ultimoDia);
            row.DATABALANCETE   = {start : primeiroDia, end : ultimoDia};
            row.CDFILIAL        = [success.dataset.filial_empresa[0].CDFILIAL];
            row.NMFILIAL        = [success.dataset.filial_empresa[0].NMFILIAL];
            row.CDEMPRESA       = success.dataset.filial_empresa[0].CDEMPRESA;
            row.NMEMPRESA       = success.dataset.filial_empresa[0].NMEMPRESA;
            row.RELATORIO       = "Balancete Gerencial";
            row.CDNVCONT        = 'T';
            ZhFilterPreferences.setOriginalFilter(widget, row);
            ZhFilterPreferences.openFilterWidget(widget, row).then(function() {
                templateManager.container.getActiveWidget().getField('CDCENTCUST').dataSourceFilter.forEach(
                    function(filter){
                        if(filter.name == 'CDFILIAL'){
                            filter.value = row.CDFILIAL;
                        }
                    }
                );
                templateManager.container.getActiveWidget().getField('CDCENTCUST').readOnly = false;
            });
            
        },
        function(error) {
            ZhFilterPreferences.openFilterWidget(widget);
        });
        
        //this.setMaskContCtbl(widget.getField('CDCONTCTBLT'));
        //this.setMaskContCtbl(widget.getField('NMCONTINI').fields[0]);
        //this.setMaskContCtbl(widget.getField('NMCONTFIN').fields[0]);
        
        this.setDataFieldNvCont(widget.getField('CDNVCONT'));
    };
    
    this.validaEmpresa = function(widget) {
        if(widget.currentRow.CDFILIAL) {
            var empresas  = widget.currentRow.CDEMPRESA;
            var cdEmpresa = empresas[0];
            var valida    = true;
            if(empresas instanceof Array) {
                empresas.forEach(function(empresa) {
                    if(empresa !== cdEmpresa) valida = false;
                });
                if(!valida) {
                    ScreenService.showMessage(mensagens.empresasDiferem);
                    removeValorFields(widget, ['NMFILIAL', 'CDFILIAL', 'CDEMPRESA', 'NMEMPRESA', 'CDCENTCUST']);
                    alteraReadOnlyFields(widget, ['CDCENTCUST'], true);
                }
                else {
                    alteraReadOnlyFields(widget, ['CDCENTCUST'], false);
                    var filter = {
                        "requestType": "FilterData",
                        "filter": [{"name": "CDEMPRESA", "operator": "=", "value": cdEmpresa}]
                    };
                    restEngine.post("ctb#/crud/empresa", filter, function(success){
                        var empresa = success.dataset.empresa[0];
                        widget.currentRow.NMEMPRESA = empresa.NMEMPRESA;
                        widget.currentRow.CDEMPRESA = empresa.CDEMPRESA;
                    }.bind(this));
                }
            }
        }
        else {
            removeValorFields(widget, ['NMFILIAL', 'CDFILIAL', 'CDEMPRESA', 'NMEMPRESA', 'CDCENTCUST']);
            alteraReadOnlyFields(widget, ['CDCENTCUST'], true);
        }
    };
    
    this.setDataFieldNvCont = function(field) {
        this.getParamGeral().then(function(response) {
            var maxlevel = this.getLevelByMask(response.dataset.paramgeral[0].CDPICTCCTB);
            for(var i = 1; i <= maxlevel; i++) {
                field.dataSource.data.push({
                    "value": i,
                    "description": i
                });
            }
        }.bind(this)); 
    };
    
    this.getLevelByMask = function (mask) {

		var firstLevel = 1;

		var splitMask = mask.split('.');
		var biggestLevel = splitMask.length;

		return biggestLevel;
	};
    
    // this.setMaskContCtbl = function(field) {
    //     this.getParamGeral().then(function(response) {
    //         var paramgeral = response.dataset.paramgeral[0];
    //         field.mask =  {
    //             "type": "fix",
    //             "params": {
    //                 "mask": paramgeral.CDPICTCCTB
    //             }
    //         };
    //     });
    // };
    
    this.cdcentcustFilter = function (args){
        var field = args.owner.field;
        field.dataSourceFilter[1].value = null;
        field.reload();
    };
    
    this.setNrctrlbalgettmp = function(widget) {
        widget.dataSourceFilter[0].value = (widget.dataSource.data[0]) ? widget.dataSource.data[0].NRCTBBALGERTMP : null;
        widget.dataSourceFilter[1].value = (widget.dataSource.data[0]) ? widget.dataSource.data[widget.dataSource.data.length - 1].CDCONTCTBLT : null;
    };
    
    this.getParamGeral = function() {
        return General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []);
    };
    
    this.buildFieldsJson = function(widget) {
        var filterPopup = widget.appliedFilter.FILTER_ROW;
        removeFieldsCentCust(widget);
        var centcust = filterPopup.CDCENTCUST;
        var filter   = [
            {
                "name": "CDFILIAL",
                "operator": "IN",
                "value": filterPopup.CDFILIAL
            }
        ];
        if(centcust){
            if(centcust.length != 0) {
                filter.push({
                    "name": "CDCENTCUST",
                    "operator": "IN",
                    "value": centcust
                });
            } 
        }
        General.callRestEngine("ctb#/getAllCdCentCust", "FilterData", filter).then(function(response) {
            response.dataset.getAllCdCentCust.forEach(function(data) {
                var nameCentCust = data.CDCENTCUST+' - '+data.NMCENTCUST;
                buildField(data.CDCENTCUST, nameCentCust, widget);
            }.bind(this));
            metaDataFactory.widgetFactory(widget, widget.container);
            widget.redraw(true);
            widget.reload().then(function(){
                widget.redraw(true);
            }.bind(this));
        }.bind(this));
    };
    
    this.validaAlteracaoConta = function(field){
        var widget = field.widget;
        if(!verificaValorInvalido(widget.currentRow.CDCONTINI, widget.currentRow.CDCONTFIN)) {
            ScreenService.showMessage(mensagens.valorInvalido);
            field.setValue('');
            var cdfield = field.name.replace("NM", "CD");
            widget.currentRow[cdfield] = '';
        }
    };
    
    function verificaValorInvalido(fieldMin, fieldMax) {
        return (!(fieldMin && fieldMax) || fieldMin <= fieldMax);
    }
    
    function alteraReadOnlyFields(widget, fields, readOnly) {
        fields.forEach(function(field) {
            widget.getField(field).readOnly = readOnly;
        });
    }
    
    function removeValorFields(widget, fields) {
        fields.forEach(function(field) {
            widget.currentRow[field] = '';
        });
    }
    
    function removeFieldsCentCust(widget) {
        var fields = widget.fields.filter(function(field) {
            if(!field.CENTCUST) return field; 
        });
        widget.fields = fields;
    }
    
    function buildField(cdcentcust, nmcentcust, widget) {
        var field = {
            "name": "'".concat(cdcentcust).concat("'"),
            "label": nmcentcust,
            "template": "field/text-edit.html",
            "isVisible": true,
            "CENTCUST": true,
            "showOnList": true,
            "filterProperties": {
                "isVisible": false,
                "showOnForm": false
            },
            "xlsType": "integer",
            "mask": {
                "type": "viewFloat",
                "params": {
                    "showSymbol": false,
                    "allowEmpty": true,
                    "precision": 2,
                    "thousands": ".",
                    "decimal": ","
                }
            }
        };
        metaDataFactory.fieldFactory(field, widget, widget);
    }

    function formatarData(data) {
        var d = new Date(data),
        mes = '' + (d.getMonth() + 1),
        dia = '' + d.getDate(),
        ano = d.getFullYear();
    
        if (mes.length < 2) mes = '0' + mes;
        if (dia.length < 2) dia = '0' + dia;
    
        return [dia, mes, ano].join('/');
    }
    
    self.setFilterCentrodeCusto = function(widget){
        if((widget.currentRow.CDFILIAL) && (widget.currentRow.CDFILIAL != "")){
            widget.getField('CDCENTCUST').dataSourceFilter.forEach(
                function(filter){
                    if(filter.name == 'CDFILIAL'){
                        filter.value = widget.currentRow.CDFILIAL;
                    }
                }
            );
            widget.getField('CDCENTCUST').reload();
        }
    };

};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ctb23000_BalanceteGerencial_Controller', Ctb23000_BalanceteGerencial_Controller);
});

// FILE: ./assets/js/controllers/Ctb24000_Balancete_Controller.js
var Ctb24000_Balancete_Controller = function(ScreenService, templateManager, metaDataFactory, Messages_Contabil, restEngine, General, ZhFilterPreferences) {

    var self = this;
    
    var contctblMask = "";
    
    self.defaultValuesFilter = function() {
        var widget       = templateManager.container.getWidget('balanceteWidget');
    	var rowSetFilter = {
                    'IDCONSOLIDADO': "N",
                    'TPSALDO': "F",
                    'IDENCERRAMENTO': "N"
                };
                ZhFilterPreferences.setOriginalFilter(widget.id, rowSetFilter);
                ZhFilterPreferences.openFilterWidget(widget, rowSetFilter);
    };
    
    self.preparaFiltroBalancete = function(args) {
    	var widget    = templateManager.container.getWidget('balanceteWidget');
    	var filterRow = args.e.preference.FILTER_ROW;
    	
    	args.e.preference.FILTER_ROW = {};
    	
    	//var cdempresa  = filterRow.hasOwnProperty('CDEMPRESA')  ? filterRow.CDEMPRESA.join('_')  : null;
    	
    	General.callRestEngine('ctb#/aplicarFiltroBalancete', 'Row', filterRow).then(function (response) {
    		var nrbalancete = response.dataset.balancete[0];
    		
    		var filtro = [
    			{
    				"name": "P_NRBALANCETE",
    				"operator": "=",
    				"value": nrbalancete
    			}
    		];
    		
    		widget.dataSourceFilter = filtro;
    		widget.reload();
    	}).catch(function(erro){
    		ScreenService.showMessage(erro.data.error);
    	});
    };
    
    function formatarData(data) {
        var d = new Date(data),
        mes = '' + (d.getMonth() + 1),
        dia = '' + d.getDate(),
        ano = d.getFullYear();
    
        if (mes.length < 2) mes = '0' + mes;
        if (dia.length < 2) dia = '0' + dia;
    
        return [dia, mes, ano].join('/');
    }
    
    /*
     * Função chamada pela tela ao ser aberta.
     * Seta a máscara de conta contábil buscada da PARAMGERAL na variável.
     */
    this.setContctblMask = function() {
        // Chama a rota que retorna os dados da PARAMGERAL.
        General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []).then(function(response) {
            // Busca o primeiro dado retornado, que será o único registro da parametrização.
            var paramgeral = response.dataset.paramgeral[0];

            // Armazena o valor da máscara na variável.
            contctblMask = paramgeral.CDPICTCCTB;
        });
    };
    
    self.tipoOnChange = function(widget) {
        var currentRow = widget.currentRow;
        
        var consolidado = currentRow.IDCONSOLIDADO == 'S';
        
        if(consolidado){
           widget.getField("CDEMPRESA").showOnForm = true;
           widget.getField("NMEMPRESA").showOnForm = false;
        }else{
            widget.getField("NMEMPRESA").showOnForm = true;
            widget.getField("CDEMPRESA").showOnForm = false;
        }
            
        widget.redraw();
        templateManager.updateTemplate();

    };
    
    this.getContctblMask = function() {
    return contctblMask;
  };

};

Configuration(function(ContextRegister){
    ContextRegister.register('Ctb24000_Balancete_Controller', Ctb24000_Balancete_Controller);
});

// FILE: ./assets/js/controllers/Ctb32700_DREAnual_Controller.js
var Ctb32700_DREAnual_Controller = function(ScreenService, General, Ctb32700_DREAnual_Service) {

    /** Variáveis de Inicialização */
    var self = this;

    /** Busca Padrão DRE */
    self.buscaPadraoDre = function(widget){
        widget.currentRow.CDREPORT = 'CTB32700';
        widget.currentRow.DTCTBINICIAL = moment().format('MM/YYYY');
    };

    /** Gera Relátorio DRE */
    self.geraRelatorioDre = function(args){
        var widget = args.owner.widget;

        if(widget.isValid()){
            Ctb32700_DREAnual_Service.geraDREAnual(widget.currentRow).then(function (relatorios) {
                
                var relatorio = relatorios.dataset.geraDREAnual.relatorios[0];
                var report = widget.currentRow.CDREPORT;
                var routes = 'ctb#/' + report;
                var row = {
                    NRORG       : getLocalVar('NRORG') ,
                    NRCONTABGER : relatorio.NRCONTABGER
                };
                General.openReport(routes, report, row);
                
            }, function (error) {
                ScreenService.showMessage(error.data.error);
            });
        }
    };
  
};

/* global Configuration */
Configuration(function(ContextRegister){
    ContextRegister.register('Ctb32700_DREAnual_Controller', Ctb32700_DREAnual_Controller);
});

// FILE: ./assets/js/controllers/Ctb42200_Saldo_Contabil_Controller.js
var Ctb42200_Saldo_Contabil_Controller = function(ScreenService, templateManager, General, ZhFilterPreferences) {
    var self = this;
    
    this.preparaFiltroSaldoContabil = function(args) {
        var widget    = templateManager.container.getWidget('saldo_contabil');
    	var filterRow = args.e.preference.FILTER_ROW;
    	var itemErradoIndex = null;
    	
    	for(var index = 0, filters = widget.dataSourceFilter; index< filters.length ; index ++){
    	   var item = filters[index];
            if(item.name == 'DTINICIAL'){
    	        item.value = filterRow.DTLANCCONT ? filterRow.DTLANCCONT.start : null;
    	    }else if(item.name == 'DTFINAL'){
    	        item.value = filterRow.DTLANCCONT ? filterRow.DTLANCCONT.end : null;
    	    }else if(!filterRow[item.name]){
    	        item.value = 'T';
    	    }else if(filterRow[item.name] && (!item.value|| Array.isArray(item.value))){
    	        item.value = filterRow[item.name];
    	    }
    	    if(item.name == 'DTLANCCONT' || item.name == 'NMEMPRESA'){
    	        itemErradoIndex = index;
    	        break;
    	    }
    	}
        if(itemErradoIndex != null){
            widget.dataSourceFilter.splice(itemErradoIndex, 1);
            self.preparaFiltroSaldoContabil(args);    
        }else{
            widget.reload();    
        }
    	
    };
    
    this.setDefautlFilialAndOpenFilter = function(widget) {
        var row = widget.currentRow;
        var filter = [
            {   
                "name": "CDFILIAL",
                "operator": "=",
                "value": "FILIAL_LOGADA"
            }  
        ];
        var date = new moment();
        row.DTLANCCONT   = {start : date.format('DD/MM/YYYY'), end : date.format('DD/MM/YYYY')};
        row.RELATORIO       = "Saldo Contabil";
        
        General.callRestEngine("ctb#/crud/filial_empresa", "FilterData", filter).then(function(success) {
            
            row.CDEMPRESA       = success.dataset.filial_empresa[0].CDEMPRESA;
            row.NMEMPRESA       = success.dataset.filial_empresa[0].NMEMPRESA;
            
            ZhFilterPreferences.setOriginalFilter(widget, row);
            ZhFilterPreferences.openFilterWidget(widget, row);
            
        },
        function(error) {
            ZhFilterPreferences.openFilterWidget(widget);
        });
        
    };


};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb42200_Saldo_Contabil_Controller', Ctb42200_Saldo_Contabil_Controller);
});


// FILE: ./assets/js/controllers/Ctb44200_Razao_Gerencial_Controller.js
var Ctb44200_Razao_Gerencial_Controller = function(ScreenService, templateManager, General, Ctb44400_DreGerencial_Service, maskEngine, ZhFilterPreferences) {
    var self = this;

    this.preparaFiltroRazaoGerencial = function(args) {
        var widget    = templateManager.container.getWidget('razao_gerencial');
        var filterRow = args.e.preference.FILTER_ROW;
        var filtro = [];
        Object.keys(filterRow).forEach((item) => {
          switch (item) {
              case 'DTLANCCONT':
                Object.keys(filterRow[item]).forEach((dado) => {
                if(dado == 'start'){
                   filtro.push(  
                       {
                        "name": "DTINICIAL",
                        "operator": "=",
                        "value": filterRow[item][dado]
                       }
                    );
                } else if(dado == 'end') {
                    filtro.push(  
                      {
                        "name": "DTFINAL",
                        "operator": "=",
                        "value": filterRow[item][dado]
                      }
                    );
                }
                });
                break;
              case 'CDEMPRESA':
                  filtro.push(  
                      {
                        "name": "CDEMPRESA",
                        "operator": "=",
                        "value": filterRow[item].join('_') 
                      }
                    );
                break;
                case 'CDFILIAL':
                  filtro.push(  
                      {
                        "name": "CDFILIAL",
                        "operator": "=",
                        "value": filterRow[item].join('_') 
                      }
                    );
                break;
                case 'CDCENTCUST':
                  filtro.push(  
                      {
                        "name": "CDCENTCUST",
                        "operator": "=",
                        "value": filterRow[item].join('_') 
                      }
                    );
                 
                break;
                case 'CDCONTINI':
                  filtro.push(  
                      {
                        "name": "CDCONTINI",
                        "operator": "=",
                        "value": filterRow[item]
                      }
                    );
                break;
                case 'CDCONTFIN':
                  filtro.push(  
                      {
                        "name": "CDCONTFIN",
                        "operator": "=",
                        "value": filterRow[item]
                      }
                    );
                 
                break;
                case 'CDAREAGERE':
                  filtro.push(  
                      {
                        "name": "CDAREAGERE",
                        "operator": "=",
                        "value": filterRow[item].join('_') 
                      }
                    );
                 
                break;
          }
        });
    	this.geraRazaoGerencial(args, filtro);
    };

    this.geraRazaoGerencial = function(args, filterRow) {
        var widget    = templateManager.container.getWidget('razao_gerencial');
        
    	General.callRestEngine('ctb#/geraRazaoGerencialNovo', 'Row', filterRow).then(function (response) {
    		var nrctbtemp = response.dataset.ctbtemp[0];

    		var filtro = [
    			{
    				"name": "NRCTBTEMP",
    				"operator": "=",
    				"value": nrctbtemp
    			}
    		];

    		args.e.preference.FILTER_ROW = {"NRCTBTEMP" : nrctbtemp};
    		widget.dataSourceFilter = filtro;
    		widget.reload();
    	}).catch(function(erro){
    		ScreenService.showMessage(erro.data.error);
    	});
    };

};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb44200_Razao_Gerencial_Controller', Ctb44200_Razao_Gerencial_Controller);
});


// FILE: ./assets/js/controllers/Ctb44400_DreGerencial_Controller.js
var Ctb44400_DreGerencial_Controller = function(ScreenService, templateManager, General, Ctb44400_DreGerencial_Service, maskEngine, ZhFilterPreferences) {
    
    var contctblMask = "";  //Mascara
    var opcao        = "O"; //Opção do tipo de relatório que a tela exibirá: O = "Demonstrações Contábeis"; G = "Demonstrativo de Resultado Gerencial"
    
    /*Default value para 'Tipo Demonstrativo' IDTIPODEMO*/
    this.openFilter = function(widget) {
        var rowsToSet = {};
        rowsToSet.IDTIPODEMO = "O";
        ZhFilterPreferences.setOriginalFilter(widget.id, rowsToSet);
        ZhFilterPreferences.openFilterWidget(widget, rowsToSet);
    };
    
    /**/
    this.getIdtipodemoFromFilter = function() {
        return templateManager.container.getActiveWidget().appliedFilter.FILTER_ROW.IDTIPODEMO;
    };
    
    /*Aquisição da respectiva máscara*/
    this.setContctblMask = function() {
        General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []).then(function(response) {
                var paramgeral = response.dataset.paramgeral[0];
                contctblMask = paramgeral.CDPICTCCTB;
            }
        );
    };
    
    this.getContctblMask = function() {
        return contctblMask;
    };
    
    /*Alterna o datasource e os filtros do CDORIGDEMO (Chave de Acesso) da widget itens_apuracao conforme seleção no IDTIPOORIG (Origem)*/
    this.setDataSourceCdorigdemo = function(args) {
        var field = args.owner.getParent().widget.getField('CDORIGDEMO');
        
        field.clearValue();
        if(args.row.IDTIPOORIG == 'V') { //Valor Item Demonstração
            field.dataSource.name  = "ctb#/crud/itensapuracao_itemdemof";
            field.dataSourceFilter = [
                {
                    "name": "NRORG",
                    "operator": "=",
                    "value": "@getLocalVar('NRORG')@"
                },
                {
                    "name": "CDTIPODEMO",
                    "operator": "=",
                    "value": "@General.getFieldValue('CDTIPODEMO', 'tipo_demonstrativo')@"
                },
                {
                    "name": "IDTIPODEMO",
                    "operator": "=",
                    "value": "@General.getFieldValue('IDTIPODEMO', 'tipo_demonstrativo')@"
                }
            ];
        } else { //'S' Saldo em conta
            field.dataSource.name  = "ctb#/crud/itensapuracao_contctbl";
            field.dataSourceFilter = null;
        }
        field.reload();
    };
    
    /*Salva os registros de 'Itens de Apuração' e retorna o próximo código do campo CDSEGUAPUR para os casos de Inserção*/
    this.salvarItensApuracao = function(widget) {
        var newCdseguapur = "";
        var filter = [
            {   
                "name": "CDTIPODEMO",
                "operator": "=",
                "value": widget.currentRow.CDTIPODEMO
            },
            {   
                "name": "CDITEMSTRU",
                "operator": "=",
                "value": widget.currentRow.CDITEMSTRU
            },
            {   
                "name": "IDTIPODEMO",
                "operator": "=",
                "value": widget.currentRow.IDTIPODEMO
            }  
        ];
        if(widget.isValid()) {
            if(widget.currentRow.__is_new) { //Novo registro, deve-se crirar um novo código
                General.callRestEngine("ctb#/crud/itensapuracao_seq_cdseguapur", "FilterData", filter).then(function(response) {
                        if(response.dataset.itensapuracao_seq_cdseguapur.length != 0) //Ignora um response vazio do datasource
                            newCdseguapur = response.dataset.itensapuracao_seq_cdseguapur[0].CDSEGUAPUR;
                        if(newCdseguapur == "") //Primeiro registro
                            widget.currentRow.CDSEGUAPUR = "001";
                        else //Registro seguinte
                            widget.currentRow.CDSEGUAPUR = newCdseguapur;
                        General.saveCrud(widget);
                    }.bind(this)
                );
            } else //Edição, salva normalmente
                General.saveCrud(widget);
        }
    };
    
    /*Ajusta a visibilidade dos campos 'Operação' e '% Sobre' de acordo com o campo 'Origem'*/
    this.setVisibibFieldFromOrigem = function(args) {
        var widget = args.owner.getParent().widget;
        //Se a 'Origem' for 'Título' os campos 'Operação' e '% Sobre' ficam desabilitados
        if(args.row.IDORIGVALOR == 'T') {
            widget.getField('CDITEMSTRUPERC').readOnly = true;
            args.row.CDITEMSTRUPERC = '';
            widget.getField('IDOPERACAO').readOnly = true;
            args.row.IDOPERACAO = 'N';
        } else {
            widget.getField('CDITEMSTRUPERC').readOnly = false;
            widget.getField('IDOPERACAO').readOnly = false;
        }
    };
    
    /*Ajusta a disponibilidade/acesso da widget 'Itens de Apuração'. Quando a 'Origem' for editada para 'Apurado' a referida widget ficará inacessível*/
    this.setVisibWidgetItensApuracao = function(owner) {
        if(owner.currentRow.IDORIGVALOR == 'A')
            General.changeWidgetAcessibility(owner.widgets, true);
        else
            General.changeWidgetAcessibility(owner.widgets, false);
    };
    
    this.setVisibWidgetItensApuracaoCancela = function(args) {
        if(args.row.IDORIGVALOR == 'A')
            General.changeWidgetAcessibility(args.owner.widget.widgets, true);
        else
            General.changeWidgetAcessibility(args.owner.widget.widgets, false);
    };
    
    /*Ajusta o valor do IDTIPODEMO no filtro do NMTIPODEMO em tipo_demonstrativo*/
    this.getValorOpcao = function() {
        return opcao;
    };
    
    /*Controla vários campos de acordo com o tipo de demonstrativo selecionado no 'Tipo de Demonstrativo' (IDTIPODEMO)*/
    this.controlaCamposDemonstrativo = function(args) {
        opcao  = args.row.IDTIPODEMO;
        var widget = args.owner.field.widget.getParent().widgets[0]; //Adquiri a widget pai 'tipo_demonstrativo'
        
        if(opcao == "O") { //O Demonstrações Contábeis
            /*tipo_demonstrativo*/
            widget.getField('CDTIPODEMO').class     = 2;
            widget.getField('NMTIPODEMO').class     = 6;
            
            widget.getField('IDREFESPED').class     = 4;
            widget.getField('IDREFESPED').isVisible = true;
            /*itens_estrutura*/
            widget = widget.widgets[0];
            widget.getField('IDGRUPOBALSPED').isVisible    = true;
            widget.getField('IDGRUPOBALSPED').validations  = {"required": true};
            
            widget.getField('IDSTSALDOITSPED').isVisible   = true;
            widget.getField('IDSTSALDOITSPED').validations = {"required": true};
            
            widget.getField('CDNIVELITDEMOF').isVisible    = true;
            widget.getField('CDNIVELITDEMOF').validations  = {"required": true};
        } else { //G Demonstrativo de Resultado Gerencial
            /*tipo_demonstrativo*/
            widget.getField('CDTIPODEMO').class     = 4;
            widget.getField('NMTIPODEMO').class     = 8;
            
            widget.getField('IDREFESPED').class     = 0;
            widget.getField('IDREFESPED').isVisible = false;
            /*itens_estrutura*/
            widget = widget.widgets[0];
            widget.getField('IDGRUPOBALSPED').isVisible    = false;
            widget.getField('IDGRUPOBALSPED').validations  = null;
            
            widget.getField('IDSTSALDOITSPED').isVisible   = false;
            widget.getField('IDSTSALDOITSPED').validations = null;
            
            widget.getField('CDNIVELITDEMOF').isVisible    = false;
            widget.getField('CDNIVELITDEMOF').validations  = null;
        }

        widget = args.owner.field.widget.getParent().widgets[0];
        widget.redraw();
    };
    
    this.openPopUpRelatorios = function() {
        var widgetPopup = templateManager.container.getWidget('popUp_demonstrativoResultado');
        
        // set valorers Default
        widgetPopup.currentRow.SELECAOEMPRESA = 'T';
        widgetPopup.currentRow.IDSALDO = 'A';
        widgetPopup.currentRow.TIPOSALDO = 'S';
        widgetPopup.getField("NMTIPODEMO").reload();
        
        ScreenService.openPopup(widgetPopup);
    };
    
    // Controla Visibilidade do select de empresa
    this.empresaOnChange = function(widget){
        var  readOnlyEmpresa= widget.getField("SELECAOEMPRESA").value() === 'T';
        var empresa = widget.getField("CDEMPRESA");
        empresa.setValue([]);
        empresa.readOnly = readOnlyEmpresa;
        if(readOnlyEmpresa){
              delete empresa.validations.required;
        }else{
             empresa.validations.required = true  ;
        }
       
        empresa.reload();
    };
    
    /* Gera Relatorio */  
    this.geraRelatorios = function(widget){
        var row = Util.clone(widget.currentRow);
        var rowValida;
        
        if(row.IDSALDO == 'A'){
           rowValida = this.validaPeriodo(row.DATAA , row.DATAB);
           
        }else{
            rowValida = this.validaPeriodo(row.DATAAINTERA , row.DATAAINTERB);
            rowValida *= this.validaPeriodo(row.DATABINTERA , row.DATABINTERB);
        }
        
       if(rowValida && widget.isValid()){
           Ctb44400_DreGerencial_Service.geraRelatorio(row).then(function(birtURL) {
            window.open(birtURL.dataset.URL[0]);
        }, function(error) {
            ScreenService.showMessage(error.data.error);
        });
           
       } 
        
    };
    
    
    // Controla Visibilidade dos campos de Periodos
    this.idsaldoOnChange = function (widget){
        var  visibleSaldoAcumulado= widget.getField("IDSALDO").value() === 'A';
        var widgetPopup = templateManager.container.getWidget('popUp_demonstrativoResultado');
        
        // Controla data Quando Acumulado
        var dataa =  widget.getField("DATAA");
        var datab =  widget.getField("DATAB");
        
        dataa.validations.required = visibleSaldoAcumulado;
        dataa.isVisible = visibleSaldoAcumulado;
        dataa.setValue("");
        
        datab.validations.required = visibleSaldoAcumulado;
        datab.isVisible = visibleSaldoAcumulado;
        datab.setValue("");

        // Controla Periodo quando acumulado
        
        var dataaintera = widget.getField("DATAAINTERA");
        var dataainterb = widget.getField("DATAAINTERB");
        var databintera = widget.getField("DATABINTERA");
        var databinterb = widget.getField("DATABINTERB");
        
        dataaintera.validations.required = !visibleSaldoAcumulado;
        dataaintera.isVisible = !visibleSaldoAcumulado;
        dataaintera.setValue("");
        
        dataainterb.validations.required = false;
        dataainterb.isVisible = !visibleSaldoAcumulado;
        dataainterb.setValue("");
        
        databintera.validations.required = !visibleSaldoAcumulado;
        databintera.isVisible = !visibleSaldoAcumulado;
        databintera.setValue("");
        
        databinterb.validations.required = false;
        databinterb.isVisible = !visibleSaldoAcumulado;
        databinterb.setValue("");
        
        widgetPopup.reload();
    
    };
    
    this.validaPeriodo = function(dataIni , dataFin){
        dataIni = moment(dataIni, 'DD/MM/YYYY');
        dataFin = moment(dataFin, 'DD/MM/YYYY');
        if(dataIni && dataIni && dataIni.isAfter(dataFin)){
            ScreenService.showMessage("Data inicial do período deve ser menor ou igual a data final");
            return false;
        }
        return true;
    };
    
};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb44400_DreGerencial_Controller', Ctb44400_DreGerencial_Controller);
});


// FILE: ./assets/js/controllers/Ctb72700_relatorio_lancamentos_sem_codigo_comercial_Controller.js
var Ctb72700_relatorio_lancamentos_sem_codigo_comercial_Controller = function(ScreenService, templateManager, localStorageEngine, General, ZhFilterPreferences) {

    var self = this;
    
    this.relatorioOnEnter = function(args) {
        self.setContctblMask();
        var rowSetFilter = {};
        /*General.callRestEngine("ctb#/crud/contctbl", "FilterData", []).then(function(response) {
            if(response.dataset && response.dataset.contctbl && response.dataset.contctbl.length){
                var contctbl = response.dataset.contctbl;
                rowSetFilter = {   
                    'CDCONTCTBLINI': contctbl[0].CDCONTCTBL,
                    'CDCONTCTBLFIN': contctbl[contctbl.length-1].CDCONTCTBL,
                    'NMCONTCTBLINI': contctbl[0].NMCONTCTBL,
                    'NMCONTCTBLFIN': contctbl[contctbl.length-1].NMCONTCTBL
                };
            }*/
            ZhFilterPreferences.setOriginalFilter(args.owner, rowSetFilter);

            // função nativa para abrir o relatório quando a página é carregada
            ZhFilterPreferences.openFilterWidget(args.owner);
            /*
        });*/
    };
  
    this.setContctblMask = function() {
        General.callRestEngine("cadCtb#/crud/paramgeral", "FilterData", []).then(function(response) {
            var paramgeral = response.dataset.paramgeral[0];
            localStorageEngine.setLocalVar('CDPICTCCTB', paramgeral.CDPICTCCTB);
        });
    };
    
    self.filtroRelatorio = function(widget, preference){
        var currentRowFiltro = preference.FILTER_ROW;

        var cdempresa = currentRowFiltro.CDEMPRESA;
        var cdcontctblini = currentRowFiltro.CDCONTCTBLINI;
        var cdcontctblfin = currentRowFiltro.CDCONTCTBLFIN;
        var dtinicio = currentRowFiltro.DTLANCCONT.start;
        var dtfinal = currentRowFiltro.DTLANCCONT.end;
        
        widget.dataSourceFilter.forEach(function (filtro) {
            switch(filtro.name){
                case 'CDEMPRESA': 
                    filtro.value = cdempresa;
                    break;
                case 'CDCONTCTBLINI':
                    filtro.value = cdcontctblini;
                    break;
                case 'CDCONTCTBLFIN':
                    filtro.value = cdcontctblfin;
                    break;
                case 'DTINICIAL':
                    filtro.value = dtinicio;
                    break;
                case 'DTFINAL':
                    filtro.value = dtfinal;
                    break;
            }
        });
        
        preference.CUSTOM_FILTER_ROW = currentRowFiltro;
        delete preference.CUSTOM_FILTER_ROW.DTLANCCONT;
        
        
    };
    
    

};

Configuration(function(ContextRegister){
    ContextRegister.register('Ctb72700_relatorio_lancamentos_sem_codigo_comercial_Controller', Ctb72700_relatorio_lancamentos_sem_codigo_comercial_Controller);
});

// FILE: ./assets/js/controllers/Ctb90100_SpedContabil_Controller.js
var Ctb90100_SpedContabil_Controller = function(ScreenService, templateManager, General, ZhFilterPreferences, ZHPromise, restEngine) {

    /* Variáveis de Inicialização */
    var self = this;

    /*
     * Função auxiliar para a chamada da função de exportação no backend.
     * Criada para uma padronização nas exportações das telas.
     */
    this.exportarArquivo = function(row, route, message) {
        // Inicializa uma promise.
        var deferred = ZHPromise.defer();
        message = message || 'Exportando...';

        // Muda a mensagem de carregamento para uma mensagem personalizada.
        ScreenService.changeLoadingMessage(message);

        // Chama a rota para efetuar a exportação.
        restEngine.request(route, {"requestType": "Row", "row": row}, undefined, undefined, undefined, undefined, 99999999999999999999)
        .then(function(response) {
            // Cria a rota a ser chamada para o donwload do arquivo exportado.
            var downloadRoute = window.serviceUrls.filter(function(x){return x.package == 'ctb';})[0].baseUrl + "/downloadArquivo?requestType=Row&row[DSARQUIVO]=";
            var fileName = response.dataset.columnsToReturn.fileName;
            
            // Abre a rota em uma nova janela, permitindo que o arquivo seja baixado.
            window.open(downloadRoute + fileName);

            // Finaliza a promise com sucesso.
            deferred.resolve(response);
        })
        .catch(function(error) {
            // Mensagem padrão em caso de timeout.
            var errorMessage = 'Timeout';

            // Verifica se houve alguma resposta da requisição.
            if (error.data && error.data.error) {
                // Caso haja alguma resposta, atribui a mensagem de erro.
                errorMessage = error.data.error;
            }

            // Imprime a mensagem.
            ScreenService.showMessage(errorMessage);

            // Finaliza a promise retornando o objeto de erro.
            deferred.reject(error);
        })
        .finally(function() {
            // Restaura a mensagem original.
            ScreenService.restoreDefaultLoadingMessage();
        });

        // Retorna a promise a ser finalizada.
        return deferred;
    };
    
    /*
     * Função para a chamada da função de exportação.
     */
    this.exportaSpedContabil = function(widget) {
        // Verifica se todos os campos obrigatórios foram preenchidos.
        if (widget.isValid()) {
            var row = widget.currentRow; 
            var route = "ctb#/exportaSpedContabil";
            var message = 'Exportando Sped...';
            self.exportarArquivo(row, route, message);
        }
    };
    
    self.verificaRazaoAuxliarObg = function(){
        var widget = templateManager.container.getWidget('SpedContabilForm');
        if(widget.currentRow.GERARAZAO == 'S'){
            widget.getField('TIPOLIVRO').readOnly= false;
            widget.getField('TIPOLIVRO').validations = {"required": true};
        }else{
            widget.getField('TIPOLIVRO').readOnly = true;
            widget.getField('TIPOLIVRO').validations = {};
            widget.getField('TIPOLIVRO').value("");
        }
        
        widget.reload();
        widget.getField('TIPOLIVRO').reload();
    };

    self.setDefaultValues = function(){
        var widget  =  templateManager.container.getWidget('SpedContabilForm');
        widget.currentRow.IDSPED = 'S';
        widget.currentRow.PERIODO = 'A';
        widget.currentRow.PORTE = 'N';
        widget.currentRow.GERARAZAO = 'N';
        widget.currentRow.TIPOLIVRO = 'S';
        widget.currentRow.FINALIDADE = 'S';
        widget.getField('MOVIMENTO').value('N');
    };
    
    self.verificaPeriodo = function(fieldName){
        var widget  =  templateManager.container.getWidget('SpedContabilForm');
        var dataInicial = widget.currentRow.DTINICIAL;
        var dataFinal = widget.currentRow.DTFINAL;
        var dataIni = moment(dataInicial, 'DD/MM/YYYY');
        var dateFin = moment(dataFinal, 'DD/MM/YYYY');
        if(dataIni && dataIni && dataIni.isAfter(dateFin)){
            widget.getField(fieldName).setValue('');
            ScreenService.showMessage("Operação bloqueada. Período de referência inicial e final devem estar em um intervalo válido.");
        }
    };
};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb90100_SpedContabil_Controller', Ctb90100_SpedContabil_Controller);
});


// FILE: ./assets/js/controllers/Ctb93000_EscrituracaoContabilFiscal.js
var Ctb93000_EscrituracaoContabilFiscal = function(ScreenService, templateManager, General, ZhFilterPreferences) {

    /* Variáveis de Inicialização */
    var self = this;

    /* Define Valores Padrões */
    self.defineValoresPadroes = function(widget) {
        widget.currentRow.IDECFRETIFI = 'N';
        widget.currentRow.IDECFTRANSMI = 'S';
    };

    /* Exporta ECF - Escrituração Contábil Fiscal */
    self.exportaECF = function(widget) {
        if(widget.isValid() && self.verificaAno(widget)){
            
            General.callRestEngine('ctb#/exportaECF', 'Row', widget.currentRow).then(function (result) {
                var arquivo = result.dataset.arqmagnetico.nrseqarqmag;
                ScreenService.showMessage('Arquivo ECF exportado com sucesso.');
            
                self.downloadArquivo([arquivo]);
              
            }).catch(function(erro){
                ScreenService.showMessage(erro.data.error);
            });
            
        }
    };
    
    /* Habilita Campo Numero Recibo */
    self.habilitaNumeroRecibo = function(widget) {
        if(widget.currentRow.IDECFRETIFI == 'S')
             widget.getField('NRRECIBO').readOnly = false;
        else{ 
            widget.getField('NRRECIBO').readOnly = true;
            widget.getField('NRRECIBO').value('');
        }
        widget.reload();
    };
    
    self.downloadArquivo = function(arquivo) {
        window.open(window.serviceUrls.filter(function(x){return x.package == 'ctb';})[0].baseUrl+"/donwloadArquivo?requestType=DataSet&dataset[0][DSARQUIVO]="+arquivo);
    };//olhar isso aqui
    
    self.verificaAno = function(widget){
        var ano = parseInt(widget.currentRow.DTANOREF);
        if(ano < 1600){
            ScreenService.showMessage("Ano de Referência inválido.");
            widget.currentRow.DTANOREF = "";
            return false;
        }
        return true;
    };
};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb93000_EscrituracaoContabilFiscal', Ctb93000_EscrituracaoContabilFiscal);
});


// FILE: ./assets/js/controllers/EscrituracaoContabilFiscal_Controller.js
var EscrituracaoContabilFiscal_Controller = function(ScreenService, templateManager, General, Ctb10000_LancamentosContabeis_Service, maskEngine, ZhFilterPreferences) {
    
    // Variável para guardar o escopo atual nas funções.
    var self = this;
    // Variável de controle para o armazenamento da widget atualmente aberta.
    var windowCurrentlyOpen = false;

    /*
     * Função para atualizar um field select conforme necessidade.
     * Caso algum filtro deste select seja alterado, por exemplo, a propriedade
     * "needReload" do field será setada pra true, indicando que o campo precisa
     * ser atualizado. Alterar a propriedade para false depois impede que o campo
     * sempre seja atualizado sem necessidade.
     */
    this.checkFieldNeedReload = function(field) {
        // Verifica se a propriedade não foi setada como false.
        if (field.needReload !== false) {
            // Caso não tenha, recarrega o field e seta a propriedade como false.
            field.reload();
            field.needReload = false;
        }
    };

    /*
     * Função para sair de uma "tela" e retornar à widget principal.
     */
    this.closeSwipe = function(widget) {
        // Prepara uma promise para esta função.
        // var deferred = ZHPromise.defer();
        var mainWidget = templateManager.container.getWidget("mainWidget");

        // Desativa a widget atualmente aberta.
        widget.deactivate();

        // Limpa a variável que indica qual a widget atualmente aberta.
        windowCurrentlyOpen = false;

        // Fecha o swipe.
        ScreenService.goBack().then(function() {
            // Ativa a widget principal.
            mainWidget.activate();
            // Finaliza a promise retornada.
            // deferred.resolve();
        });
        widget.currentRow.NMREG = "";
        // Retorna a promise preparada.
        // return deferred.promise;
    };

    /*
     * Função que altera a propriedade readOnly do campo de inscrição conforme
     * a inserção de empresa. Também reseta qualquer valor previamente preenchido.
     */
    this.empresaOnChange = function(widget) {
        // Variável booleana que é setada como true caso alguma empresa tenha sido selecionada.
        var empresaIsSelected = !!widget.currentRow.CDEMPRESA;
        var inscricaoField = widget.getField('CDINSCESTA');

        // Altera as propriedades do field de inscrição e reseta seu valor.
        inscricaoField.readOnly = !empresaIsSelected;
        inscricaoField.setValue(null);
        inscricaoField.needReload = true;
    };

    /*
     * Função auxiliar para a chamada da função de exportação no backend.
     * Criada para uma padronização nas exportações das telas.
     */
    this.exportarArquivo = function(row, route, message) {
        // Inicializa uma promise.
        var deferred = ZHPromise.defer();
        message = message || Messages_fiscal.EXPORTANDO;

        // Muda a mensagem de carregamento para uma mensagem personalizada.
        ScreenService.changeLoadingMessage(message);

        // Chama a rota para efetuar a exportação.
        restEngine.request(route, {"requestType": "Row", "row": row}, undefined, undefined, undefined, undefined, 99999999999999999999)
        .then(function(response) {
            // Cria a rota a ser chamada para o donwload do arquivo exportado.
            var downloadRoute = window.serviceUrls.filter(function(x){return x.package == 'fis';})[0].baseUrl + "/downloadArquivo?requestType=Row&row[DSARQUIVO]=";
            var fileName = response.dataset.columnsToReturn.fileName;
            
            // Abre a rota em uma nova janela, permitindo que o arquivo seja baixado.
            window.open(downloadRoute + fileName);

            // Finaliza a promise com sucesso.
            deferred.resolve(response);
        })
        .catch(function(error) {
            // Mensagem padrão em caso de timeout.
            var errorMessage = Messages_fiscal.TIMEOUT_ERROR;

            // Verifica se houve alguma resposta da requisição.
            if (error.data && error.data.error) {
                // Caso haja alguma resposta, atribui a mensagem de erro.
                errorMessage = error.data.error;
            }

            // Imprime a mensagem.
            ScreenService.showMessage(errorMessage);

            // Finaliza a promise retornando o objeto de erro.
            deferred.reject(error);
        })
        .finally(function() {
            // Restaura a mensagem original.
            ScreenService.restoreDefaultLoadingMessage();
        });

        // Retorna a promise a ser finalizada.
        return deferred;
    };
    
    this.findLastRowData = function(widgetName, row){
	    return restEngine.post("ctb#/"+widgetName+"/findLastRowData", {
            "requestType": "Row",
            "row": row
        });
	};

    /*
     * Função para o retorno da data atual.
     */
    this.getCurrentDate = function() {
        return moment().format("DD/MM/YYYY");
    };

    /*
     * Função para o retorno do primeiro dia do mês da data atual.
     */
    this.getFirstDayOfMonth = function() {
        return moment().startOf('month').format("DD/MM/YYYY");
    };

    /*
     * Função para o retorno do último dia do mês da data atual.
     */
    this.getLastDayOfMonth = function() {
        return moment().endOf('month').format("DD/MM/YYYY");
    };

    /*
     * Função que verifica o clique em uma das opções disponíveis na widget
     * principal. Determina se um swipe será aberto ou não, dependendo da
     * opção selecionada.
     */
    this.mainWidgetAfterMoveRow = function(widget) {
        // Guarda o nome da widget relacionada à opção clicada, se houver.
        var windowToOpen = widget.currentRow.WINDOW;
        // Guarda a propriedade "ENABLED" da opção selecionada.
        var windowEnabled = widget.currentRow.ENABLED;

        // Verifica se há uma widget associada (não for um submenu) e se esta
        // está habilitada (a tela estiver disponível para ser utilizada).
        if (windowToOpen && windowEnabled) {
            // Verifica se já há uma widget aberta e se esta é diferente da
            // selecionada.
            if (windowCurrentlyOpen && windowCurrentlyOpen != windowToOpen) {
                // Fecha o swipe com a widget já aberta.
                self.closeSwipe(templateManager.container.getWidget(windowCurrentlyOpen)).then(function() {
                    // Abre o swipe na widget selecionada.
                    ScreenService.openSwipe(templateManager.container.getWidget(windowToOpen));
                });
            }
            // Senão, abre o swipe na opção selecionada.
            else {
                // Abre o swipe na widget selecionada.
                ScreenService.openSwipe(templateManager.container.getWidget(windowToOpen));
            }
            // Altera a variável de controle da widget atualmente aberta.
            windowCurrentlyOpen = windowToOpen;
        }
        // Senão, verifica se não há a propriedade "ENABLED" na opção
        // selecionada, indicando que é um submenu.
        else if (windowEnabled !== false) {
            // Altera o estado aberto/fechado do submenu.
            widget.currentRow._opened = !widget.currentRow._opened;
        }
    };
    

};

Configuration(function(ContextRegister) {
    ContextRegister.register('EscrituracaoContabilFiscal_Controller', EscrituracaoContabilFiscal_Controller);
});


// FILE: ./assets/js/controllers/Ger02900_ParametrosContabilizacao_Controller.js
var Ger02900_ParametrosContabilizacao_Controller = function(ScreenService, templateManager, ZHPromise, General) {

    var self = this;
    var windowCurrentlyOpen = false;
    var contctblMask = "";
    var produtoFields = [
        "CDPRODINI",
        "NMPRODINI",
        "CDPRODFIM",
        "NMPRODFIM",
        "CDCTBLENTRPF",
        "NMCTBLENTRPF",
        "CDCTBLSAIDPF",
        "NMCTBLSAIDPF",
        "CDCTBLPRODPF",
        "NMCTBLPRODPF",
        "CDCTBLCPROPF",
        "NMCTBLCPROPF",
        "CDCTBLPRACPF",
        "NMCTBLPRACPF",
        "CDCTBLAJUSPF",
        "NMCTBLAJUSPF",
        "CDCTBLIMPLPF",
        "NMCTBLIMPLPF"
    ];
    var unidadeFields = {
        "NMFILIALORIG": null,
        "T_CDFILIALDEST": 'T',
        "IDCTBLENTRPF": 'R',
        "IDCTBLSAIDPF": 'R',
        "IDCTBLPRODPF": 'R',
        "IDCTBLCPROPF": 'R',
        "IDCTBLPRACPF": 'R',
        "IDCTBLAJUSPF": 'R',
        "IDCTBLIMPLPF": 'R',
        "CDFILIALDEST": []
    };

    self.applyDefaultIdentrsaidop = function(widget) {
        if (!widget.currentRow.IDENTRSAIDOP) {
            widget.currentRow.IDENTRSAIDOP = 'E';
        }
    };

    var cadastramentoProdutoIsValid = function(widget) {
        var isValid = false;
        var currentRow = widget.currentRow;
        if (widget.isValid()) {
            if (currentRow.IDTIPOCAD == 'P') {
                if (currentRow.CDPRODFIM >= currentRow.CDPRODINI) {
                    isValid = true;
                }
                else {
                    ScreenService.showMessage("O produto final deve ser maior que o produto inicial.");
                }
            }
            else {
                isValid = true;
            }
        }
        return isValid;
    };

    var callCadastroProduto = function(widget) {
        General.callRestEngine("ctb#/parametros_contabilizacao_cadastraproduto", "Row", widget.currentRow).then(function() {
            self.closeCadastramentoProduto().then(function() {
                ScreenService.showMessage("Replicação de parâmetros feita com sucesso.");
            });
        }).catch(function(error) {
            var errorMessage = 'Timeout';
            if (error.data) {
                errorMessage = error.data.error;
            }
            ScreenService.showMessage(errorMessage);
        });
    };

    self.cancelInForm = function(widget) {
        Util.extend(widget.currentRow, widget.backupRow);
        widget.view();
    };

    self.changeWidgetFormMode = function(widget) {
        widget.edit();
    };

    self.checkFormData = function(widget) {
        var data = widget.dataSource.data;
        if (Array.isArray(data) && data[0]) {
            widget.currentRow = data[0];
            widget.backupRow = Util.clone(widget.currentRow);
            widget.template = widget.templateToForm;
        }
        else {
            ScreenService.showMessage("Não há registro de parametrização cadastrado.");
            widget.template = widget.viewTemplate;
        }
    };

    self.checkReloadDependentWidget = function(currentWidget) {
        var childWidget = templateManager.container.getWidget(currentWidget.dependentWidgetName);
        var toReload = currentWidget.widgetDependentFields.every(function(fieldValue) {
            return !!currentWidget.currentRow[fieldValue];
        });
        if (toReload) {
            childWidget.list();
            childWidget.reload();
            childWidget.view();
        }
        else {
            if (childWidget.viewTemplate) {
                childWidget.template = childWidget.viewTemplate;
            }
            childWidget.dataSource.data = [];
            childWidget.currentRow = {};
        }
    };

    self.checkReloadDependentField = function(field) {
        if (field.toReload !== false) {
            field.reload();
            field.toReload = false;
        }
    };

    self.clearDescriptionFieldValue = function(field) {
        if (!field.value()) {
            field.widget.currentRow[field.descriptionField] = null;
        }
    };

    self.closeCadastramentoProduto = function() {
        return ScreenService.goBack().then(function() {
            templateManager.container.getWidget('estProdutoUnidade').activate();
        });
    };

    self.closeCadastramentoTitulo = function() {
        return ScreenService.goBack().then(function() {
            templateManager.container.getWidget('finUnidadeTabbed').activate();
        });
    };

    self.closeSwipe = function(widget) {
        var deferred = ZHPromise.defer();
        var mainWidget = templateManager.container.getWidget("mainWidget");
        widget.deactivate();
        windowCurrentlyOpen = false;
        ScreenService.closeSwipe(0).then(function() {
            mainWidget.activate();
            deferred.resolve();
        });
        return deferred.promise;
    };

    self.getContctblMask = function() {
        return contctblMask;
    };

    self.mainWidgetAfterMoveRow = function(widget) {
        var windowToOpen = widget.currentRow.WINDOW;
        if (windowToOpen) {
            if (windowCurrentlyOpen && windowCurrentlyOpen != windowToOpen) {
                self.closeSwipe(templateManager.container.getWidget(windowCurrentlyOpen)).then(function() {
                    ScreenService.openSwipe(templateManager.container.getWidget(windowToOpen));
                    windowCurrentlyOpen = windowToOpen;
                });
            }
            else {
                ScreenService.openSwipe(templateManager.container.getWidget(windowToOpen));
                windowCurrentlyOpen = windowToOpen;
            }
        }
        else {
            widget.currentRow._opened = !widget.currentRow._opened;
        }
    };

    self.openCadastramentoProduto = function() {
        if (General.getFieldValue('CDFILIAL', 'estProdutoUnidadeTabbed')) {
            ScreenService.openSwipe(templateManager.container.getWidget("cadastramentoProdutoTabbed"));
        }
        else {
            ScreenService.showMessage("É necessário filtrar por uma unidade.");
        }
    };

    self.openCadastramentoTitulo = function() {
        ScreenService.openSwipe(templateManager.container.getWidget("cadastramentoTituloTabbed"));
    };

    self.saveCadastramentoProduto = function(widget) {
        if (cadastramentoProdutoIsValid(widget)) {
            if (widget.currentRow.IDTIPOCAD == 'P') {
                var emptyContas = !produtoFields.some(function(fieldName) {
                    return fieldName.indexOf("CDCTBL") !== -1 && !!widget.currentRow[fieldName];
                });
                widget.currentRow.CDFILIALPROD = General.getFieldValue('CDFILIAL', 'estProdutoUnidadeTabbed');
                if (emptyContas) {
                    ScreenService.confirmMessage("Apagar todas as contas cadastradas para o intervalo de produtos informados?").then(function() {
                        callCadastroProduto(widget);
                    });
                }
                else {
                    callCadastroProduto(widget);
                }
            }
            else {
                callCadastroProduto(widget);
            }
        }
    };

    self.saveCadastramentoTitulo = function(widget) {
        if (widget.isValid()) {
            General.callRestEngine("ctb#/parametros_contabilizacao_cadastratitulo", "Row", widget.currentRow).then(function() {
                self.closeCadastramentoTitulo().then(function() {
                    ScreenService.showMessage("Replicação de parâmetros feita com sucesso.");
                });
            }).catch(function(error) {
                var errorMessage = 'Timeout';
                if (error.data) {
                    errorMessage = error.data.error;
                }
                ScreenService.showMessage(errorMessage);
            });
        }
    };

    self.setContctblMask = function() {
       General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []).then(function(response) {
            var paramgeral = response.dataset.paramgeral[0];
            contctblMask = paramgeral.CDPICTCCTB;
       });
    };

    self.showDatasourceLoadingError = function(data, widget) {
        widget.dataSource.data = [];
        var errorMessage = 'Timeout';
        if (data && data.error) {
            errorMessage = data.error;
        }
        ScreenService.showMessage(errorMessage);
    };

    self.toggleDependentFieldsReadOnly = function(parentField) {
        var widget = parentField.widget;
        var dependentFields = parentField.dependentFields || [];
        var readOnly = !parentField.value();
        dependentFields.forEach(function(fieldName) {
            var dependentField = widget.getField(fieldName);
            dependentField.readOnly = readOnly;
            dependentField.toReload = true;
            dependentField.setValue(null);
        });
    };

    self.toggleReplicacaoAlteracao = function(acaoField) {
        var contaField = acaoField.widget.getField("CD" + acaoField.name.substring(2));
        contaField.readOnly = acaoField.value() == 'R';
        contaField.setValue(null);
        contaField.widget.currentRow["CD" + acaoField.name.substring(2)] = null;
    };

    self.toggleUnidadeDestinoReadonly = function(widget) {
        var unidadeDestinoField = widget.getField('CDFILIALDEST');
        unidadeDestinoField.readOnly = !(widget.currentRow.CDFILIALORIG && widget.currentRow.T_CDFILIALDEST == 'L');
        unidadeDestinoField.validations = unidadeDestinoField.readOnly ? {} : {required: true};
        unidadeDestinoField.setValue([]);
    };

    self.toggleTipoCadastroProduto = function(widget) {
        var produtoIsSelected = widget.currentRow.IDTIPOCAD == 'P';
        Object.keys(unidadeFields).forEach(function(fieldName) {
            var field = widget.getField(fieldName);
            field.readOnly = produtoIsSelected;
            field.setValue(unidadeFields[fieldName]);
        });
        widget.currentRow.CDFILIALORIG = null;
        widget.getField("CDFILIALDEST").readOnly = true;
        produtoFields.forEach(function(fieldName) {
            var field = widget.getField(fieldName);
            field.readOnly = !produtoIsSelected || field.name.indexOf('NM') !== -1;
            field.setValue(null);
        });

        widget.currentRow.NMFILIALDEST = [];
        widget.getField("CDPRODINI").validations = produtoIsSelected ? {required: true} : {};
        widget.getField("CDPRODFIM").validations = produtoIsSelected ? {required: true} : {};
        widget.getField("NMFILIALORIG").validations = !produtoIsSelected ? {required: true} : {};
        widget.getField("T_CDFILIALDEST").validations = !produtoIsSelected ? {required: true} : {};
        widget.getField("CDFILIALDEST").validations = {};
    };

};

Configuration(function(ContextRegister){
    ContextRegister.register('Ger02900_ParametrosContabilizacao_Controller', Ger02900_ParametrosContabilizacao_Controller);
});

// FILE: ./assets/js/controllers/Ger06100_Conta_Contabil_Controller.js
var Ger06100_Conta_Contabil_Controller = function(ScreenService, templateManager, General, Ger06100_Conta_Contabil_Service){
    
    var MSG_MASCARA           = 'Máscara de Conta Contábil não Cadastrada.'; 
    var MSG_EXLUIR            = 'Exclusão não permitida. Existem contas contábeis relacionadas.'; 
    var MSG_PRENCHIMENTONIVEL = 'Conta Contábil informada com preenchimento de nível inválido.'; 
    var MSG_NIVELANTERIOR     = 'Nível anterior da conta contábil não cadastrado.'; 
    var MSG_INTERVALOCONTA    = 'Conta Contábil Final deve ser maior ou igual a Conta Contábil Inicial.'; 
    var MSG_SUCESSOCADASTRO   = 'Operação realizada com sucesso.';
    var IDENTIFICADOR  = {
    	"A":"Ativo",
    	"P":"Passivo",
    	"R":"Receita",
    	"D":"Despesa",
    	"C":"Custo",
    	"N":"Não tem"
    };
    
    this.afterMoveRowContaContabil = function (widget){
    	var mascara               = getLocalVar('CDPICTCCTB');  
    	var widgetSwipe           = templateManager.container.getWidget('swipeContaContabil');
    	var formContaContabil     = templateManager.container.getWidget('formContaContabil');
       	var widgetContaCorrelatas = templateManager.container.getWidget('widgetSubContas');
       	
       	ScreenService.openSwipe(widgetSwipe);
    	formContaContabil.reload([], false).then(
    	    function (success) {
				// para mostrar 'Não tem' caso o valor do campo seja null
				if(!formContaContabil.currentRow.IDTIPOCOME){
				    formContaContabil.currentRow.IDTIPOCOME =' ';
				}
				controlaWidgetContasCorrelatas(formContaContabil);
			}
		);
    	widgetContaCorrelatas.reload();
    	formContaContabil.getField('CDCONTCTBL').mask.params.mask = mascara;
    	
    };
    
    this.cancelar = function (widget){
    	var formContaContabil   = templateManager.container.getWidget('formContaContabil');
    	var widgetContaContabil = templateManager.container.getWidget('widgetContaContabil');
    	General.widgetCancelForm(widget);
    	if(widget.currentRow.__is_new){
    		ScreenService.closeSwipe();
    		widgetContaContabil.activate();
    	}
    	controlaWidgetContasCorrelatas(formContaContabil);
    };
    
    this.voltar = function (widget){
    	var widgetContaContabil = templateManager.container.getWidget('widgetContaContabil');
    	ScreenService.goBack();
    	widgetContaContabil.activate();
    };
    
    this.addContaContabil = function (widget){
        var mascara = getLocalVar('CDPICTCCTB');  
        if(mascara){
			General.justInteger('#CDCONTREDU');
			var widgetSwipe       = templateManager.container.getWidget('swipeContaContabil');
	    	var formContaContabil = templateManager.container.getWidget('formContaContabil');
	    	ScreenService.openSwipe(widgetSwipe);
	    	formContaContabil.getField('CDCONTCTBL').mask.params.mask = '?'+mascara;
	    	General.widgetEdit(formContaContabil);
	    	formContaContabil.currentRow = {"__is_new":true, "IDCONTCCUS":"O",'IDTIPOCOME':" ","IDPADRREL":"N", "IDNATUCONT":"00",'CDRATEIO':'','IDTIPOPESS':null,"CDINDPLACON":null,'CDCTBLINTE':null,'CDCONTPLANREFE':null,'CDCONTCTBLANALI':null,'CDCONTREFEAUX':null,'CDCONTREFEPRE':null};
	    	widget.descriptionOrder = '';
	    	this.controlaCamposNivelConta(formContaContabil);
		}else{
			ScreenService.showMessage(MSG_MASCARA);
		}
		
    };
    
    this.editarContaContabil = function (widget){
    	General.widgetEdit(widget);
    	General.justInteger('#CDCONTREDU');
    	this.controlaCamposNivelConta(widget);	
    };
    
    this.deletarContaContabil = function (widget){
		var nivelMascara  = General.getLevelByMask('CDPICTCCTB',1);
		if (parseFloat(widget.currentRow.CDNVCONTCTBL) === nivelMascara.length ){
    		this.delete(widget);
		}
    	else{
    		Ger06100_Conta_Contabil_Service.verificaExclusao(widget.currentRow).then(
    			function(success) {
                	var dataSet = success.dataset.contctbl;
                	if(dataSet.length ===0){
                	   this.delete(widget);
                	}else{
                		ScreenService.showMessage(MSG_EXLUIR);
                	}
            	}.bind(this),
            	function(callback){
                	if(callback.data){
                		ScreenService.showMessage(callback.data.error);
                	}
            	}
            );
    	}
	};
    
    this.carregarDataSource = function(args){
        var widget = args.owner;
        if(widget.dataSource.data.length >0)
        	widget.currentRow = widget.dataSource.data[0];	
        else
        	widget.currentRow = {"__is_new":true};
        
    };
    
    this.verificaDataField = function (field, msg){
       	field.reload().then(
    	    function (success) {
				if(field.dataSource.data.length ===0){
				    ScreenService.showMessage(msg);
				}
			}
		); 
    };
    
    this.controlaCampoContaVertical = function (field){
    	var widget = field.widget;
    	var campoContaVertical = widget.getField('CDCONTCTBLANALI');
    	if(field.value()==='R')
    		campoContaVertical.readOnly = true;	
    	else
    		campoContaVertical.readOnly = false;
    };
    
    //Realiza o controle de campos que são habilidatos apenas quando a conta for de nível completo 
    this.controlaCamposNivelConta = function (widget){
    	
    	var campos        = ['IDCONTCCUS','IDTIPOCOME','IDPADRREL','CDCONTPLANREFE','CDCONTREFEPRE','CDCONTREFEAUX','CDCONTREFEIMUISEN'];	
    	var nivelMascara  = General.getLevelByMask('CDPICTCCTB',1);
    	var readOnly      = true;
    	var contaVertical = widget.getField('CDCONTCTBLANALI');
    	
    	if (parseFloat(widget.currentRow.CDNVCONTCTBL) === nivelMascara.length )
    		readOnly = false;
    	campos.forEach(function(campo) {
		    widget.getField(campo).readOnly = readOnly;
		});
		
		
		if(widget.currentRow.CDNVCONTCTBL){
			if(parseFloat(widget.currentRow.CDNVCONTCTBL) > 1 && widget.currentRow.IDCONTCCUS !=='R')
				contaVertical.readOnly = false;
			else
				contaVertical.readOnly = true;	
		}
		else{
			contaVertical.readOnly = true;
		}
		
    };
   
	// controla status de Tabbes de Sub contas correlatas de acordo com as condições definidas
	var controlaWidgetContasCorrelatas = function (widget){
		var widgetContaCorrelatas = templateManager.container.getWidget('widgetSubContas');
		var nivelMascara          = General.getLevelByMask('CDPICTCCTB',1);
			if (parseFloat(widget.currentRow.CDNVCONTCTBL) === nivelMascara.length )
    			widgetContaCorrelatas.enabled = true;
			else 
				widgetContaCorrelatas.enabled = false;
	};
	
	this.validaDataContaContabil = function (field, campoData){
		if(field.value()){
			var widget = field.widget;
			var resul =  Ger06100_Conta_Contabil_Service.validaDataContaContabil(widget.currentRow, campoData);
			// caso a data não passe na validação
			if(!resul){
				ScreenService.confirmMessage(ScreenService.i18n('Conta referencial com data de validade expirada. Deseja usá-la assim mesmo?'), 'question', 
					function (success) {}, 
					function (error) {
						field.value('');
					}
				);
				
			}	
		}
	};
	
	this.delete = function (widget){
		var widgetContaContabil = templateManager.container.getWidget('widgetContaContabil');
		ScreenService.confirmMessage(ScreenService.i18n('Delete Register?'), 'question', function (success) {
			widget.removeRow().then(
				function () {
					ScreenService.closeSwipe().then(function () {
						widgetContaContabil.activate();
						widgetContaContabil.reload();
						//ScreenService.showMessage('Deletado com sucesso.');
						
					});
				}, 
				function (error) {
					if (error.data && error.data.error.indexOf('ORA-02292') !== -1) {
						ScreenService.showMessage('Exclusão não permitida! O registro possui registros filhos.');
					} else {
						ScreenService.showMessage(error.data.error);
					}
				
				}
			);
		});
	};
	
	var salvarContaContabil = function (widget){
		var nivelMascara        = General.getLevelByMask('CDPICTCCTB',1);
		var widgetContaContabil = templateManager.container.getWidget('widgetContaContabil');
		var formContaContabil   = templateManager.container.getWidget('formContaContabil');
		var tipoConta           = widget.currentRow.IDTIPOCOME;
		Ger06100_Conta_Contabil_Service.verificaValores(widget.currentRow, nivelMascara);
		Ger06100_Conta_Contabil_Service.salvarContaContabil(widget.currentRow).then(
			function(success) {
            	controlaWidgetContasCorrelatas(formContaContabil);
            	if (widget.currentRow.__is_new) {
					widget.template = widget.templateToView;
					widget.view();
					ScreenService.closeSwipe();
					widgetContaContabil.activate();
					widgetContaContabil.reload();
				} else {
					if(!widget.currentRow.IDTIPOCOME){
						widget.currentRow.IDTIPOCOME = ' ';	
					}
					widget.activate();
					widget.template = widget.templateToView;
					widget.view();
				}
        	}.bind(this),
        	function(callback){
            	widget.getField('CDCONTCTBL').element.focus();
            	widget.currentRow.IDTIPOCOME = tipoConta;
            	if(callback.data){
            		ScreenService.showMessage(callback.data.error);
            	}
        	}
        );
	};

	this.salvarSubContas = function (widget){
		var widgetPai = templateManager.container.getWidget('widgetContaContabil');
		if(widget.isValid()){
			if(widget.currentRow.__is_new){
				widget.currentRow.CDCONTCTBL = widgetPai.currentRow.CDCONTCTBL;
			}
			widget.currentRow.CDCONTACORRE =widget.currentRow.CDCONTACORRE.replace(/[^0-9]/g,'');
			Ger06100_Conta_Contabil_Service.salvarSubContas(widget.currentRow).then(
    			function(success) {
                	widget.activate();
					if (widget.currentRow.__is_new) {
						widget.list(true);
						ScreenService.goBack();
						widget.reload();
					} else {
						widget.computeDescriptionOrder();
						widget.view();
					}
            	}.bind(this),
            	function(callback){
                	if(callback.data){
                		ScreenService.showMessage(callback.data.error);
                	}
            	}
            );
		}
	};
	
	this.deletarSubContas = function (widget){
		ScreenService.confirmMessage(ScreenService.i18n('Delete Register?'), 'question', function (success) {
			Ger06100_Conta_Contabil_Service.deletarSubContas(widget.currentRow).then(
    			function(success) {
                	ScreenService.closeSwipe().then(function () {
						widget.activate();
					});
					widget.reload();
					ScreenService.showMessage('Deletado com sucesso.');
            	},
            	function(error){
                	if (error.data && error.data.error.indexOf('ORA-02292') !== -1) {
						ScreenService.showMessage('Exclusão não permitida! O registro possui registros filhos.');
					} else {
						ScreenService.showMessage(error.data.error);
					}
            	}
            );
		});
	};
	
	/*
	Valida se o nível está preenchido corretamente.
	Valida se existe conta com nivel anterior cadastrado;
	*/
	this.validacoesSalvarContaContabil = function (widget){
		if(widget.isValid()){
			var cdcontctbl   = widget.getField('CDCONTCTBL').value().replace(/[^0-9]/g,'');
			var nivelMascara = General.getLevelByMask('CDPICTCCTB',1);
			if(Ger06100_Conta_Contabil_Service.validaPreenchimentonivel(cdcontctbl, nivelMascara)){
				widget.currentRow.CDNVCONTCTBL = Ger06100_Conta_Contabil_Service.retornaNivelConta(cdcontctbl, nivelMascara);
				widget.currentRow.CDCONTANTE   = Ger06100_Conta_Contabil_Service.retornaContaPai(cdcontctbl, widget.currentRow.CDNVCONTCTBL, nivelMascara);
				salvarContaContabil(widget);
			}else{
				ScreenService.showMessage(MSG_PRENCHIMENTONIVEL);
			}
		}
	};
	
	/* Função que retorna o nivel da conta e a conta PAI.
	Valida se o nível está preenchido corretamente.
	Valida se existe conta com nivel anterior cadastrado;
	*/
	this.propriedadesContaContabil = function (field){
		var widget = field.widget;
		if(field.value()){
			var cdcontctbl     = field.value();
			var nivelMascara   = General.getLevelByMask('CDPICTCCTB',1);
			cdcontctbl         = cdcontctbl.replace(/[^0-9]/g,'');
			var resultadoNivel = Ger06100_Conta_Contabil_Service.validaPreenchimentonivel(cdcontctbl, nivelMascara);
			
			if(resultadoNivel){
				widget.currentRow.CDNVCONTCTBL = Ger06100_Conta_Contabil_Service.retornaNivelConta(cdcontctbl, nivelMascara);
				widget.currentRow.CDCONTANTE   = Ger06100_Conta_Contabil_Service.retornaContaPai(cdcontctbl, widget.currentRow.CDNVCONTCTBL, nivelMascara);
				//Contas de Nível 1 não possuem PAI
				if( parseFloat (widget.currentRow.CDNVCONTCTBL) > 1){
					Ger06100_Conta_Contabil_Service.verificaContaNivelAnterior(widget.currentRow).then(
	 	    			function(success) {
		                	var contasNivelAnterior = success.dataset.contctbl;
		                	if(contasNivelAnterior.length>0){
		                		this.controlaCamposNivelConta(widget);
		                		widget.currentRow.CDCONTREDU = widget.currentRow.CDCONTCTBL.replace(/[^0-9]/g,'');
		                	}
		                	else{
		                		ScreenService.showMessage(MSG_NIVELANTERIOR);
		                		widget.currentRow.CDCONTANTE   = null;
								widget.currentRow.CDNVCONTCTBL = null;
		                		this.controlaCamposNivelConta(widget);
		                	}
		            	}.bind(this),
		            	function(callback){
		                	if(callback.data){
		                		ScreenService.showMessage(callback.data.error);
		                		this.controlaCamposNivelConta(widget);
		                	}
		            	}
		            ); 
				}
				else{
					this.controlaCamposNivelConta(widget);
					widget.currentRow.CDCONTREDU = widget.currentRow.CDCONTCTBL;
				}
				
			}else{
				ScreenService.showMessage(MSG_PRENCHIMENTONIVEL);
				widget.currentRow.CDCONTANTE   = null;
				widget.currentRow.CDNVCONTCTBL = null;
				this.controlaCamposNivelConta(widget);
			}	
		}else{
			widget.currentRow.CDCONTANTE   = null;
			widget.currentRow.CDNVCONTCTBL = null;
		}
	};
	
	this.validacoesCadastramentoAutomatico = function (widget){
		if(widget.isValid()){
			switch(widget.currentRow.TIPOCADASTRO) {
			    case '1':
			        if( Ger06100_Conta_Contabil_Service.validaIntervaloContas(widget.currentRow.P_CONTAINICIAL,widget.currentRow.P_CONTAFINAL) ){
			           	ScreenService.confirmMessage(ScreenService.i18n("Confirma o cadastramento automático do Indentificador Padrão '"+IDENTIFICADOR[widget.currentRow.P_IDPADRREL]+"' para as Contas Contábeis informadas ?"), 'question', 
							function (success) {
								widget.currentRow.P_CONTAINICIAL = widget.currentRow.P_CONTAINICIAL.replace(/[^0-9]/g,'');
								widget.currentRow.P_CONTAFINAL   = widget.currentRow.P_CONTAFINAL.replace(/[^0-9]/g,'');
								salvarCadastramentoAutomatico(widget);
							} 
						);
			        }else{
			        	ScreenService.showMessage(MSG_INTERVALOCONTA);
			        }
			        break;
			    case '2':
			        if( Ger06100_Conta_Contabil_Service.validaIntervaloContas(widget.currentRow.P_CONTAINICIAL,widget.currentRow.P_CONTAFINAL) ){
			           	ScreenService.confirmMessage(ScreenService.i18n("Deseja cadastrar a conta base informada para ser utilizada na Análise Vertical para o intervalo de contas informado ?"), 'question', 
							function (success) {
								widget.currentRow.P_CONTAINICIAL = widget.currentRow.P_CONTAINICIAL.replace(/[^0-9]/g,'');
								widget.currentRow.P_CONTAFINAL   = widget.currentRow.P_CONTAFINAL.replace(/[^0-9]/g,'');
								salvarCadastramentoAutomatico(widget);
							} 
						);
			        }else{
			        	ScreenService.showMessage(MSG_INTERVALOCONTA);
			        }
			        break;
			    case '3':
			    	ScreenService.confirmMessage(ScreenService.i18n("Confirma a alteração de todas as contas contábeis parametrizadas com esta conta referencial "+widget.currentRow.P_CONTANTIGA +", para está conta referencial "+widget.currentRow.P_CONTNOVA+" ?"), 'question', 
						function (success) {
							salvarCadastramentoAutomatico(widget);
						} 
					);
			    	break;
			}
		}	
	};
	
	var salvarCadastramentoAutomatico = function (widget){
		var widgetContaContabil = templateManager.container.getWidget('widgetContaContabil');
		if(widget.isValid()){
			Ger06100_Conta_Contabil_Service.salvarCadastramentoAutomatico(widget.currentRow).then(
				function(success) {
	            	ScreenService.closePopup();
	            	widgetContaContabil.activate();
	            	widgetContaContabil.reload();
	            	ScreenService.showMessage(MSG_SUCESSOCADASTRO);
	            	
	        	}.bind(this),
	        	function(callback){
	            	if(callback.data){
	            		ScreenService.showMessage(callback.data.error);
	            	}
	        	}
	        );	
		}
	};
	
	this.controlaCamposCadastramentoAutomatico = function (widget){
		var camposTipo1 = ['P_CONTAINICIAL','P_CONTAFINAL','P_IDPADRREL'];
		var camposTipo2 = ['P_CONTAINICIAL','P_CONTAFINAL','P_CONTABASE'];
		var camposTipo3 = ['P_CONTANTIGA','P_CONTNOVA','TIPOCONTA'];
		var campoAntigo = widget.getField('P_CONTANTIGA');
		var campoNovo   = widget.getField('P_CONTNOVA');
		
		switch( widget.getField('TIPOCADASTRO').value() ) {
		    case '1':
		        this.statusField(camposTipo2,widget, false);
		        this.statusField(camposTipo3,widget, false);
		        this.statusField(camposTipo1,widget, true);
		        break;
		    case '2':
		        this.statusField(camposTipo1,widget, false);
		        this.statusField(camposTipo3,widget, false);
		        this.statusField(camposTipo2,widget, true);
		        break;
       	    case '3':
		        widget.currentRow.TIPOCONTA='ECD';
		        campoAntigo.dataSource.name ='ctb#/crud/contrefe';
				campoNovo.dataSource.name   ='ctb#/crud/contrefe';
		        this.statusField(camposTipo1,widget, false);
		        this.statusField(camposTipo2,widget, false);
		        this.statusField(camposTipo3,widget, true);
		        break;
		}
	};
	
	this.statusField = function  (nomesFileds, widget, visibilidade){
		nomesFileds.forEach(function(nome) {
		    widget.getField(nome).isVisible = visibilidade;
		    if(visibilidade)
		    	 widget.getField(nome).validations.required = true;
			else
				delete (widget.getField(nome).validations.require);
			
		});
		
	};
	
	this.controlaTipoContaReferencial = function(field){
		var widget = field.widget;
		var campoAntigo = widget.getField('P_CONTANTIGA');
		var campoNovo   = widget.getField('P_CONTNOVA');
		if(field.value()==='ECD'){
			campoAntigo.dataSource.name ='ctb#/crud/contrefe';
			campoNovo.dataSource.name   ='ctb#/crud/contrefe';
		}
		else if(field.value()==='AUX'){
			campoAntigo.dataSource.name ='ctb#/crud/contrefeaux_contacontabil';
			campoNovo.dataSource.name   ='ctb#/crud/contrefeaux_contacontabil';
		}
		campoAntigo.value('');
		campoNovo.value('');
	};

};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ger06100_Conta_Contabil_Controller', Ger06100_Conta_Contabil_Controller);
});

// FILE: ./assets/js/controllers/Ger06200_HistoricoPadrao_Controller.js
var Ger06200_HistoricoPadrao_Controller = function(ScreenService, templateManager, ZHPromise, General,Ger06200_HistoricoPadrao_Service) {

    var self = this;
    
    this.vdHistExiste = function(cdhistpadr){
       return Ger06200_HistoricoPadrao_Service.vdHistExiste(cdhistpadr); 
    };
    
    
    
    this.saveHistPadr = function(row){
        var widget = templateManager.container.getWidget('HistoricoPadrao');
        if(widget.isValid()){
            if(row.__is_new == true){
                this.vdHistExiste(row.CDHISTPADR).then(function(histpadr){
                    
                    if(!histpadr.dataset.histpadr[0]){
                        Ger06200_HistoricoPadrao_Service.saveHistPadr(row).then(function(){
                            ScreenService.showMessage("Salvo com Sucesso.");
                            row.__is_new = false;
                            ScreenService.closeSwipe();
                            widget.reload();
                        }, function(error){
                            ScreenService.showMessage(error.data.error);
                        });
                    }else{
                        ScreenService.showMessage("Histórico Padrão já Cadastrado.");
                    }
                    
                });
            }else{
                Ger06200_HistoricoPadrao_Service.saveHistPadr(row).then(function(){
                ScreenService.showMessage("Salvo com Sucesso.");
                ScreenService.closeSwipe();
                });
            }
        }
    };
    
    /**
     * Confirmar Edição
     */
    self.confirmaEditar = function(){
        var widget = templateManager.container.getWidget('HistoricoPadrao');

        widget.getField('DSHISTPADR').focused = true;
        delete widget.getField('CDHISTPADR').focused;

    };
    
    /**
     * Confirmar Adição
     */
    self.confirmaAdicionar = function(){
        var widget = templateManager.container.getWidget('HistoricoPadrao');

        widget.getField('CDHISTPADR').focused = true;
        delete widget.getField('DSHISTPADR').focused;

    };
    
};

Configuration(function(ContextRegister){
    ContextRegister.register('Ger06200_HistoricoPadrao_Controller', Ger06200_HistoricoPadrao_Controller);
});

// FILE: ./assets/js/controllers/Ger06300_CentroDeCusto_Controller.js
function Ger06300_CentroDeCusto_Controller(General, ScreenService, templateManager) {

	var hasDuplicateKeys = function(widget) {
		var codFilial = widget.currentRow.CDFILIAL;
		var codCentCust = widget.currentRow.CDCENTCUST;
		var arr = widget.dataSource.data.filter(function(data) {
			return ((data.CDCENTCUST === codCentCust) && (data.CDFILIAL === codFilial));
		});
		return (arr.length > 1);
	};

	this.saveCentroDeCusto = function(widget) {
		if(widget.isValid()){
			widget.saveRow().then(function() {
				if (widget.currentRow.__is_new) {
					widget.reload();
					widget.list(true);
					ScreenService.goBack();
				} else {
					widget.reload();
					widget.view();
				}
				var unidadeWidget = templateManager.container.getWidget('centroCustoUnidade');
				if (typeof unidadeWidget.dataSource.data !== "undefined") {
					var matchingRows = unidadeWidget.dataSource.data.filter(function(row) {
				  	return (row.CDCENTCUST == widget.currentRow.CDCENTCUST);
					});
				if (matchingRows.length > 0) {
					unidadeWidget.reload();
				}
				unidadeWidget.getField("NMCENTCUST").reload();
			}

			},function(callback){
					if(callback.data){
						ScreenService.showMessage(callback.data.error);
					}
			});
		}

	};

	this.saveCentroDeCustoUnidade = function(widget) {
		var unidadeFiltro = templateManager.container.getWidget('unidadeTabbed').getField('NMFILIAL').value();
		var unidadeWidget = templateManager.container.getWidget('centroCustoUnidade').getField('NMFILIAL').value();

		if (widget.isValid()) {
			if (!hasDuplicateKeys(widget)) {
				widget.saveRow(widget).then(function(success) {
					if (widget.currentRow.__is_new) {
						widget.reload();
						widget.list(true);
						ScreenService.goBack();
					}
					else {
						widget.reload();
						widget.view();
					}
					if(unidadeFiltro!==unidadeWidget){
						widget.reload();
					}

					//verifyAndChangeUnidade(widget);
				}, function(callback) {
						if(callback.data){
							ScreenService.showMessage(callback.data.error);
						}
					//verifyAndChangeUnidade(widget);
				});
			}
			else {
				ScreenService.showMessage("Centro de Custo já cadastrado para a unidade selecionada.");
			}
		}
	};

	this.setDefaultUnidade = function(childWidget) {
		widget = childWidget.parent;
		childWidget.currentRow.CDFILIAL = widget.currentRow.CDFILIAL;
		childWidget.currentRow.NMFILIAL = widget.currentRow.NMFILIAL;
	};

	this.updateGridFilter = function(widget) {
		childWidget = templateManager.container.getWidget("centroCustoUnidade");
		childWidget.dataSourceFilter[0].value = widget.currentRow.CDFILIAL;
		childWidget.reload();
	};
	/*
	var verifyAndChangeUnidade = function(widget) {
		var tabbedWidget = templateManager.container.getWidget("unidadeTabbed");
		if (widget.currentRow.CDFILIAL != tabbedWidget.currentRow.CDFILIAL) {
			tabbedWidget.currentRow.CDFILIAL = widget.currentRow.CDFILIAL;
			tabbedWidget.currentRow.NMFILIAL = widget.currentRow.NMFILIAL;
			widget.dataSourceFilter[0].value = widget.currentRow.CDFILIAL;
			widget.reload();
		}
	};
	*/
	this.mascara = function(){
		setTimeout(function(){
			$('#CDCENTCUST').mask('?9999');
		},500);
	};
	this.setDefaultValueCentroCustoPadrao = function(args){
		var centroCustoPadrao = templateManager.container.getWidget('centroCustoUnidade').getField('CENTCUSTPADRAO');
		centroCustoPadrao.value('S');
	};
}

Configuration(function (ContextRegister) {
	ContextRegister.register('Ger06300_CentroDeCusto_Controller', Ger06300_CentroDeCusto_Controller);
});

// FILE: ./assets/js/controllers/Ger07700_Auditores_Independentes_Controller.js
var Ger07700_Auditores_Independentes_Controller = function(ScreenService, templateManager, General) {

  this.createAuditor = function(widget) {
    widget.newRow();
    widget.currentRow.__is_new = true;
  };
  
  this.loadEmpresasRelacionadas = function(widget) {
    widget.reload();
    var gridEmpresas = templateManager.container.getWidget("grid_empresas_relacionadas");
    
    if (widget.currentRow.__is_new) {
      
      // gridEmpresas.isVisible = false;
      
    } else {
      gridEmpresas.dataSourceFilter = [{
        name: "NRSEQAUDITOR",
        operator: "=",
        value: widget.currentRow.NRSEQUENCIAL
      }];
      
      gridEmpresas.isVisible = true;
      
    } 
    
    templateManager.updateTemplate();
    widget.reload();
  };
  
  this.createRelacao = function(widget) {
    var gridAuditores = templateManager.container.getWidget("grid_auditores");
    widget.newRow();
    widget.currentRow.__is_new = true;
    widget.currentRow.NRSEQAUDITOR = gridAuditores.currentRow.NRSEQUENCIAL; 
  };
  
  //General.widgetCancelForm não funciona aqui
  this.cancelSaveRelacao = function(widget) {
    
    widget.dataSource.data.pop();
    widget.list();
    ScreenService.closeSwipe();
    
  };
  
  this.filterNome = function(widget) {
    
    widget.getField('DSREGISTROCVM').filterProperties.readOnly = true;
    widget.reload();
  };
  
  this.filterCVM = function(widget) {
    
    widget.getField('NMAUDITOR').filterProperties.readOnly = true;
    widget.reload();
  };
  
  this.resetFilters = function(widget) {
    
    widget.getField('NMAUDITOR').filterProperties.readOnly = false;
    widget.getField('DSREGISTROCVM').filterProperties.readOnly = false;
    widget.reload();
    
  };
  
  this.saveAuditor = function(widget) {
    if(widget.isValid()){
        var filter = [
          {
              "name": "DSREGISTROCVM",
              "operator": "IN",
              "value": widget.currentRow.DSREGISTROCVM
          } 
        ];
        
        var qtRegistros = widget.dataSource.data.filter(function(registros){
            if(registros.DSREGISTROCVM == widget.currentRow.DSREGISTROCVM && registros.NRSEQUENCIAL != widget.currentRow.NRSEQUENCIAL)
              return true;
            else
              return false;
        });
        
        if(qtRegistros.length > 0)
          ScreenService.showMessage("Operação Bloqueada. Registro na CVM já existente.");
        else{
          General.saveCrud(widget).then(function(sucess){
            widget.mode = "list";
            widget.reload();
            General.changeWidgetAcessibility(widget.widgets, true);
          }.bind(this));
        }
    }
  };
  
};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ger07700_Auditores_Independentes_Controller', Ger07700_Auditores_Independentes_Controller);
});

// FILE: ./assets/js/controllers/Ger08000_Contador_Controller.js
var Ger08000_Contador_Controller = function(ScreenService, templateManager, General, Ger08000_Contador_Service, Endereco){
   var self = this;
   this.setDataSourceFilterEstado = function(widget, field_name){
        widget = templateManager.container.getWidget('widgetContador');
        this.habilitaEstado(widget, field_name);
        this.habilitaMunicipio(widget, null);
        this.habilitaEndereco(widget);
        if (!widget.getField('NMESTADO').readOnly){
            widget.getField('NMESTADO').dataSourceFilter = [
                {
                  "name": "CDPAIS",
                  "operator": "=",
                  "value": widget.currentRow.CDPAIS
                }
            ];
            widget.getField('NMESTADO').reload();
            widget.getField('NMESTADOCRC').dataSourceFilter = [
                {
                  "name": "CDPAIS",
                  "operator": "=",
                  "value": widget.currentRow.CDPAIS
                }
            ];
            widget.getField('NMESTADOCRC').reload();
            widget.getField('NMESTADOCRP').dataSourceFilter = [
                {
                  "name": "CDPAIS",
                  "operator": "=",
                  "value": widget.currentRow.CDPAIS
                }
            ];
            widget.getField('NMESTADOCRP').reload();
        }
   };


  this.setDataSourceFilterMunicipio = function(widget, field_name){
        this.habilitaMunicipio(widget, field_name);
        this.habilitaEndereco(widget);
        if (!widget.getField('NMMUNICIPIO').readOnly){
            widget.getField('NMMUNICIPIO').dataSourceFilter = [
                {
                  "name": "CDPAIS",
                  "operator": "=",
                  "value": widget.currentRow.CDPAIS
                },
                {
                    "name": "SGESTADO",
                    "operator": "=",
                    "value": widget.currentRow.SGESTADO
                }
            ];
            widget.getField('NMMUNICIPIO').reload();
        }
  };
  
    /* Funcao Concaternar Logradouro numero e nome de rua FROM ./assets/js/controllers/Ger00200_Empresa_Controller.js */
    this.concatenaCamposEmpresa = function(row){
         
         if(!row.DSLOGRADOUROSEP){
             row.DSENDECONTDR  = row.DSENDEIESTSEP+', '+row.NRENDEIESTSEP ;
         }else{
             row.DSENDECONTDR  = row.DSLOGRADOUROSEP+' '+row.DSENDEIESTSEP+', '+row.NRENDEIESTSEP ;
         }
    };

  this.save = function(){
      var widget = templateManager.container.getWidget('widgetContador');
      if (widget.isValid()){
            var paramsNewCode = widget.paramsNewCode;

            var keysParamsNewCode = Object.keys(paramsNewCode);
            keysParamsNewCode.forEach(function(value) {
                widget.currentRow[value] = paramsNewCode[value];
            });

            widget.currentRow.IDTPIJURCONT  = 'I'; // Valor Default
            widget.currentRow.NMCONTADOR    = widget.currentRow.NMCONTADOR.substr(0, 30);
            widget.currentRow.NMCONTATO2    = widget.currentRow.NMCONTADOR.substr(0, 20);
            widget.currentRow.NMRESPONSAVL  = widget.currentRow.NMCONTADOR;
            widget.currentRow.DSBAIRRO      = widget.currentRow.DSBAIRRO.substring(0,20);
            widget.currentRow.DSLOGRADOURO  = widget.currentRow.DSLOGRADOURO.substring(0,50);
            
            if (widget.isNewRow()){
                Ger08000_Contador_Service.verificaCdContador(widget.currentRow).then(function(){
                    
                    // Concatena os Campos if Logradouro {campo1 + campo2 + campo3 } else { campo1 + campo2 }
                    self.concatenaCamposEmpresa(widget.currentRow);
                    
                    // { Campo na tabela}  = { campo no front }
                    widget.currentRow.DSLOGRADOURO  = widget.currentRow.DSENDECONTDR;
                    
                    // Entao salva ...
                    Ger08000_Contador_Service.save(widget.currentRow).then(function(successData){
                        widget.currentRow.NRORG = successData.dataset.columnsToReturn[0].NRORG;
                        widget.currentRow.__is_new = false;
                        ScreenService.showMessage('Contador cadastrado com sucesso!');
                        widget.view();
                    });
                 })
                .catch(function(erroContadorCadastrado){
                    var errorMessage = 'Timeout';
                    if (erroContadorCadastrado.data) {
                        errorMessage = erroContadorCadastrado.data.error;
                    }
                    ScreenService.showMessage(errorMessage);
                });
            }else{
                
                // Concatena os Campos if Logradouro {campo1 + campo2 + campo3 } else { campo1 + campo2 }
                self.concatenaCamposEmpresa(widget.currentRow);
                    
                // { Campo na tabela}  = { campo no front }
                widget.currentRow.DSLOGRADOURO  = widget.currentRow.DSENDECONTDR;
                
                // Entao salva ...
                Ger08000_Contador_Service.save(widget.currentRow).then(function(){
                    ScreenService.showMessage('Cadastro alterado com sucesso!');
                    widget.view();
                })
                .catch(function(erroContadorCadastrado){
                    var errorMessage = 'Timeout';
                    if (erroContadorCadastrado.data) {
                        errorMessage = erroContadorCadastrado.data.error;
                    }
                    ScreenService.showMessage(errorMessage);
                });
            }

      }
  };

  this.habilitaEstado = function(widget, field_name){
      var boPaisVazio = !widget.currentRow.NMPAIS;
      widget.getField('NMESTADO').readOnly = boPaisVazio;
      widget.getField('NMESTADOCRC').readOnly = boPaisVazio;
      widget.getField('NMESTADOCRP').readOnly = boPaisVazio;
      if ((boPaisVazio) || (field_name == 'NMPAIS')){
            widget.currentRow.NMESTADO = '';
            widget.currentRow.SGESTADO = '';
            widget.currentRow.NMESTADOCRC = '';
            widget.currentRow.SGESTADOCRC = '';
            widget.currentRow.NMESTADOCRP = '';
            widget.currentRow.SGESTADOCRP = '';
      }
  };

  this.habilitaMunicipio = function(widget, field_name){
        var boEstadoVazio = !widget.currentRow.NMESTADO;
        widget.getField('NMMUNICIPIO').readOnly = boEstadoVazio;
        if ((boEstadoVazio) || (field_name == 'NMESTADO')){
          widget.currentRow.CDMUNICIPIO = '';
          widget.currentRow.NMMUNICIPIO = '';
        }
  };

  this.habilitaEndereco = function(widget){
        var boMunicipioVazio = !widget.currentRow.NMMUNICIPIO;
        widget.getField('DSBAIRRO').readOnly = boMunicipioVazio;
        // desnecessario widget.getField('DSLOGRADOURO').readOnly = boMunicipioVazio;
        // desnecessario widget.getField('DSCOMPLLOGRA').readOnly = boMunicipioVazio;

      if (boMunicipioVazio) {
            widget.currentRow.DSBAIRRO = '';
            // desnecessario widget.currentRow.DSLOGRADOURO = '';
            // desnecessario widget.currentRow.DSCOMPLLOGRA = '';
      }
  };

  this.setCamposInt = function(){
       General.justInteger('#CDCONTADOR');
       General.justInteger('#NRTELCONTATO');
       General.justInteger('#NRINSJURCONT');
       General.justInteger('#NRRAMALCONTA');
       General.justInteger('#NRANOCRP');
   };

  this.checkCEP = function(field){
        //gets needed values
        var widget = field.widget;
        var CEP = field.value();

        //checks valid masked CEP length existence
        if(CEP && CEP.length == 10) {
            //requests CEP validation from Correios
            Ger08000_Contador_Service.validateCEP(CEP).then(function(response) {
                var address = response.dataset.ENDERECO;

                //sets received data on current widget
                widget.currentRow.CDPAIS        = (address.CDPAIS)?             address.CDPAIS : '';
                widget.currentRow.NMPAIS        = (address.NMPAIS)?             address.NMPAIS : '';
                widget.currentRow.SGESTADO      = (address.SGESTADO)?         address.SGESTADO : '';
                widget.currentRow.NMESTADO      = (address.NMESTADO)?         address.NMESTADO : '';
                widget.currentRow.CDMUNICIPIO   = (address.CDMUNICIPIO)?   address.CDMUNICIPIO : '';
                widget.currentRow.NMMUNICIPIO   = (address.NMMUNICIPIO)?   address.NMMUNICIPIO : '';
                widget.currentRow.DSBAIRRO      = (address.NMBAIRRO)?         address.NMBAIRRO.substring(0, 20) : '';
                widget.currentRow.DSLOGRADOURO  = (address.DSENDERECO)?     address.DSENDERECO.substring(0, 50) : '';
                
                widget.currentRow.CDLOGRADOURO = (address.CDLOGRADOURO) ? address.CDLOGRADOURO : '';  // Marcoviny add
				widget.currentRow.DSLOGRADOUROSEP = (address.DSLOGRADOURO)   ? address.DSLOGRADOURO : ''; // Marcoviny add
				widget.currentRow.DSENDEIESTSEP = (address.DSENDERECO) ? address.DSENDERECO : ''; // Marcoviny add
				widget.currentRow.NRENDEIESTSEP = (address.NRENDEIESTSEP) ? address.NRENDEIESTSEP : ''; // Marcoviny add
                
                this.habilitaEstado(widget, null);
                this.habilitaMunicipio(widget, null);
                this.habilitaEndereco(widget);
                
            }.bind(this), function(error) { // o Bind serve para repassar o contexto do controller para o contexto da função
                var errorMessage = 'Timeout'; //default value

                //removes faulty CEP
                widget.currentRow.NRCEP = '';

                //if theres an appropriate error message, gets it
                if(error.data)
                    errorMessage = error.data.error;

                //shows error message
                ScreenService.showMessage("Erro na requisição do CEP '" + CEP + "': " + errorMessage, "warning");
            });
        }
  };
  
  this.validarCepEnd = function (args) {
		var widget = args.owner.owner.widget;
		var CEP = '';
		if (widget.name == 'widgetContador') {
			CEP = widget.currentRow.NRCEP;
		}
		if (CEP) {
			Endereco.buscarCep(CEP).then(function (response) {
				var endereco = response.dataset.ENDERECO;
				if (endereco) {
					if (widget.name == 'widgetContador') {
						widget.currentRow.NRCEP        = CEP;
    					widget.currentRow.CDPAIS       = (endereco.CDPAIS)       ? endereco.CDPAIS : '';
    					widget.currentRow.NMPAIS       = (endereco.NMPAIS)       ? endereco.NMPAIS : '';
    					widget.currentRow.SGESTADO     = (endereco.SGESTADO)     ? endereco.SGESTADO : '';
    					widget.currentRow.NMESTADO     = (endereco.NMESTADO)     ? endereco.NMESTADO : '';
    					widget.currentRow.CDMUNICIPIO  = (endereco.CDMUNICIPIO)  ? endereco.CDMUNICIPIO : '';
    					widget.currentRow.NMMUNICIPIO  = (endereco.NMMUNICIPIO)  ? endereco.NMMUNICIPIO : '';
    					widget.currentRow.CDBAIRRO     = (endereco.CDBAIRRO)     ? endereco.CDBAIRRO : '';
						widget.currentRow.DSBAIRRO     = (endereco.NMBAIRRO)     ? endereco.NMBAIRRO   : '';
						widget.currentRow.DSLOGRADOURO = (endereco.DSENDERECO)   ? endereco.DSENDERECO : '';
						
                        widget.currentRow.CDLOGRADOURO = (endereco.CDLOGRADOURO) ? endereco.CDLOGRADOURO : '';  // Marcoviny add
						widget.currentRow.DSLOGRADOUROSEP = (endereco.DSLOGRADOURO)   ? endereco.DSLOGRADOURO : ''; // Marcoviny add
						widget.currentRow.DSENDEIESTSEP = (endereco.DSENDERECO) ? endereco.DSENDERECO : ''; // Marcoviny add
						widget.currentRow.NRENDEIESTSEP = (endereco.NRENDEIESTSEP) ? endereco.NRENDEIESTSEP : ''; // Marcoviny add
						
					}
					this.verificaFieldOnChangePais(endereco);
					this.habilitaEstadoEmissao(widget);
					
				}
				if (response.dataset.ERRO) ScreenService.showMessage(response.dataset.ERRO.MESSAGE, "warning");
			}.bind(self));
		}
	};
	
	self.verificaFieldOnChangePais = function (endereco) {
		var widget = templateManager.container.getWidget('widgetContador');
		if (!endereco) {
			widget.getField('NMPAIS').value('');
			widget.getField('CDPAIS').value('');

			widget.getField('NMESTADO').readOnly = true;
			widget.getField('NMESTADO').value('');
			widget.getField('SGESTADO').value('');

			widget.getField('NMMUNICIPIO').readOnly = true;
			widget.getField('NMMUNICIPIO').value('');
			widget.getField('CDMUNICIPIO').value('');

			widget.getField('DSBAIRRO').readOnly = true;
			widget.getField('DSBAIRRO').value('');
			widget.getField('CDBAIRRO').value('');
			
			// desnecessario widget.getField('DSLOGRADOURO').readOnly = true;
			// desnecessario widget.getField('DSLOGRADOURO').value('');
			
			// desnecessario widget.getField('DSCOMPLLOGRA').readOnly = true;
			// desnecessario widget.getField('DSCOMPLLOGRA').value('');
		} else {
			var pais = endereco.NMPAIS;
			var estado = endereco.NMESTADO;
			var municipio = endereco.NMMUNICIPIO;
			if (!pais) {
				widget.getField('NMESTADO').readOnly = true;
				widget.getField('NMMUNICIPIO').readOnly = true;
				widget.getField('DSBAIRRO').readOnly = true;
				// desnecessario widget.getField('DSLOGRADOURO').readOnly = true;
				// desnecessario widget.getField('DSCOMPLLOGRA').readOnly = true;
			} else {
				if (!estado) {
					widget.getField('NMESTADO').readOnly = false;
					widget.getField('NMMUNICIPIO').readOnly = true;
					widget.getField('DSBAIRRO').readOnly = true;
				    // desnecessario widget.getField('DSLOGRADOURO').readOnly = true;
				    // desnecessario widget.getField('DSCOMPLLOGRA').readOnly = true;
				} else {
					widget.getField('NMESTADO').readOnly = false;
					if (!municipio) {
						widget.getField('NMMUNICIPIO').readOnly = false;
						widget.getField('DSBAIRRO').readOnly = true;
				        // desnecessario widget.getField('DSLOGRADOURO').readOnly = true;
				        // desnecessario widget.getField('DSCOMPLLOGRA').readOnly = true;
					} else {
						widget.getField('NMMUNICIPIO').readOnly = false;
						widget.getField('DSBAIRRO').readOnly = false;
				        // desnecessario widget.getField('DSLOGRADOURO').readOnly = false;
				        // desnecessario widget.getField('DSCOMPLLOGRA').readOnly = false;
					}
				}
			}
		}
	};
	
	self.habilitaEstadoEmissao = function (widget){
	    if(widget.currentRow.NMPAIS){
    	    widget.getField('NMESTADOCRC').readOnly = false;
            widget.getField('NMESTADOCRP').readOnly = false;   
	    }
	};
  
};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ger08000_Contador_Controller', Ger08000_Contador_Controller);
});

// FILE: ./assets/js/controllers/Ger09400_ParametroContabil_Controller.js
var Ger09400_ParametroContabil_Controller  = function(templateManager, ScreenService, General, ZHPromise, Ger09400_ParametroContabil_Service){
    var widget;
    var widgetfilha;
    
    var self = this;
    
    var messages = {
        EMPRESA_DESTINO_CADASTRADA: 'Empresa destino do codigo V1 já cadastrada no banco',
        EMPRESA_ORIGEM_NAO_CADASTRADA: 'Empresa origem do codigo V1 não cadastrada no banco',
        REQUEST_SUCCESS: 'Operação realizada com sucesso.'
    };
    
    function getErrorMessage(messageCode, dbColumnRelated){
        var errorMessage;
        if(messageCode in messages){
            switch(messageCode){
                case "EMPRESA_DESTINO_CADASTRADA":
                case "EMPRESA_ORIGEM_NAO_CADASTRADA":
                    errorMessage = messages[messageCode].replace('V1', dbColumnRelated);
                    break;
                default:
                    errorMessage = messages[messageCode];
            }
        }
        else{
            errorMessage = messageCode;
	    }
        return errorMessage;
    }
    
    function requestSuccess(){
        return function(response){
            var messageCode = 'REQUEST_SUCCESS';
            ScreenService.showMessage( getErrorMessage(messageCode), 'SUCCESS');
            ScreenService.closePopup();
            templateManager.container.getActiveWidget().reload();
            templateManager.container.getWidget('cadastramentoAutomatico').fields.filter(function(field){
                return field.template != 'field/select-multiple.html';
            }).forEach(function(field){
                field.readOnly = true;
                if (field.template === 'field/select-native.html')
                    field.value('N');
                else 
                    field.setValue('');
            });
        };
    }
    
    function requestError(){
        return function(response){
            var errorMessage = 'Timeout';
			if (response.data){
			   var error = response.data.error;
			   var data = response.data;
			   if(data.dataset)
			       if(data.dataset.empresaCadastrada)
			           if(data.dataset.empresaCadastrada.CDEMPRESA)
    			        errorMessage = getErrorMessage(error, data.dataset.empresaCadastrada.CDEMPRESA);
			   else{
			    errorMessage = getErrorMessage(error);
			   }
			}
            ScreenService.showMessage(errorMessage);
        };
    }

    self.setCampos = function(){
        widget = templateManager.container.getWidget('ger09400_parametro_contabil_grid');
        widgetfilha = templateManager.container.getWidget('ger09400_parametro_contabil_gridFilha');
        var banco = widget.dataSource.data;
        var result = Ger09400_ParametroContabil_Service.buildDataOfDataSource(banco);
        widgetfilha.dataSource.data = result[1];
        widget.dataSource.data = result[0];
        widget.activate();
    };

    self.setFormAndDates = function(currentRow, newRow){
        if(!currentRow.__is_new){
            self.setReadOnly(false, templateManager.container.getWidget('ger09400_parametro_contabil_grid'));
            for (var i = widgetfilha.dataSource.data.length - 1; i >= 0; i--) {
                if(widgetfilha.dataSource.data[i].CDEMPRESA == currentRow.CDEMPRESA){
                    for (var j = widgetfilha.fields.length - 1; j >= 0; j--) {
                        var fieldName = widgetfilha.fields[j].name;
                        widgetfilha.getField(fieldName).setValue(widgetfilha.dataSource.data[i][fieldName]);
                    }
                    for (var index = widget.dataSource.data.length - 1; index >= 0; index--) {
                        if(widget.dataSource.data[i].CDEMPRESA == currentRow.CDEMPRESA){
                            widget.getField('DTINIINTCONTDFE').minDate = widget.currentRow.DTINICCONT;
                            widget.getField('DTINIINTCONTDFE').maxDate = widget.currentRow.DTFININTCONTDFE;
                            widget.getField('DTINIINTCONTDFS').minDate = widget.currentRow.DTINICCONT;
                            widget.getField('DTINIINTCONTDFS').maxDate = widget.currentRow.DTFININTCONTDFS;
                            widget.getField('DTINICCTBL').minDate = widget.currentRow.DTINICCONT;
                            widget.getField('DTINICCTBL').maxDate = widget.currentRow.DTFINACCTBL;
                            widget.getField('DTINIINTCONTGPA').minDate = widget.currentRow.DTINICCONT;
                            widget.getField('DTINIINTCONTGPA').maxDate = widget.currentRow.DTFININTCONTGPA;

                            widget.getField('DTFININTCONTDFE').maxDate = widget.currentRow.DTFINACONT;
                            widget.getField('DTFININTCONTDFE').minDate = widget.currentRow.DTINIINTCONTDFE;
                            widget.getField('DTFININTCONTDFS').maxDate = widget.currentRow.DTFINACONT;
                            widget.getField('DTFININTCONTDFS').minDate = widget.currentRow.DTINIINTCONTDFS;
                            widget.getField('DTFINACCTBL').maxDate = widget.currentRow.DTFINACONT;
                            widget.getField('DTFINACCTBL').minDate = widget.currentRow.DTINICCTBL;
                            widget.getField('DTFININTCONTGPA').maxDate = widget.currentRow.DTFINACONT;
                            widget.getField('DTFININTCONTGPA').minDate = widget.currentRow.DTINIINTCONTGPA;

                            index = 0;
                        }
                    }
                    i = 0;
                }
            }
        } else {
            self.setReadOnly(false, newRow);
            newRow.currentRow.IDCONTGERE = 'N';
            newRow.currentRow.IDCONTCOME = 'N';
            newRow.currentRow.IDUTCUSTESTCONT = 'S';
            newRow.currentRow.IDSUGRAT = 'N';
            newRow.currentRow.IDUTSALDOSOC = 'N';
            newRow.currentRow.IDMSMCONTADBCR = 'N';
            newRow.currentRow.IDCONSVNDDFS = 'N';
            newRow.currentRow.IDDESPTRIBDIFAL = 'N';
            newRow.currentRow.IDRETESTSETOR = 'N';
        }
    };

    self.checaData = function(fieldInicial, fieldFinal, fieldMud, valueAntigo, widget){
        if(fieldMud.name == 'DTINICCONT' || fieldMud.name == 'DTFINACONT'){
            if(Ger09400_ParametroContabil_Service.comparDate(fieldInicial.value(), fieldFinal.value())){
                ScreenService.showMessage('A data inicial do Período Contábil deve ser menor que a data final do Período Contábil.');
                fieldMud.setValue(valueAntigo);
            }
            if(fieldMud.name == 'DTINICCONT'){
                if(Ger09400_ParametroContabil_Service.comparDate(fieldMud.value(), valueAntigo) && !widget.currentRow.__is_new){
                    fieldMud.setValue(valueAntigo);
                    ScreenService.showMessage('A data inicial do Período Contábil não pode ser alterada pra uma data maior do que a data anterior: '+valueAntigo);
                } else {
                    var minDate = fieldMud.value();
                    self.setMin('DTINIINTCONTDFE', minDate, widget);
                    self.setMin('DTINIINTCONTDFS', minDate, widget);
                    self.setMin('DTINICCTBL', minDate, widget);
                    self.setMin('DTINIINTCONTGPA', minDate, widget);
                }
            } else {
                var maxDate;
                if(!Util.isEmptyOrBlank(fieldMud.value())){
                    maxDate = moment(fieldMud.value(), 'DD/MM/YYYY').endOf('month').format('DD/MM/YYYY');
                } else {
                    maxDate = '';
                }
                widget.currentRow.DTFINACONT = maxDate;
                self.setMax('DTFININTCONTDFE', maxDate, widget);
                self.setMax('DTFININTCONTDFS', maxDate, widget);
                self.setMax('DTFINACCTBL', maxDate, widget);
                self.setMax('DTFININTCONTGPA', maxDate, widget);
                
                self.setMax('DTINIINTCONTDFE', maxDate, widget);
                self.setMax('DTINIINTCONTDFS', maxDate, widget);
                self.setMax('DTINICCTBL', maxDate, widget);
                self.setMax('DTINIINTCONTGPA', maxDate, widget);
            }
            self.contabilIsvalid(widget);
        } else if(fieldMud.name == 'DTINICLANC' || fieldMud.name == 'DTFINALANC'){
            if(Ger09400_ParametroContabil_Service.comparDate(fieldInicial.value(), fieldFinal.value())){
                ScreenService.showMessage('A data inicial do Período de Lançamento deve ser menor que a data final do Período de Lançamento.');
                fieldMud.setValue(valueAntigo);
            } else if(fieldMud.name == 'DTFINALANC'){
                if(Ger09400_ParametroContabil_Service.intraPeriodoConta(moment(fieldMud.value(),'DD/MM/YYYY').endOf('month').format('DD/MM/YYYY'), widget.currentRow.DTINICCONT, widget.currentRow.DTFINACONT)){
                    ScreenService.showMessage('A data final do Período de Lançamento deve estar dentro do Período Contábil');
                    fieldMud.setValue(valueAntigo);
                } else {
                    var date = moment(fieldMud.value() ,'DD/MM/YYYY').endOf('month').format('DD/MM/YYYY');
                    widget.currentRow.DTFINALANC = date;
                }
            } else if(Ger09400_ParametroContabil_Service.intraPeriodoConta(fieldMud.value(), widget.currentRow.DTINICCONT, widget.currentRow.DTFINACONT)) {
                ScreenService.showMessage('O Período de Lançamento deve estar dentro do Período Contábil');
                fieldMud.setValue(valueAntigo);
            }
        }
    };

    self.contabilIsvalid = function(widget){
        if(widget.getField('DTINICCONT').value() && widget.getField('DTFINACONT').value()){
            self.setReadOnly(false, templateManager.container.getWidget('ger09400_parametro_contabil_grid'));
        }
    };

    self.setReadOnly = function(bolean, widget){
        for (var i = 4; i < widget.fields.length; i++) {
            widget.fields[i].readOnly = bolean;
        }
    };

    self.setMin = function(fieldName, minDate, widget){
        widget.getField(fieldName).minDate = minDate;
    };

    self.setMax  = function(fieldName, maxDate, widget){
        widget.getField(fieldName).maxDate = maxDate;
    };

    self.newRowParametroContabil = function(widget){
        widgetfilha = templateManager.container.getWidget('ger09400_parametro_contabil_gridFilha');
        widgetfilha.newRow();
        widget.newRow();
        self.edit(widget, widget.widgets[0]);
    };

    self.edit = function(widget, widgetfilha){
        widgetfilha.template = widgetfilha.templateToForm;
        widgetfilha.backupRow = angular.copy(widgetfilha.currentRow);
        widgetfilha.edit();
        if(widget.currentRow.__is_new){
            widget.getField('NMEMPRESA').showOnForm = true;
            widget.getField('NMEMPRESA').label = 'Empresa';
        }
        General.edit(widget);
    };

    self.cancelar = function(widget, widgetfilha){
        if (widget.currentRow.__is_new) {
            self.setReadOnly(false, widget);
            widget.getField('NMEMPRESA').showOnForm = false;
            widget.getField('NMEMPRESA').label = 'Nome';
            widgetfilha.template = widgetfilha.templateToView;
            widgetfilha.currentRow = {};
            widget.list(true);
            widget.dataSource.data.pop();
            widget.currentRow = {};
            ScreenService.goBack();
        } else if (widget.mode === 'edit') {
            widget.view();
            for (var j in widget.backupRow) {
                widget.currentRow[j] = widget.backupRow[j];
            }
            for (var i in widgetfilha.backupRow) {
                widgetfilha.currentRow[i] = widgetfilha.backupRow[i];
            }
            widgetfilha.template = widgetfilha.templateToView;
            widgetfilha.view();
            widget.activate();
        }
    };

    self.salvar = function(widget, widgetfilha){
        if(widget.isValid() && widgetfilha.isValid()){
            widget.currentRow.IDCONTGERE = widgetfilha.currentRow.IDCONTGERE;
            widget.currentRow.IDCONTCOME = widgetfilha.currentRow.IDCONTCOME;
            widget.currentRow.IDUTCUSTESTCONT = widgetfilha.currentRow.IDUTCUSTESTCONT;
            widget.currentRow.IDSUGRAT = widgetfilha.currentRow.IDSUGRAT;
            widget.currentRow.IDUTSALDOSOC = widgetfilha.currentRow.IDUTSALDOSOC;
            widget.currentRow.IDMSMCONTADBCR = widgetfilha.currentRow.IDMSMCONTADBCR;
            widget.currentRow.IDCONSVNDDFS = widgetfilha.currentRow.IDCONSVNDDFS;
            widget.currentRow.IDDESPTRIBDIFAL = widgetfilha.currentRow.IDDESPTRIBDIFAL;
            widget.currentRow.DTINICRELA = widget.currentRow.DTINICCONT;
            widget.currentRow.DTFINARELA = widget.currentRow.DTFINACONT;
            widget.currentRow.IDRETESTSETOR = widgetfilha.currentRow.IDRETESTSETOR;
            widget.currentRow.IDCONSDTMOVIRETEST = widgetfilha.currentRow.IDCONSDTMOVIRETEST;
            General.saveCrud(widget).then(function(){
                self.setReadOnly(false, widget);
                widget.getField('NMEMPRESA').showOnForm = false;
                widget.getField('NMEMPRESA').label = 'Nome';
                widgetfilha.template = widgetfilha.templateToView;
                widgetfilha.view();
                ScreenService.closeSwipe();
                widget.list();
                widget.activate();
            }, function () {
                widget.getField('DTINICCONT').setValue(widget.currentRow.DTINICCONT);
                widget.getField('DTINICCONT').reload();
                widget.getField('DTFINACONT').setValue(widget.currentRow.DTFINACONT);
                widget.getField('DTFINACONT').reload();
                widget.getField('DTINICLANC').setValue(widget.currentRow.DTINICLANC);
                widget.getField('DTINICLANC').reload();
                widget.getField('DTFINALANC').setValue(widget.currentRow.DTFINALANC);
                widget.getField('DTFINALANC').reload();
            });
        }else{
            var widgetAtiva = templateManager.container.getActiveWidget();

            if (widgetAtiva.name.localeCompare('ger09400_parametro_contabil_gridFilha') === 0) {
                if (!templateManager.container.getWidget('ger09400_parametro_contabil_grid').isValid())
                    templateManager.container.getWidget('ger09400_parametro_contabil_grid').activate();
            }
        }
    };
    
    self.openPopupCadastramentoAutomatico = function(){
        var cadastramentoAutomaticoWidget = templateManager.container.getWidget("cadastramentoAutomatico");
        ScreenService.openPopup(cadastramentoAutomaticoWidget);
        cadastramentoAutomaticoWidget.newRow();
        cadastramentoAutomaticoWidget.fields.filter(function (field){
            return field.template != 'field/select-multiple.html';
        }).forEach(function(field){
            field.readOnly = true;
            if(field.name != 'IDALTERAPERIODO' || field.name != 'IDALTERALANCAMENTO' )
                field.validations = {};
        });
    };
    
    self.cadastrarAutomaticamente = function(widget){
        if(widget.isValid()){
            if (widget.currentRow.IDALTERAPERIODO === 'S' || widget.currentRow.IDALTERALANCAMENTO === 'S'){
                validateSaldoPositivo(widget).then(function (){
                    validatelacnamentoPendenteRecalculo(widget).then(function(){
                        Ger09400_ParametroContabil_Service.cadastrarAutomaticamente(widget.currentRow).then(
                            requestSuccess(),
                            requestError()
                        );
                    });
                });
            } else {
                ScreenService.showMessage('Para alterar as parametrizações das empresas é necessário selecionar ao menos uma das opções (Períodos ou Controles de Lançamentos).');
            }
        }
    };
    
    self.deleteCrud = function (widget){
        General.deleteCrud(widget).then(function(){
            widget.getField('NMEMPRESA').reload();
            templateManager.container.getWidget('cadastramentoAutomatico').getField('NMEMPRESA').reload();
        });
    };
    
    self.changeReadOnlyOnFieldsToSelectFieldGroups = function(widget){
        if(widget.currentRow.NMEMPRESA.length>0){
            widget.getField('IDALTERAPERIODO').readOnly = false;
            widget.getField('IDALTERALANCAMENTO').readOnly = false;
        } else {
            widget.getField('IDALTERAPERIODO').readOnly = true;
            widget.getField('IDALTERAPERIODO').setValue('N');
            self.changeReadOnlyOnPopupFieldGroups(widget, 'alteracaoPeriodo', 'IDALTERAPERIODO');
            widget.getField('IDALTERALANCAMENTO').readOnly = true;
            widget.getField('IDALTERALANCAMENTO').setValue('N');
            self.changeReadOnlyOnPopupFieldGroups(widget, 'alteracaoControlesLancamento', 'IDALTERALANCAMENTO');
            widget.redraw();
        }
        var CODEMPRESA =[];
        widget.getField('NMEMPRESA').dataSource.data.forEach(function(data){
            widget.currentRow.NMEMPRESA.forEach(function(CDEMPRESA){
                if(CDEMPRESA === data.CDEMPRESA){
                    CODEMPRESA.push(data.CDEMPRESA);
                }
            });
        });
        widget.currentRow.CDEMPRESA = CODEMPRESA;
    };
    
    self.changeReadOnlyOnPopupFieldGroups = function (widget, fieldGroupName, selectName){
        var readOnly;
        if (widget.currentRow[selectName] === 'S') {
            readOnly = false;
        } else {
            readOnly = true;
        }
        widget.fields.filter(function(field){
            return field.fieldGroup === fieldGroupName;
        }).forEach(function(field){
            field.readOnly = readOnly;
            if (readOnly){
                field.validations = {};
            } else {
                field.validations = {required: true};
            }
        });
        
    };
    
    function validateSaldoPositivo (widget){
        var defer = ZHPromise.defer();
        General.callRestEngine('ctb#/parametroContabil/validateSaldoPositivo', 'Row', widget.currentRow).then(function(response){
            var  preenchido;
            var mensagem = '';
            response.dataset.saldo.forEach(function (data){
                if (!Util.isEmptyOrBlank(data)) {
                    preenchido = true;
                    mensagem = mensagem.concat('Empresa '.concat(data[0].CDEMPRESA).concat(' possui lançamentos pendentes de recálculo fiscal desde ').concat(data[0].DTSEMEVOLUCAO).concat('.\r\n'));
                }
            });
            if (!preenchido){
                defer.resolve();
            } else {
                ScreenService.showMessage(mensagem);
                defer.reject();
            }
        }, function(){
            defer.reject();
        });
        return defer.promise;
    }
    
    function validatelacnamentoPendenteRecalculo (widget){
        var defer = ZHPromise.defer();
        General.callRestEngine('ctb#/parametroContabil/validateLacnamentoPendenteRecalculo', 'Row', widget.currentRow).then(function(response){
            var  preenchido;
            var mensagem = '';
            response.dataset.lancamento.forEach(function (data){
                if (!Util.isEmptyOrBlank(data)){
                    preenchido = true;
                    mensagem = mensagem.concat('Empresa '.concat(data[0].CDEMPRESA).concat(' possui saldo com data superior à data informada para final do Período Contábil.\r\n'));
                }
            });
            if (!preenchido){
                defer.resolve();
            } else {
                ScreenService.showMessage(mensagem);
                defer.reject();
            }
        }, function(){
            defer.reject();
        });
        return defer.promise;
    }
    
    self.changeGridFilhaMode = function(){
        widgetfilha = templateManager.container.getWidget('ger09400_parametro_contabil_gridFilha');
        if (widgetfilha.getParent().mode != 'edit')
            widgetfilha.view();
    };
    
    self.setCalendarValueOnDtiniccontChange = function(widget){
        widget.fields.filter(function(field){
            return field.template === 'field/calendar.html';
        }).forEach(function(field){
            field.setValue('');
        });
    };

};
Configuration(function(ContextRegister){
    ContextRegister.register('Ger09400_ParametroContabil_Controller', Ger09400_ParametroContabil_Controller);
});

// FILE: ./assets/js/controllers/Ger17700_Rendimentos_Socios_Controller.js
var Ger17700_Rendimentos_Socios_Controller = function(ScreenService, templateManager, General, Ger08000_Contador_Service){
   var self = this;
   
   this.habilitaCamposBrasil = function(widget){
        var boVisible = widget.currentRow.CDPAISREG === 105;
        if (boVisible){
           widget.fieldGroups[1].isVisible = boVisible;  
        }
        widget.getField('CDREG').readOnly = !boVisible;
        if (widget.getField('CDREG').readOnly)
            widget.currentRow.CDREG = "";
   };
   
   this.tipoMascaraPessoa = function (widget){
        var field = General.inscricaoFormat(widget.currentRow.CDREG);
        var msg = 'CNPJ / CPF inválido!';
        if (field.tipo.cod === 'F'){
            widget.currentRow.IDTIPOREG = 'PF';
            if (field.valid === false && !widget.getField('CDREG').readOnly){
                ScreenService.showMessage(msg);
            }else{
                widget.currentRow.CDREG = field.value;
            }
        }else if (field.tipo.cod === 'J') {
            widget.currentRow.IDTIPOREG = 'PJ';
            if (field.valid === false && !widget.getField('CDREG').readOnly){
                ScreenService.showMessage(msg);
            }else{
                widget.currentRow.CDREG = field.value;
            }
        } 
   };
   
    this.formataCNPJCPF = function(widget){
        var rows = widget.dataSource.data;
        rows.forEach(function(row){
            var insc = General.inscricaoFormat(row.CDREG);
            row.CDREG = insc.value;   
        });
    };
   
   this.tipoMascaraRepres = function (widget){
        var field = General.inscricaoFormat(widget.currentRow.NRCPFREPREG);
        var msg = 'CPF do representante legal inválido!';
        if (field.tipo.cod === 'F'){
            if (field.valid === false){
                ScreenService.showMessage(msg);
            }else{
                widget.currentRow.NRCPFREPREG = field.value;
            }
        }else{
            ScreenService.showMessage(msg);
        }
   };
   
   this.alteraCodigo = function(widget){
        var codigo = widget.currentRow.CDREG;
        codigo = codigo.replace(".", "");
        codigo = codigo.replace(".", "");
        if (widget.currentRow.IDTIPOREG === 'PJ'){
            codigo = codigo.replace("/", "");
        }else{
            codigo = codigo.replace(".", "");
        }
        codigo = codigo.replace("-", "");
        widget.currentRow.CDREG = codigo;
        
        if (widget.currentRow.NRCPFREPREG){
            codigo = widget.currentRow.NRCPFREPREG;
            codigo = codigo.replace(".", "");
            codigo = codigo.replace(".", "");
            codigo = codigo.replace(".", "");
            codigo = codigo.replace("-", "");
            widget.currentRow.NRCPFREPREG = codigo;
        }
        
        if (!widget.currentRow.QUALIREPREG){
            widget.currentRow.QUALIREPREG = '00';
        }
   };
   
   this.iniciaInsercaoSocio = function(widget){
       widget.currentRow.IDTIPOREG = 'PF';
       //widget.currentRow.__is_new = true;
       General.changeWidgetAcessibility(widget.widgets, false);
       
       this.habilitaCamposBrasil(widget);
   };
   
   this.salvarSocio = function (widget){
        //Verifica se CPF/CNPJ inserido é válido
        if ((widget.currentRow.IDTIPOREG === 'PF' && General.validateCPF(widget.currentRow.CDREG) && !widget.getField('CDREG').readOnly) || 
            (widget.currentRow.IDTIPOREG === 'PJ' && General.validateCNPJ(widget.currentRow.CDREG) && !widget.getField('CDREG').readOnly) || 
            (widget.getField('CDREG').readOnly && widget.currentRow.CDREG === "")) { 
            // Chama a rota para efetuar a rotina de recálculo.
            General.callRestEngine("ctb#/salvarSocio", "Row", widget.currentRow)
            .then(function() {
                ScreenService.showMessage("Registro salvo com sucesso.");
                self.formataCNPJCPF(widget);
                widget.list();
                ScreenService.closeSwipe();
                widget.reload();
                General.changeWidgetAcessibility(widget.widgets, widget.currentRow.IDSOCIOREG === 'S'); 
            })
            .catch(function(error) {
                // Mensagem padrão em caso de timeout.
                var errorMessage = 'Timeout';
    
                // Verifica se houve alguma resposta da requisição.
                if (error.data) {
                    // Caso haja alguma resposta, atribui a mensagem de erro.
                    errorMessage = error.data.error;
                }

                // Imprime a mensagem.
                ScreenService.showMessage(errorMessage);
            });
        } else {
            ScreenService.showMessage('CPF/CNPJ inválido.');
        }
        
   };
   
   this.alterarSocio = function(widget){
       General.changeWidgetAcessibility(widget.widgets, false);
       widget.edit(widget);
       this.habilitaCamposBrasil(widget);
   };
   
   this.cancelActionSocio = function(args) {
       General.changeWidgetAcessibility(args.owner.widget.widgets, args.owner.widget.currentRow.IDSOCIOREG === 'S');
       General.backOrCancel(args);
   };
   
   this.iniciaInsercaoEmpresa = function(widget){
       widget.currentRow.NRSEQREG = widget.parent.currentRow.NRSEQREG;
       /* Código 09 (Titular) foi escolhido devido ser o único que indifere se a pessoa reside ou não no Brasil) */
       widget.currentRow.IDQUALIY600 = '09'; 
   };
   
   this.salvarQuadroSocietario = function(widget){
        if (widget.isValid()) {
            General.callRestEngine("ctb#/salvarQuadroSocietario", "Row", widget.currentRow)
            .then(function() {
                ScreenService.showMessage("Registro salvo com sucesso.");
                widget.view();
                templateManager.updateTemplate();
            })
            .catch(function(error) {
                // Mensagem padrão em caso de timeout.
                var errorMessage = 'Timeout';
    
                // Verifica se houve alguma resposta da requisição.
                if (error.data) {
                    // Caso haja alguma resposta, atribui a mensagem de erro.
                    errorMessage = error.data.error;
                }
    
                // Imprime a mensagem.
                ScreenService.showMessage(errorMessage);
            });    
            templateManager.updateTemplate();
        } else {
            ScreenService.showMessage("Preencha todos os campos corretamente");
        }
   };
   
   this.habilitaCamposEWidgets = function(widget){
       self.formataCNPJCPF(widget);
       General.changeWidgetAcessibility(widget.widgets, widget.currentRow.IDSOCIOREG === 'S');
   };
   
   this.salvarRendimento = function(widget) {
        if (widget.isValid()) {
            //Formata a data para inserção no banco de dados
            if (typeof widget.currentRow.DTREFERENCIA === "number") 
                widget.currentRow.DTREFERENCIA = '31/12/'+widget.currentRow.DTREFERENCIA;
            else 
                widget.currentRow.DTREFERENCIA = '31/12/'+widget.currentRow.DTREFERENCIA.substr(widget.currentRow.DTREFERENCIA.length - 4);
            //Formata todos os valores monetários para floats válidos
            if (typeof widget.currentRow.VRREMTRAB === 'string')
                widget.currentRow.VRREMTRAB = parseFloat(widget.currentRow.VRREMTRAB.replace(/\./g, "").replace(",", "."));
            if (typeof widget.currentRow.VRLUCRODIV === 'string')
                widget.currentRow.VRLUCRODIV = parseFloat(widget.currentRow.VRLUCRODIV.replace(/\./g, "").replace(",", "."));
            if (typeof widget.currentRow.VRJURCAPPROP === 'string')
                widget.currentRow.VRJURCAPPROP = parseFloat(widget.currentRow.VRJURCAPPROP.replace(/\./g, "").replace(",", "."));
            if (typeof widget.currentRow.VRDEMAISREND === 'string')
                widget.currentRow.VRDEMAISREND = parseFloat(widget.currentRow.VRDEMAISREND.replace(/\./g, "").replace(",", "."));
            if (typeof widget.currentRow.VRIRRETIDO === 'string')
                widget.currentRow.VRIRRETIDO = parseFloat(widget.currentRow.VRIRRETIDO.replace(/\./g, "").replace(",", "."));
            
            widget.currentRow.NRSEQREG = widget.parent.currentRow.NRSEQREG;
            
            //Flag para permitir a edição de um rendimento sem alterar o ano no backend
            widget.currentRow.anoUnchanged = !widget.currentRow.__is_new && (widget.currentRow.DTREFERENCIA.substr(widget.currentRow.DTREFERENCIA.length - 4) == widget.backupRow.DTREFERENCIA);
            
            General.callRestEngine("ctb#/socio_rendimento/save", "Row", widget.currentRow)
            .then(function() {
                ScreenService.showMessage("Registro salvo com sucesso.");
                ScreenService.closeSwipe();
                widget.list();
                widget.reload();
            })
            .catch(function(error) {
                // Mensagem padrão em caso de timeout.
                var errorMessage = 'Timeout';
    
                // Verifica se houve alguma resposta da requisição.
                if (error.data) {
                    // Caso haja alguma resposta, atribui a mensagem de erro.
                    errorMessage = error.data.error;
                }
    
                // Imprime a mensagem.
                ScreenService.showMessage(errorMessage);
            }); 
        } else {
            ScreenService.showMessage("Preencha todos os campos corretamente");
        }
   };   
   
};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ger17700_Rendimentos_Socios_Controller', Ger17700_Rendimentos_Socios_Controller);
});

// FILE: ./assets/js/controllers/Ger18100_RegistroP130ReceitasIncentivadas_Controller.js
function Ger18100_RegistroP130ReceitasIncentivadas_Controller(General, ScreenService, templateManager) {

  	var self = this;
  	
  	self.verificaDataSource = function(){
  		var widget = templateManager.container.getWidget('ger18100_registro_p130_receitas_incentivadas');
  		if(widget.getField('CDREGP130').dataSource.data.length == 0 ){
  			ScreenService.showMessage("Não existem Receitas Incentivadas importadas para o sistema. Favor acessar a tela de importação e realizar a importação da tabela P130 da ECF.");
  			return;
  		}
  		return;
  	};
  	
	self.habilitaDataEValor = function() {
		var widget = templateManager.container.getWidget('ger18100_registro_p130_receitas_incentivadas');
		
	    if(widget.getField('IDTIPOP130').value() == 'E' || widget.getField('IDTIPOP130').value() == 'CA'){
	    	widget.getField('DTRECINCEMPR').readOnly = false;
	    	widget.getField('VRRECINCEMPR').readOnly = false;
	    	widget.getField('DTRECINCEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widget.getField('VRRECINCEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    }else {
	    	widget.getField('DTRECINCEMPR').validations = {};
	    	widget.getField('VRRECINCEMPR').validations = {};
		    widget.getField('DTRECINCEMPR').readOnly = true;
	    	widget.getField('VRRECINCEMPR').readOnly = true;
	    }
	};
	
	self.verificaData = function(widget) {
		if(widget.getField('DTRECINCEMPR').value() == ''){
			ScreenService.showMessage("Preencha o campo de data. Campo obrigatório.");
			return false;
		}
		var aux = widget.getField('DTRECINCEMPR').value(); 
		if(aux.substring(6,10) != '2019'){
			ScreenService.showMessage("Data informada deve estar no ano de referência informado. ");
			return false;
		}
		return true;
	};
	
	self.setDataReferencia = function(widget){
		var ano = widget.getField('DTANO').value();
		widget.getField('DTREFERENCIA').value('31/12/'+ ano);
	};
	
	self.salvar = function() {
		var widget = templateManager.container.getWidget('ger18100_registro_p130_receitas_incentivadas');
		
		self.setDataReferencia(widget);
		if(widget.isValid()){
			General.callRestEngine('ctb#/crud/recincempr_max', 'FilterData', []).then(function (result) {
				result = result.dataset.recincempr_max[0];
				
				if((widget.getField('IDTIPOP130').value() == 'E') || (widget.getField('IDTIPOP130').value() == 'CA')){
					if((self.verificaData(widget) == true) && (self.verificaValor(widget) == true)){
						var filter = [
							{
								"name": "DTRECINCEMPR",
								"operator": "IN",
								"value": widget.getField('DTRECINCEMPR').value()
							},
							{
								"name": "P_CDEMPRESA",
								"operator": "=",
								"value": widget.getField('CDEMPRESA').value()
							},
							{
								"name": "P_ANO",
								"operator": "=",
								"value": widget.getField('DTANO').value()
							},
							{
								"name": "VRRECINCEMPR",
								"operator": "IN",
								"value": widget.getField('VRRECINCEMPR').value()
							}
						];
						General.callRestEngine('ctb#/crud/regp130ecf_recincempr', 'FilterData', filter).then(function (result) {
					        result = result.dataset.regp130ecf_recincempr;
					        
					        if(result.length == 0){
					        	General.saveCrud(widget);
					        	ScreenService.showMessage('Registro salvo com sucesso.');
					        }else{
					        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
					        }
						});
					}
				}
				if((widget.getField('IDTIPOP130').value() == 'R') || (widget.getField('IDTIPOP130').value() == 'CNA')){
					var filtro = [
						{
							"name": "CDREGP130",
							"operator": "IN",
							"value": widget.getField('CDREGP130').value()
						},
						{
							"name": "P_CDEMPRESA",
							"operator": "=",
							"value": widget.getField('CDEMPRESA').value()
						},
						{
							"name": "P_ANO",
							"operator": "=",
							"value": widget.getField('DTANO').value()
						}
						
					];
					General.callRestEngine('ctb#/crud/regp130ecf_recincempr', 'FilterData', filtro).then(function (result) {
				        result = result.dataset.regp130ecf_recincempr;
				        
				        if(result.length == 0){
				        	General.saveCrud(widget);
				        	ScreenService.showMessage('Registro salvo com sucesso.');
				        }else{
				        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
				        }
					});
				}
			}.bind(this));
		}
	};
	
	self.verificaValor = function(widget) {
	    if ((widget.getField('VRRECINCEMPR').value() != '') && (widget.getField('VRRECINCEMPR').value() != null) ) {
	        if(typeof widget.getField('VRRECINCEMPR').value() == 'number'){
	        	if(widget.getField('VRRECINCEMPR').value() <= '0'){
					ScreenService.showMessage("Valor da receita deve ser maior que zero");
					return false;
				}
	        	return true;
	        }
	        if (typeof widget.getField('VRRECINCEMPR').value() != 'string') {
	            widget.getField('VRRECINCEMPR').value(widget.getField('VRRECINCEMPR').value() + '');
	            if (widget.getField('VRRECINCEMPR').value().indexOf(".") != -1) {
	                widget.getField('VRRECINCEMPR').value(widget.getField().VRRECINCEMPR.replace(".", ","));
	            }
	        }
	        if (typeof widget.getField('VRRECINCEMPR').value() == 'string') {
		        var parteInteira = widget.getField('VRRECINCEMPR').value().slice(0, widget.getField('VRRECINCEMPR').value().length - 3);
		        var parteDecimal = widget.getField('VRRECINCEMPR').value().slice(widget.getField('VRRECINCEMPR').value().length - 2, widget.getField('VRRECINCEMPR').value().length);
		        if (parteInteira.indexOf(".") != -1) {
		            parteInteira = parteInteira.replace(/[\[\].]+/g, '');
		        }
		
		
		        widget.getField('VRRECINCEMPR').value(parteInteira + '.' + parteDecimal);
		        widget.getField('VRRECINCEMPR').value(parseFloat(widget.getField('VRRECINCEMPR').value()));
		        if(widget.getField('VRRECINCEMPR').value() <= '0'){
					ScreenService.showMessage("Valor da receita deve ser maior que zero");
					return false;
				}
	    	}
	    }else {
	    	ScreenService.showMessage("Preencha o campo de valor. Campo obrigatório.");
	    	return false;
	    }
	
	    return true;
	};
	
	self.isNumber = function(widget){
   		var n = widget.getField('DTANO').value();
   		if(n == null){
   			n = 1;
   		}
   		n = n.toString();
   		n = n.replace(/\./g,'');
		if(!(!isNaN(parseFloat(n)) && isFinite(n)) || n.length < 4){
			widget.getField('DTANO').value(n.replace(/./g, ''));
			// ScreenService.showMessage("Campo Ano obrigatório!");
		}
   };
	

}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Ger18100_RegistroP130ReceitasIncentivadas_Controller', Ger18100_RegistroP130ReceitasIncentivadas_Controller);
});

// FILE: ./assets/js/controllers/Ger18200_RegistroP200ApuracaoaBaseDeCalculo_Controller.js
function Ger18200_RegistroP200ApuracaoaBaseDeCalculo_Controller(General, ScreenService, templateManager) {

  	var self = this;

	self.verificaDataSource = function(){
  		var widget = templateManager.container.getWidget('ger18200_registro_p200_apuracao_da_base_de_calculo');
  		if(widget.getField('CDREGP200').dataSource.data.length == 0 ){
  			ScreenService.showMessage("Não existem Bases de Cálculo do Lucro Presumido importadas para o sistema. Favor acessar a tela de importação e realizar a importação da tabela P200 da ECF.");
  			return;
  		}
  		return;
  	};
  	
	self.habilitaDataEValor = function() {
		var widget = templateManager.container.getWidget('ger18200_registro_p200_apuracao_da_base_de_calculo');
		
	    if(widget.getField('IDTIPOP200').value() == 'E' || widget.getField('IDTIPOP200').value() == 'CA'){
	    	widget.getField('DTBASECALCPEMPR').readOnly = false;
	    	widget.getField('VRBASECALCPEMPR').readOnly = false;
	    	widget.getField('DTBASECALCPEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widget.getField('VRBASECALCPEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    }else {
	    	widget.getField('DTBASECALCPEMPR').validations = {};
	    	widget.getField('VRBASECALCPEMPR').validations = {};
		    widget.getField('DTBASECALCPEMPR').readOnly = true;
	    	widget.getField('VRBASECALCPEMPR').readOnly = true;
	    }
	};
	
	self.verificaData = function(widget) {
		if(!widget.getField('DTBASECALCPEMPR').value()){
			ScreenService.showMessage("Preencha o campo de data. Campo Obrigatório.");
			return false;
		}
		var aux = widget.getField('DTBASECALCPEMPR').value(); 
		if(aux.substring(6,10) != '2019'){
			ScreenService.showMessage("Data informada deve estar no ano de referência informado.");
			return false;
		}
		return true;
	};

	self.setDataReferencia = function(widget){
		var ano = widget.getField('DTANO').value();
		widget.getField('DTREFERENCIA').value('31/12/'+ ano);
	};
	
	self.salvarP200 = function() {
		var widget = templateManager.container.getWidget('ger18200_registro_p200_apuracao_da_base_de_calculo');
		
		self.setDataReferencia(widget);
		if(widget.isValid()){
			General.callRestEngine('ctb#/crud/basecalcpempr_max', 'FilterData', []).then(function (result) {
				result = result.dataset.basecalcpempr_max[0];
				
				if((widget.getField('IDTIPOP200').value() == 'E') || (widget.getField('IDTIPOP200').value() == 'CA')){
					if((self.verificaData(widget) == true) && (self.verificaValor(widget) == true)){
						var filter = [
							{
								"name": "DTBASECALCPEMPR",
								"operator": "IN",
								"value": widget.getField('DTBASECALCPEMPR').value()
							},
							{
								"name": "P_CDEMPRESA",
								"operator": "=",
								"value": widget.getField('CDEMPRESA').value()
							},
							{
								"name": "P_ANO",
								"operator": "=",
								"value": widget.getField('DTANO').value()
							},
							{
								"name": "VRBASECALCPEMPR",
								"operator": "IN",
								"value": widget.getField('VRBASECALCPEMPR').value()
							}
						];
						General.callRestEngine('ctb#/crud/regp200ecf_basecalcpempr', 'FilterData', filter).then(function (result) {
					        result = result.dataset.regp200ecf_basecalcpempr;
					        
					        if(result.length == 0){
					        	General.saveCrud(widget);
					        	ScreenService.showMessage('Registro salvo com sucesso.');
					        }else{
					        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
					        }
						});
					}
				}
				if((widget.getField('IDTIPOP200').value() == 'R') || (widget.getField('IDTIPOP200').value() == 'CNA')){
					var filtro = [
						{
							"name": "CDREGP200",
							"operator": "IN",
							"value": widget.getField('CDREGP200').value()
						},
						{
							"name": "P_CDEMPRESA",
							"operator": "=",
							"value": widget.getField('CDEMPRESA').value()
						},
						{
							"name": "P_ANO",
							"operator": "=",
							"value": widget.getField('DTANO').value()
						}
						
					];
					General.callRestEngine('ctb#/crud/regp200ecf_basecalcpempr', 'FilterData', filtro).then(function (result) {
				        result = result.dataset.regp200ecf_basecalcpempr;
				        
				        if(result.length == 0){
				        	General.saveCrud(widget);
				        	ScreenService.showMessage('Registro salvo com sucesso.');
				        }else{
				        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
				        }
					});
				}
				
					
			}.bind(this));
		}
	};
	
	self.verificaValor = function(widget) {
	    if ((widget.getField('VRBASECALCPEMPR').value() != '') && (widget.getField('VRBASECALCPEMPR').value() != null) ) {
	        if(typeof widget.getField('VRBASECALCPEMPR').value() == 'number'){
	        	if(widget.getField('VRBASECALCPEMPR').value() <= '0'){
					ScreenService.showMessage("Valor da receita deve ser maior que zero");
					return false;
				}
	        	return true;
	        }
	        if (typeof widget.getField('VRBASECALCPEMPR').value() != 'string') {
	            widget.getField('VRBASECALCPEMPR').value(widget.getField('VRBASECALCPEMPR').value() + '');
	            if (widget.getField('VRBASECALCPEMPR').value().indexOf(".") != -1) {
	                widget.getField('VRBASECALCPEMPR').value(widget.getField('VRBASECALCPEMPR').value().replace(".", ","));
	            }
	        }
	        var parteInteira = widget.currentRow.VRBASECALCPEMPR.slice(0, widget.currentRow.VRBASECALCPEMPR.length - 3);
	        var parteDecimal = widget.currentRow.VRBASECALCPEMPR.slice(widget.currentRow.VRBASECALCPEMPR.length - 2, widget.currentRow.VRBASECALCPEMPR.length);
	        if (parteInteira.indexOf(".") != -1) {
	            parteInteira = parteInteira.replace(/[\[\].]+/g, '');
	        }
	
	
	        widget.getField('VRBASECALCPEMPR').value(parteInteira + '.' + parteDecimal);
	        widget.getField('VRBASECALCPEMPR').value(parseFloat(widget.getField('VRBASECALCPEMPR').value()));
	        if(widget.getField('VRBASECALCPEMPR').value() <= '0'){
				ScreenService.showMessage("Valor da receita deve ser maior que zero");
				return false;
			}
	    }else {
	    	ScreenService.showMessage("Preencha o campo de valor. Campo obrigatório.");
	    	return false;
	    }
	
	    return true;
	};
	
	self.isNumber = function(widget){
   		var n = widget.getField('DTANO').value();
   		if(n == null){
   			n = 1;
   		}
   		n = n.toString();
   		n = n.replace(/\./g,'');
		if(!(!isNaN(parseFloat(n)) && isFinite(n)) || n.length < 4){
			widget.getField('DTANO').value(n.replace(/./g, ''));
			// ScreenService.showMessage("Campo Ano obrigatório!");
		}
   };

}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Ger18200_RegistroP200ApuracaoaBaseDeCalculo_Controller', Ger18200_RegistroP200ApuracaoaBaseDeCalculo_Controller);
});

// FILE: ./assets/js/controllers/Ger31000_contabilizacao_estoque.js
/* jshint esversion: 6 */
var Ger31000_contabilizacao_estoque_Controller = function(ScreenService, templateManager, ZHPromise, General, Messages_Contabil, maskEngine, ZhFilterPreferences, Ger31000_contabilizacao_estoque_Service) {

    var self = this; // Variável para guardar o escopo atual nas funções.
    var windowCurrentlyOpen = false; // Variável de controle para o armazenamento da widget atualmente aberta.
    var Picts = []; //Mascaras
    var prodMask = "";
    
    /* Aquisição das máscaras */
    this.setPict = function() {
        General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []).then(function(response) {
                var paramgeral = response.dataset.paramgeral[0];
                Picts = [
                    {
                        "pict": "PROD",
                        "mask": paramgeral.CDPICTPROD
                    },
                    {
                        "pict": "RECE",
                        "mask": paramgeral.CDPICTRECE
                    },
                    {
                        "pict": "SERV",
                        "mask": paramgeral.CDPICTSERV
                    },
                    {
                        "pict": "CFIS",
                        "mask": paramgeral.CDPICTCFIS
                    },
                    {
                        "pict": "CCTB",
                        "mask": paramgeral.CDPICTCCTB
                    },
                    {
                        "pict": "ETAPA",
                        "mask": paramgeral.CDPICTETAPA
                    }
                ];
            }
        );
    };
    
    this.getPict = function(pict) {
        return Picts.find(Picts => Picts.pict === pict).mask.replace('a', '9');
    };
    
    self.setProdMask = function() {
        General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []).then(function(response) {
            var paramgeral = response.dataset.paramgeral[0];
            prodMask = paramgeral.CDPICTPROD;
        });
    };
    
    self.getProdMask = function() {
        return prodMask;
    };
    
    /* Função para sair de uma "tela" e retornar à widget principal. */
    this.closeSwipe = function(widget) {
        // Prepara uma promise para esta função.
        var deferred = ZHPromise.defer();
        var mainWidget = templateManager.container.getWidget("mainWidget");

        // Desativa a widget atualmente aberta.
        widget.deactivate();

        // Limpa a variável que indica qual a widget atualmente aberta.
        windowCurrentlyOpen = false;

        // Fecha o swipe.
        ScreenService.goBack().then(function() {
            // Ativa a widget principal.
            mainWidget.activate();
            // Finaliza a promise retornada.
            deferred.resolve();
        });
        // Retorna a promise preparada.
        return deferred.promise;
    };
    
    
    /*
     * Função que verifica o clique em uma das opções disponíveis na widget
     * principal. Determina se um swipe será aberto ou não, dependendo da
     * opção selecionada.
     */
    this.mainWidgetAfterMoveRow = function(widget) {
        // Guarda o nome da widget relacionada à opção clicada, se houver.
        var windowToOpen = widget.currentRow.WINDOW;
        // Guarda a propriedade "ENABLED" da opção selecionada.
        var windowEnabled = widget.currentRow.ENABLED;

        // Verifica se há uma widget associada (não for um submenu) e se esta está habilitada (a tela estiver disponível para ser utilizada).
        if (windowToOpen && windowEnabled) {
            // Verifica se já há uma widget aberta e se esta é diferente da selecionada.
            if (windowCurrentlyOpen && windowCurrentlyOpen != windowToOpen) {
                // Fecha o swipe com a widget já aberta.
                self.closeSwipe(templateManager.container.getWidget(windowCurrentlyOpen)).then(function() {
                    // Abre o swipe na widget selecionada.
                    ScreenService.openSwipe(templateManager.container.getWidget(windowToOpen));
                });
            } else { // Senão, abre o swipe na opção selecionada.
                // Abre o swipe na widget selecionada.
                ScreenService.openSwipe(templateManager.container.getWidget(windowToOpen));
            }
            // Altera a variável de controle da widget atualmente aberta.
            windowCurrentlyOpen = windowToOpen;
        } else // Senão, verifica se não há a propriedade "ENABLED" na opção selecionada, indicando que é um submenu.
            if (windowEnabled !== false) {
                // Altera o estado aberto/fechado do submenu.
                widget.currentRow._opened = !widget.currentRow._opened;
            }
    };
    
    /*Ativa/desabilita campo com filtro dependente de outros campos*/
    this.setEnableField = function(args, nmFieldRef, nmFieldDest) {
        if(args){
            var fieldDest = args.owner.field.widget.getField(nmFieldDest);
            fieldDest.clearValue();
            if(args.owner.field.widget.currentRow[nmFieldRef] != "") {
                fieldDest.readOnly = false;
                fieldDest.reload();
            } else {
                fieldDest.readOnly = true;
            }
        }
    };
    //filterWidget = parent widget, aonde tem a current row com os dados do filtro
    //objToFilter = o field ou widget a receber os dados
    this.setDatasourceFilters = function(filterWidget, objToFilter) {
        objToFilter.dataSourceFilter.forEach(function(filter){
            filter.name = filter.name == 'CDIMPOSTONFE' ? 'CDIMPOSTO' : filter.name;
            if(filter.operator == '='){
                filter.value = filterWidget.currentRow[filter.name] || 'T';
            }else if (filter.operator == 'LIKE_ALL'){
                filter.value = filterWidget.currentRow[filter.name] || '%%';
            }
        });
    };
    
    this.onEmpresaFilter = function(args) {
        this.setEnableField(args, 'NMEMPRESA', 'CDINSCESTA');
        this.setDatasourceFilters(args.owner.field.widget, args.owner.field.widget.getField('CDINSCESTA'));
        args.owner.field.widget.getField('NRSEQUMAPAPU').readOnly = true;
        this.setDatasourceFilters(args.owner.field.widget, args.owner.field.widget.getField('NRSEQUMAPAPU'));
    };    
        
    /*Ativa/Abre a widget do relatório Apropriação Contábil das Retiradas*/
    this.geraRelatorioRetirada = function(args) {
        // seleciona a widget de parametrização correspondente.
        var retiradasWidget = templateManager.container.getWidget('contabilizacao_retiradas');
        var relatorioWidget = templateManager.container.getWidget('relatorio_apropriacao');
        
        //Apenas prossegue com o relatório com todos campos obrigatórios preenchidos
        if(retiradasWidget.isValid()) {
            // Altera a habilitação da widget do relatório e fecha o popup
            relatorioWidget.enabled = true;
            ScreenService.closePopup(retiradasWidget);
            
            ///Monta e aplica o filtro (dataSource) para a query do relatório
            relatorioWidget.dataSourceFilter = [
                {
                    "name": "NRORG",
                    "operator": "=",
                    "value": "@getLocalVar('NRORG')@"
                },
                {
                    "name": "CDEMPRESA",
                    "operator": "=",
                    "value": retiradasWidget.currentRow.CDEMPRESA
                },
                {
                    "name": "CDFILIAL",
                    "operator": "IN",
                    "value": retiradasWidget.currentRow.CDFILIAL
                },
                {
                    "name": "CDTIPORETI",
                    "operator": "IN",
                    "value": retiradasWidget.currentRow.CDTIPORETI
                },
                {
                    "name": "DTINICIAL",
                    "operator": "=",
                    "value": retiradasWidget.currentRow.DTPERIODO.start
                },
                {
                    "name": "DTFINAL",
                    "operator": "=",
                    "value": retiradasWidget.currentRow.DTPERIODO.end
                }
            ];
            
            // Recarrega os dados (dataSource) parametrizados
            relatorioWidget.reload().then(function(){
                // Redesenha os dados carregados na tab
                relatorioWidget.redraw();
            });
            
            //Ativa a tab do relatório
            relatorioWidget.activate();
        } else {
            ScreenService.closePopup(retiradasWidget);
            ScreenService.showMessage(Messages_Contabil.FALTA_PARAMETROS);
        }
    };
    
    /*Ativa/Abre a widget do relatório Apropriação Contábil Implantações e aciona a geração em backend*/
    this.geraRelatorioApropriacao = function(args) {
        // seleciona a widget de parametrização correspondente.
        var retiradasWidget    = templateManager.container.getWidget('contabilizacao_ajustes');
        var relatorioAprWidget = templateManager.container.getWidget('relatorio_implantacoes');
        var relatorioSCCWidget = templateManager.container.getWidget('relatorio_sem_conta_ctb');
        
        //Apenas prossegue com o relatório com todos campos obrigatórios preenchidos
        if(retiradasWidget.isValid()) {
            // fecha o popup
            ScreenService.closePopup(retiradasWidget);
            // adquiri os dados para o relatório e 'seta' o datasorce da widget do relatório
            Ger31000_contabilizacao_estoque_Service.geraRelatorioImplantacao(retiradasWidget.currentRow, relatorioAprWidget, relatorioSCCWidget);
        } else {
            ScreenService.closePopup(retiradasWidget);
            ScreenService.showMessage(Messages_Contabil.FALTA_PARAMETROS);
        }
        
    };
    
    /*Reset do label da widget relatório Apropriação Contábil apó a mesma perder o foco*/
    this.resetLabelRelatorioImplantacoes = function() {
        var relatorioAprWidget = templateManager.container.getWidget('relatorio_implantacoes');
        relatorioAprWidget.label = "Apropriação Contábil";
    };
    
    /*Gera a Contabilização de Retiradas*/
    this.geraContabilizacaoRetirada = function(widget) {
        var row = widget.currentRow; //Row atual
        if(widget.isValid()) { //Verifica se o lote foi informado para a contabilização
            if(row.CDLOTE != "") {
                Ger31000_contabilizacao_estoque_Service.geraContabilizacaoRetirada(row);
            } else
                ScreenService.showMessage("O Código do Lote deve ser informado");
        } else
            ScreenService.showMessage(Messages_Contabil.FALTA_PARAMETROS);
        ScreenService.closePopup(widget); //Fecha o popup de ações
    };
    
    /*Gera a Contabilização de Ajustes e Implantações*/
    this.geraContabilizacaoAjustImpla = function(widget) {
        var row = widget.currentRow; //Row atual
        var retiradasWidget    = templateManager.container.getWidget('contabilizacao_ajustes');
        if(widget.isValid()) { //Verifica se o lote foi informado para a contabilização
            if(row.CDLOTE == "") {
                ScreenService.showMessage("O Código do Lote deve ser informado");
            } else if(row.CDHISTPADR == "") {
                ScreenService.showMessage("O Histórico Padrão deve ser informado");
            } else {
                Ger31000_contabilizacao_estoque_Service.geraContabilizacaoAjustImpla(row);
                var semContaWidget = templateManager.container.getWidget('relatorio_sem_conta_ctb');
                semContaWidget.enabled = true;
                ScreenService.closePopup(widget);
                
                
                General.callRestEngine("ctb#/geraContabilizacaoAjustImpla", 'Row', row).then(function(response) {
                    
                }).catch(function(error) {
                    retiradasWidget.currentRow.RELATORIO = 'C';
                    General.callRestEngine("ctb#/geraRelatorioImplantacao", 'Row', retiradasWidget.currentRow).then(function(response) {
                        semContaWidget.dataSource.data = response.dataset.data;
                        semContaWidget.enabled = true;
                        semContaWidget.activate();
                    }).catch(function(error) {
                        //ScreenService.showMessage(error.data.error, 'error');
                    });
                    
                });
                
                
            
            }
        } else {
            ScreenService.showMessage(Messages_Contabil.FALTA_PARAMETROS);
        }
        ScreenService.closePopup(widget); //Fecha o popup de ações
    };
    
    self.getCurrentDate = function() {
        return moment().format("DD/MM/YYYY");
    };
    
    self.empresaOnChange = function(widget) {
        if(widget){    
            var empresaIsSelected = !!widget.currentRow.CDEMPRESA;
            
            var parametrosWidget = widget.getParent().widgets[1];
            
            parametrosWidget.enabled = empresaIsSelected;
        }
    };
    
    self.inscricaoOnChange = function(widget) {
        // Variável booleana que é setada como true caso alguma inscrição tenha sido selecionada.
        var inscricaoIsSelected = !!widget.currentRow.CDINSCESTA;

        // seleciona a widget de parametrização correspondente.
        var parametrosWidget = widget.getParent().widgets[1];

        // Altera a habilitação da widget de parâmetros gerais
        parametrosWidget.enabled = inscricaoIsSelected;
    };
    
    self.setLoadedParameters = function(widget) {
        if(widget.dataSource.data.length > 0) {
            widget.moveToFirst();
        } else {
            widget.currentRow.CDINSCESTA = widget.getParent().widgets[0].currentRow.CDINSCESTA;
            widget.currentRow.__is_new = true;
        }
        
        widget.currentRow.CDEMPRESA = widget.getParent().widgets[0].currentRow.CDEMPRESA;
        widget.currentRow.NMEMPRESA = widget.getParent().widgets[0].currentRow.NMEMPRESA;
    };
    
    self.salvarParametrizacao = function(parametrosWidget) {
        if (parametrosWidget.isValid()) {
            var widget = parametrosWidget.getParent().widgets[0];
            
            parametrosWidget.currentRow.SGESTADO = parametrosWidget.dataSourceFilter.filter(function(filter) {
                return filter.name === 'SGESTADO';
            })[0].value;
            
            // Chama a função para salvar os dados.
            parametrosWidget.saveRow()
            .then(function() {
                parametrosWidget.getParent().widgets[0].activate();

                setParametersVerified(parametrosWidget);
                // Verifica se os parâmetros foram exibidos devido a uma
                // tentativa de exportar o SPED. Em caso positivo, tenta
                // exportar o SPED novamente.
                if (parametrosWidget.parametersRequired) {
                    self.geraRelatorioAjusteApurcao(widget);
                    // Retira a necessidade de exportar automaticamente ao
                    // abrir a parametrização novamente.
                    parametrosWidget.parametersRequired = false;
                }
            });
        }
    };
    
    self.beforeExitParametrosGerais = function(parametrosWidget) {
        // Seta a parametrização como verificada somente se a widget não
        // estiver em modo de inserção, mas sim de edição.
        if (!parametrosWidget.isNewRow()) {
            setParametersVerified(parametrosWidget);
        }
    };
    
    var setParametersVerified = function(parametrosWidget) {
        var currentRow = parametrosWidget.currentRow;
        
        // Verifica se o objeto já foi criado pra esta empresa.
        if (!parametrosWidget.empresasLoaded[currentRow.CDEMPRESA]) {
            parametrosWidget.empresasLoaded[currentRow.CDEMPRESA] = {};
        }
        // Seta o parâmetro para a empresa e inscrição estadual selecionados.
        parametrosWidget.empresasLoaded[currentRow.CDEMPRESA][currentRow.CDINSCESTA] = true;
        
    };
    
    var parametrizacaoWasLoaded = function(widget) {
        var parametrizacaoWasLoaded;
        var parametrosWidget;
        var cdempresa = widget.currentRow.CDEMPRESA;
        var cdinscesta = widget.currentRow.CDINSCESTA;

        // Seleciona e valida a widget conforme o arquivo selecionado.
        parametrosWidget = widget.getParent().widgets[1];
        // Valida se a propriedade está setada para a empresa e inscrição estadual selecionados.
        parametrizacaoWasLoaded = parametrosWidget.empresasLoaded[cdempresa] && parametrosWidget.empresasLoaded[cdempresa][cdinscesta];
        
        // Verifica se a widget de parametrização foi aberta antes de exportar o arquivo.
        if (!parametrizacaoWasLoaded) {
            // Muda a propriedade para que seja obrigatório que a parametrização seja informada.
            parametrosWidget.parametersRequired = true;

            // Exibe a mensagem que indica que os parâmetros devem ser verificados.
            ScreenService.showMessage('Parâmetros gerais devem ser informados.').then(function() {
                // Abre a swipe da widget de parâmetros.
                ScreenService.closePopup();
                parametrosWidget.activate();
            });
            // Retorna false, indicando que a parametrização não foi previamente conferida.
            return false;
        }
        // Retorna true caso contrário, indicando que a parametrização foi previamente conferida.
        return true;
    };
    
    var isValid = function(widget){
        if(!widget.isValid()){
            ScreenService.closePopup();
            ScreenService.showMessage('Preencha todos os campos.');
            return false;
        } else {
            return true;
        }
    };
    
    self.geraRelatorioAjusteApurcao = function(widget) {
        if (isValid(widget)) {
            
            widget.currentRow.widgetName = widget.name;
            var currentRow = widget.currentRow;
            
            // Verifica se a parametrização para widget foi verificada.
            if (!parametrizacaoWasLoaded(widget)) {
                return;
            }

            Ger31000_contabilizacao_estoque_Service.geraRelatorioAjusteApurcao(widget);
            
        }
    };
    
    self.verificaPorcentagem = function(field) {
        var value = parseFloat(field.value().replace(",","."));

        if((value < 0) || (value > 100)){
            field.clearValue();
            ScreenService.alertNotification(field.label+" deve ser um valor entre 0 a 100%");
        }
    };
    
    self.changeImposto = function(widget) {
        this.setDatasourceFilters(widget, widget.getField('NRSEQUMAPAPU'));
        widget.getField('NRSEQUMAPAPU').clearValue();
        widget.getField('NRSEQUMAPAPU').reload();
        widget.getField('NRSEQUMAPAPU').readOnly = !(widget.currentRow.SGIMPOSTONFE && widget.currentRow.CDINSCESTA);
    };
    
    self.changeMapaApuracDataSource =  function(widget) {
        widget.getField('NRSEQUMAPAPU').reload();
    };
    
    self.incestaOnChange =  function(args) {
        if(args.owner.field.widget.currentRow.SGIMPOSTONFE){
            this.setEnableField(args, 'CDINSCESTA', 'NRSEQUMAPAPU');
        }
         this.setDatasourceFilters(args.owner.field.widget, args.owner.field.widget.getField('NRSEQUMAPAPU'));
    };
    
    
    this.openFilterClean = function(widget){
        var filterRow = {
        };
        ZhFilterPreferences.setOriginalFilter(widget.id, filterRow);
        ZhFilterPreferences.openFilterWidget(widget);   
        widget.applyDefaultValue();
        widget.activate();
        widget.list();
    };
    
    this.abreDetalhesContabAjuste = function(widget){
        var relatorioWidget = widget.container.getWidget('relatorio_apuracao_fiscal');
        relatorioWidget.dataSourceFilter = [
                {
                    "name": "NRSEQUMAPAPU",
                    "operator": "=",
                    "value": widget.currentRow.NRSEQUMAPAPU
                },
                {
                    "name": "CDLOTE",
                    "operator": "=",
                    "value": widget.currentRow.CDLOTE
                },
                {
                    "name": "CDEMPRESA",
                    "operator": "=",
                    "value": widget.appliedFilter.FILTER_ROW.CDEMPRESA
                }
            ];
        //widget.view();
        relatorioWidget.isVisible = widget.currentRow.IDCONTABILIZADO === "S";
        relatorioWidget.reload();
    };
    
    this.aplicaDSTPAJUSTE = function(widget){
        widget.dataSource.data.forEach(function(row){
            //garante que as descrições vão ser aplicadas
            let ds = widget.getField("IDTPAJUSTE").dataSource.data.filter(filter => filter.IDTPAJUSTE == row.IDTPAJUSTE);
            row.DSTPAJUSTE = ds.DSTPAJUSTE || 'Tipo de ajuste não definido';
            //garante que os dados do filtro vão der exibidos
            let propsFiltro = widget.appliedFilter ?  Object.keys(widget.appliedFilter.FILTER_ROW || []) : [];
            
            propsFiltro.forEach(function(property, index){
                let garantia;
                row[property] = row[property] || widget.appliedFilter.FILTER_ROW[property];
                if(index ==propsFiltro.length-1){
                    garantia = row;                       
                }
            });
            delete row.changed;
        });
    };
    
    this.salvaAjusteWidgetOnSaveInlineEdit = function(widget) {
        var linhasMarcadas = widget.dataSource.data.filter(ajuste => ajuste.changed);
        var linhasEditaveis = linhasMarcadas.filter(linha => linha.IDCONTABILIZADO === "N");
        if(linhasEditaveis.length > 0){
            linhasEditaveis.forEach(function(linha){
                linha.CDEMPRESA = widget.appliedFilter.FILTER_ROW.CDEMPRESA;
            });
            Ger31000_contabilizacao_estoque_Service.salvarAjustesContabFiscal(linhasEditaveis).then(function(errosCancelamento){
                widget.reload().then(widget.view);
                //if(Object.keys(errosCancelamento.dataset.errosCancelamento).length > 0)
               //     ErrosCancelamentoAprovacaoLancamentos_Utilities.errosCancelamento(args.owner.widget, errosCancelamento.dataset.errosCancelamento);
               // else ScreenService.successNotification("Aprovação da(s) nota(s) cancelada com sucesso.");
            });
        }
        else{
            ScreenService.showMessage("Nenhum ajuste editavel foi marcado!");
        }
        /*if (widget.isValid()) {
            var encargoWidget = encargosArgs.owner;
            var itensWidget = encargosArgs.owner.container.getWidget('itens');
            var dataSourceEncargo = encargoWidget.dataSource.data;
            var parentWidget = encargosArgs.owner.getParent();

            var totalItens = somaValorTotalItens(itensWidget);
            var validaTotalEncargos = Df11000_Lancamento_Service.validaTotalEncargos(dataSourceEncargo, totalItens);

            if (!validaTotalEncargos)
                return requestError('Valor de encargo a descontar maior que o valor total dos itens.');

            //TODO remover esta linha e coloca-la no general
            var encargosSalvar;
            if (encargosArgs.row.__is_new) {
                encargosSalvar = dataSourceEncargo;
            } else {
                encargosSalvar = encargosArgs.dataSource.filter(encargo => !!encargo.changed);
            }

            Df11000_Lancamento_Service.salvaEncargo(encargosSalvar).then(() => {
                alteraStatusNotafiscal(parentWidget);
                encargosSalvar.forEach(encargo => {
                    encargo.__is_new = false;
                    //@todo remover delete encargo.changed quando desmarcaLinhasEditadas for implementada
                    delete encargo.changed_VRITEMENCA;
                    delete encargo.changed;
                });

                Df11000_Lancamento_Service.setDataSourceEncargo(encargosArgs.dataSource)
                    .then(Df11000_Lancamento_Service.atualizaLancamento)
                    .then(() => {
                        controlaStatusWidgets(encargoWidget.getParent(), encargoWidget.name, true);
                        //@todo desmarcaLinhasEditadas
                        //GerUtil.desmarcaLinhasEditadas(lancamentoEncargoWidget, CANCELAR);
                        Df11000_Lancamento_Service.setDataSourceLancamentoNota();
                        //encargosArgs.owner.view();
                        encargosArgs.owner.list();
                        encargosArgs.owner.reload();
                    });
            }, requestError);
        }*/
    };

    this.cancelaAjusteWidgetOnCancelInlineEdit = function(widget) {
        // TODO criar função para desmarcar linhas editadas
        // GerUtil.desmarcaLinhasEditadas(lancamentoEncargoWidget, CANCELAR);
        // delete encargo["changed_VRITEMENCA"];
        // delete encargo.changed;
        widget.dataSource.data.forEach(ajuste => {
            ajuste.CDLOTE = (ajuste.changed) ? ajuste.changed_CDLOTE : ajuste.CDLOTE;
            delete ajuste.changed_CDLOTE;
            delete ajuste.changed;
        });
        widget.list();
    };
    
    this.geraRelatorioAjusteApurcaoFiscal = function(widget, row = []) {
        var linhasMarcadas = row.length ? row : widget.getCheckedRows();
        var linhasRelatorio = linhasMarcadas.filter(function(linha){
            return linha.IDCONTABILIZADO === "N" && linha.CDLOTE && !linha.changed;
        });
        if(linhasRelatorio.length > 0){
            linhasRelatorio.forEach(function(linha) {
                linha.CDIMPOSTONFE = widget.appliedFilter.FILTER_ROW.CDIMPOSTONFE;
                linha.CDINSCESTA = widget.appliedFilter.FILTER_ROW.CDINSCESTA;
                linha.CDEMPRESA = widget.appliedFilter.FILTER_ROW.CDEMPRESA;
                linha.DTINIPERIODO = widget.appliedFilter.FILTER_ROW.DTINIPERIODO;
                linha.DTFIMPERIODO = widget.appliedFilter.FILTER_ROW.DTFIMPERIODO;
            });
            Ger31000_contabilizacao_estoque_Service.geraRelatorioAjusteApurcaoFiscal(linhasRelatorio).then(function(dadosRelatorio){
                widget.dataSource.data = dadosRelatorio.dataset.ctb_ajuste_apurfiscal;
                self.aplicaDSTPAJUSTE(widget);
                widget.activate();
                
                ScreenService.showMessage("Relatório gerado com sucesso.");        
            }, function(error) {
                ScreenService.showMessage(error.data.error, 'error');
            });
        }
        else{
            ScreenService.showMessage("Não é possivel gerar relatorio das linhas selecinadas");
        }
    };
    
    /*self.geraRelatorioAjusteApurcaoFiscal = function(widget){
        if (isValid(widget)) {
            
            widget.currentRow.CDHISTPADR = null;
            widget.currentRow.widgetName = widget.name;
            var currentRow = widget.currentRow;
            
            Ger31000_contabilizacao_estoque_Service.geraRelatorioAjusteApurcaoFiscal(widget);
            
        }
    };*/
        /**
     * Seta Data Souce Stripe
     * @param widget
     */
    self.setStripeData = function(widget) {
        this.aplicaDSTPAJUSTE(widget);
        var tabbed = widget.container.getWidget('ctb99000_ajuste_apur_fis');
        
        var currentRow = widget.appliedFilter.FILTER_ROW;
        var stripeWidget = templateManager.container.getWidget("stripe_ajuste_apur_fis");
        
        stripeWidget.currentRow = {};
        stripeWidget.currentRow.SGIMPOSTONFE = currentRow.SGIMPOSTONFE;
        stripeWidget.currentRow.CDINSCESTA   = currentRow.CDINSCESTA;
        stripeWidget.currentRow.NMEMPRESA    = currentRow.CDEMPRESA + ' - ' + currentRow.NMEMPRESA;
        stripeWidget.currentRow.NRSEQUMAPAPU    = currentRow.NRSEQUMAPAPU + ' - ' + currentRow.NMMAPAAPUR;
        tabbed.currentRow.DESCRIPTION = stripeWidget.currentRow.SGIMPOSTONFE +' | '+stripeWidget.currentRow.CDINSCESTA +
                                        ' | ' + stripeWidget.currentRow.NMEMPRESA + ' | '+ stripeWidget.currentRow.NRSEQUMAPAPU;
        tabbed.label = tabbed.currentRow.DESCRIPTION;
    };
    

};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ger31000_contabilizacao_estoque_Controller', Ger31000_contabilizacao_estoque_Controller);
});

// FILE: ./assets/js/controllers/Ger95200_Representante_Legal_Controller.js
var Ger95200_Representante_Legal_Controller = function(ScreenService, templateManager, General, Ger95200_Representante_Legal_Service){

     this.getWidget = function(){
          var widget = templateManager.container.getWidget('widgetRepresentante');
          return widget;
     };


     this.habilitaEstado = function(){
          var widget = this.getWidget();
          var boReadOnly = !widget.currentRow.CDPAIS;
          widget.getField('NMESTADO').readOnly = boReadOnly;
          if (boReadOnly){
               widget.currentRow.SGESTADO = '';
               widget.currentRow.NMESTADO = '';
          }
          else{
               widget.getField('NMESTADO').reload();
          }
          this.habilitaMunicipio();
     };

     this.habilitaMunicipio = function(){
          var widget = this.getWidget();
          var boReadOnly = !widget.currentRow.SGESTADO;

          widget.getField('NMMUNICIPIO').readOnly = boReadOnly;
          
          if (boReadOnly){
               widget.currentRow.CDMUNICIPIO = '';
               widget.currentRow.NMMUNICIPIO = '';
          }else{
               widget.getField('NMMUNICIPIO').reload();
          }
          this.habilitaBairro();
     };

     this.habilitaBairro = function(){
        var widget = this.getWidget();
        var boReadOnly = !widget.currentRow.CDMUNICIPIO;

        widget.getField('NMBAIRRO').readOnly = boReadOnly;
        widget.getField('DSENDEREPRES').readOnly = boReadOnly;
        widget.getField('DSCOMPREPRES').readOnly = boReadOnly;
        
        if (boReadOnly){
           widget.currentRow.CDBAIRRO = '';
           widget.currentRow.NMBAIRRO = '';
           widget.currentRow.DSENDEREPRES = '';
           widget.currentRow.DSCOMPREPRES = '';
        }
        else{
           widget.getField('NMBAIRRO').reload();
        }
     };

     this.validaCEP = function(field){
        // Pega o valor do field
        var widget = field.widget;
        var CEP = field.value();

        // Valida o tamanho do campo com a máscara
        if(CEP && CEP.length == 10) {
            // Solicita a validação do CEP no WS do Correios
            Ger95200_Representante_Legal_Service.validaCEP(CEP).then(function(response) {
                var address = response.dataset.ENDERECO;

                // Atualiza os valores da tela de acordo com o objeto address recebido.
                widget.currentRow.CDPAIS        = (address.CDPAIS)?             address.CDPAIS : '';
                widget.currentRow.NMPAIS        = (address.NMPAIS)?             address.NMPAIS : '';
                widget.currentRow.SGESTADO      = (address.SGESTADO)?         address.SGESTADO : '';
                widget.currentRow.NMESTADO      = (address.NMESTADO)?         address.NMESTADO : '';
                widget.currentRow.CDMUNICIPIO   = (address.CDMUNICIPIO)?   address.CDMUNICIPIO : '';
                widget.currentRow.NMMUNICIPIO   = (address.NMMUNICIPIO)?   address.NMMUNICIPIO : '';
                widget.currentRow.CDBAIRRO      = (address.CDBAIRRO)?   address.CDBAIRRO : '';
                widget.currentRow.NMBAIRRO      = (address.NMBAIRRO)?   address.NMBAIRRO : '';
                widget.currentRow.DSENDEREPRES  = (address.DSENDERECO)?     address.DSENDERECO : '';
                this.habilitaEstado();
            }.bind(this), function(error) { // o Bind serve para repassar o contexto do controller para o contexto da função
                var errorMessage = 'Timeout'; //default value

                //removes faulty CEP
                widget.currentRow.NRCEPREPRES = '';

                //if theres an appropriate error message, gets it
                if(error.data)
                    errorMessage = error.data.error;

                //shows error message
                ScreenService.showMessage("Erro na requisição do CEP '" + CEP + "': " + errorMessage, "warning");
            });
        }
    };

    this.AlteraCPF = function (){
        var widget = this.getWidget();
        var cpf = widget.currentRow.NRCPFREPRES;
        cpf = cpf.replace(".", "");
        cpf = cpf.replace(".", "");
        cpf = cpf.replace("-", "");
        widget.currentRow.NRCPFREPRES = cpf;
    };

    this.camposInteiros = function(){
         General.justInteger('#CDCONTADOR');
         General.justInteger('#NRDDDTELEREPRES1');
         General.justInteger('#NRTELEREPRES1');
         General.justInteger('#NRRAMALREPRES1');
         General.justInteger('#NRDDDTELEREPRES2');
         General.justInteger('#NRTELEREPRES2');
         General.justInteger('#NRRAMALREPRES2');
         General.justInteger('#NRDDDFAXREPRES');
         General.justInteger('#NRFAXREPRES');
    };
};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ger95200_Representante_Legal_Controller', Ger95200_Representante_Legal_Controller);
});

// FILE: ./assets/js/controllers/RegistroY600Socios_Controller.js
function RegistroY600Socios_Controller(General, ScreenService, templateManager, ZHPromise) {

	var self = this;
	
	self.verificaPais = function(widget){
		if(widget.getField('CDPAISREG').value() == '105'){
			widget.getField('CDREG').readOnly = false;
			widget.getField('NRCPFREPREG').readOnly = false;
			widget.getField('QUALIREPREG').readOnly = false;
		}else{
			widget.getField('CDREG').readOnly = true;
			widget.getField('NRCPFREPREG').readOnly = true;
			widget.getField('QUALIREPREG').readOnly = true;
		}
	};

	self.alteraPais = function(widget){
		self.verificaPais(widget);
		
		widget.getField('CDREG').value('');
		widget.getField('NRCPFREPREG').value('');
		widget.getField('QUALIREPREG').value('00');
	};
	
	self.salvaRegY600 = function(widget){
		if(widget.isValid()){
			
			if(widget.currentRow.NRCPFREPREG && widget.currentRow.QUALIREPREG =='00'){
				ScreenService.showMessage("Qualificação do Representante deve ser informada.", "warning");
				return;
			}
			
			if(!widget.currentRow.NRCPFREPREG && widget.currentRow.QUALIREPREG !='00'){
				ScreenService.showMessage("CPF do Representante deve ser informado.", "warning");
				return;
			}
				
			var cdreggrid = widget.currentRow.CDREG;
			var cdreg = widget.currentRow.CDREG;
			if(cdreg)
				widget.currentRow.CDREG = cdreg.replace(/[-./]+/g, '');
			var nrcpfrepreg = widget.currentRow.NRCPFREPREG;
			if(nrcpfrepreg){
				widget.currentRow.NRCPFREPREG = nrcpfrepreg.replace(/[-.]+/g, '');
			}
			
            var filter = [
	            	{
	            		"name" : "CDREG",
	                    "operator" : "=",
	                    "value" : widget.currentRow.CDREG
	            	},
	            	{
	            		"name" : "NRORG",
	                    "operator" : "=",
	                    "value" : widget.currentRow.NRORG
	            	}
            ];
			General.callRestEngine("ctb#/regy600socio_cpf", "FilterData", filter).then(function(data) {
				var existCpf = data.dataset.regy600socio_cpf.length;
				if(existCpf == 0){
					General.widgetSave(widget).then(function(){
						if(cdreg)
							if((cdreg != cdreggrid.replace(/[-./]+/g, '')))
								widget.currentRow.CDREGGRID = cdreggrid;
						else widget.currentRow.CDREGGRID = cdreggrid;
						
						templateManager.updateTemplate();
						widget.reload();
					});
				}else{
					ScreenService.showMessage("Já existe um sócio cadastrado para esse CPF/CNPJ.", "warning");
					return;
				}
			});
			
		}
		
		widget.currentRow.NMREG = "";
		widget.currentRow.IDTIPOREG = "";
		widget.currentRow.CDREGGRID = "";
		widget.currentRow.CDREG = "";
		widget.currentRow.NMPAIS = "";
		widget.currentRow.NRCPFREPREG = "";
	};
	
	self.adicionaRegY600 = function(widget){
		widget.newRow();
		widget.getField('CDREG').readOnly = true;
		widget.getField('NRCPFREPREG').readOnly = true;
		widget.getField('QUALIREPREG').readOnly = true;
		self.verificaMascara(widget);
	};
	
	self.editaRegY600 = function(widget){
		General.widgetEdit(widget);
		self.verificaPais(widget);
		self.verificaMascara(widget);
	};
	
	self.alteraTipoReg = function(widget){
		self.verificaMascara(widget);
		widget.getField('CDREG').value('');
	};
	
	self.verificaMascara = function(widget){
		if(widget.getField('IDTIPOREG').value() == 'PF'){
			widget.getField('CDREG').mask.params.mask = "999.999.999-99";
		}else{
			widget.getField('CDREG').mask.params.mask = "99.999.999/9999-99";
		}
		widget.redraw();
	};
	
	self.configuraMascCnpjCpf = function(widget) {
	    var data = widget.dataSource.data;
	    var inscFormatada;
	    data.forEach(function(value){
            if(value.CDREG){
	            if(value.CDREG.length === 14)
	                 inscFormatada = value.CDREG.substr(0, 2) + '.' + value.CDREG.substr(2, 3) + '.' + value.CDREG.substr(5, 3) + '/' + value.CDREG.substr(8, 4) + '-' + value.CDREG.substr(12, 2);
	            else if(value.CDREG.length === 11)
	                 inscFormatada = value.CDREG.substr(0, 3) + '.' + value.CDREG.substr(3, 3) + '.' + value.CDREG.substr(6, 3) + '-' + value.CDREG.substr(9, 2);
	            else inscFormatada = null;
	            value.CDREGGRID = inscFormatada?inscFormatada:value.CDREG;
            }
	    });
	};
	
	self.checkCpfCnpj = function(widget) {
		if(widget.currentRow.CDREG){
        	var inscricao = General.inscricaoFormat(widget.currentRow.CDREG);

	        if (!inscricao.valid) {
	            if (inscricao.tipo.cod == 'J') inscricao.tipo.msg = 'CNPJ' + " \"" + inscricao.value + "\" inválido!";
				else if (inscricao.tipo.cod == 'F') inscricao.tipo.msg = 'CPF' + " \"" + inscricao.value + "\" inválido!";
				else inscricao.tipo.msg = "CNPJ/CPF inválido!";
	            
	            if (inscricao.tipo.msg) ScreenService.showMessage(inscricao.tipo.msg, "warning");
	            widget.currentRow.CDREG = null;
	        }
		}
    };
    
    
    self.checkCpf = function(widget) {
    	if(widget.currentRow.NRCPFREPREG){
	        var inscricao = General.inscricaoFormat(widget.currentRow.NRCPFREPREG);
	
	        if (!inscricao.valid) {
	            if (inscricao.tipo.cod == 'J') inscricao.tipo.msg = 'CNPJ' + " \"" + inscricao.value + "\" inválido!";
				else if (inscricao.tipo.cod == 'F') inscricao.tipo.msg = 'CPF' + " \"" + inscricao.value + "\" inválido!";
				else inscricao.tipo.msg = "CPF inválido!";
	            
	            if (inscricao.tipo.msg) ScreenService.showMessage(inscricao.tipo.msg, "warning");
	            widget.currentRow.NRCPFREPREG = null;
	        }
    	}else{
    		widget.currentRow.QUALIREPREG = '00';
    	}
    };
    
    self.novoSocio = function(widget){
    	widget.currentRow.__is_new = true;
		widget.currentRow.NRSEQREG = "";
    };
	
}

Configuration(function (ContextRegister) {
	ContextRegister.register('RegistroY600Socios_Controller', RegistroY600Socios_Controller);
});

// FILE: ./assets/js/controllers/RegistroY600SociosPorEmpresa_Controller.js
function RegistroY600SociosPorEmpresa_Controller(General, ScreenService, templateManager, ZHPromise) {

	var self = this;
	
	this.salvaSocio = function(widget){
		if(widget.isValid()){
			if((self.verificaPorcentagem(widget) == true) && (self.verificaData(widget) == true)){
				if(self.verificaQualificacao(widget) == true){
					if((widget.currentRow.__is_new == true)){
			            var filter = [
			            		{
				            		"name" : "CDEMPRESA",
				                    "operator" : "=",
				                    "value" : widget.currentRow.CDEMPRESA
				            	},
				            	{
				            		"name" : "NRSEQREG",
				                    "operator" : "=",
				                    "value" : widget.currentRow.NRSEQREG
				            	},
				            	{
				            		"name" : "NRORG",
				                    "operator" : "=",
				                    "value" : getLocalVar('NRORG')
				            	}
			            ];
						General.callRestEngine("ctb#/crud/socio_quadro_societario", "FilterData", filter).then(function(data) {
							var existeSocio = data.dataset.socio_quadro_societario.length;
							if(existeSocio == 0){
								var widget = templateManager.container.getActiveWidget();
								General.saveCrud(widget);
								widget.reload();
							}else{
								ScreenService.showMessage("Sócio já cadastrado para a empresa informada", "warning");
								return;
							}
						}.bind(this));
					}else if(self.verificaQualificacaoPais(widget) == true){
						General.widgetSave(widget);
					}
				}
			}
		}
	};
	
	self.verificaQualificacaoPais = function(widget){
			if(widget.currentRow.CDPAISREG == 105){
				if(widget.currentRow.IDTIPOREG == 'PF'){
					if((widget.currentRow.IDQUALIY600 != '01') && (widget.currentRow.IDQUALIY600 != '02') && (widget.currentRow.IDQUALIY600 != '09') ){
						ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes classificações: <br/><br/>01 - Acionista Pessoa Física Domiciliado no Brasil <br/>02 - Sócio Pessoa Física Domiciliado no Brasil <br/>09 - Titular.", "warning");
						return false;
					}
				}
				if((widget.currentRow.IDTIPOREG == 'PJ')){
					if((widget.currentRow.IDQUALIY600 != '03') && (widget.currentRow.IDQUALIY600 != '04')){
						ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes classificações: <br/><br/>03 - Acionista Pessoa Jurídica Domiciliado no Brasil <br/>04 - Sócio Pessoa Jurídica Domiciliado no Brasil.", "warning");
						return false;
					}
				}
			}
			
			if(widget.currentRow.CDPAISREG != 105){
				if(widget.currentRow.IDTIPOREG == 'PF'){
					if((widget.currentRow.IDQUALIY600 != '05') && (widget.currentRow.IDQUALIY600 != '06') && (widget.currentRow.IDQUALIY600 != '09') ){
						ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>05 - Acionista Pessoa Física Residente ou Domiciliado no Exterior <br/>06 - Sócio Pessoa Física Residente ou Domiciliado no Exterior.", "warning");
						return false;
					}
				}
				if((widget.currentRow.IDTIPOREG == 'PJ')){
					if((widget.currentRow.IDQUALIY600 != '07') && (widget.currentRow.IDQUALIY600 != '08')){
						ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>07 - Acionista Pessoa Jurídica Residente ou Domiciliado no Exterior <br/>08 - Sócio Pessoa Jurídica Residente ou Domiciliado no Exterior.", "warning");
						return false;
					}
				}
			}
			return true;
	};
	
	self.verificaQualificacao = function(widget){
			if(widget.currentRow.NMPAIS == 'BRASIL'){
				if(widget.currentRow.IDTIPOREG == 'PF'){
					if((widget.currentRow.IDQUALIY600 != '01') && (widget.currentRow.IDQUALIY600 != '02') && (widget.currentRow.IDQUALIY600 != '09') ){
						ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes classificações: <br/><br/>01 - Acionista Pessoa Física Domiciliado no Brasil <br/>02 - Sócio Pessoa Física Domiciliado no Brasil <br/>09 - Titular.", "warning");
						return false;
					}
				}
				if((widget.currentRow.IDTIPOREG == 'PJ')){
					if((widget.currentRow.IDQUALIY600 != '03') && (widget.currentRow.IDQUALIY600 != '04')){
						ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes classificações: <br/><br/>03 - Acionista Pessoa Jurídica Domiciliado no Brasil <br/>04 - Sócio Pessoa Jurídica Domiciliado no Brasil.", "warning");
						return false;
					}
				}
			}
			
			if(widget.currentRow.NMPAIS != 'BRASIL'){
				if(widget.currentRow.IDTIPOREG == 'PF'){
					if((widget.currentRow.IDQUALIY600 != '05') && (widget.currentRow.IDQUALIY600 != '06') && (widget.currentRow.IDQUALIY600 != '09') ){
						ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>05 - Acionista Pessoa Física Residente ou Domiciliado no Exterior <br/>06 - Sócio Pessoa Física Residente ou Domiciliado no Exterior.", "warning");
						return false;
					}
				}
				if((widget.currentRow.IDTIPOREG == 'PJ')){
					if((widget.currentRow.IDQUALIY600 != '07') && (widget.currentRow.IDQUALIY600 != '08')){
						ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>07 - Acionista Pessoa Jurídica Residente ou Domiciliado no Exterior <br/>08 - Sócio Pessoa Jurídica Residente ou Domiciliado no Exterior.", "warning");
						return false;
					}
				}
			}
			return true;
	};
	
	self.verificaPorcentagem = function(widget){
		if((widget.currentRow.VRPERCAPTOT != '') && (widget.currentRow.VRPERCAPTOT != null)){
			if(typeof widget.getField('VRPERCAPTOT').value() != 'string'){
				widget.currentRow.VRPERCAPTOT = widget.currentRow.VRPERCAPTOT + '';
				if(widget.currentRow.VRPERCAPTOT.indexOf(".") != -1){
					widget.currentRow.VRPERCAPTOT = widget.currentRow.VRPERCAPTOT.replace(".", ",");
				}
			}
			var parteInteira = widget.currentRow.VRPERCAPTOT.slice(0 , widget.currentRow.VRPERCAPTOT.length -3);
			var parteDecimal = widget.currentRow.VRPERCAPTOT.slice(widget.currentRow.VRPERCAPTOT.length -2, widget.currentRow.VRPERCAPTOT.length); 
			if(parteInteira.indexOf(".") != -1){
				parteInteira = parteInteira.replace('.', '');
			}
			
			parteInteira = parseFloat(parteInteira);
			parteDecimal = parseFloat(parteDecimal);
			
			if(!((parteInteira >= 0) && (parteInteira <= 100)) ){
				ScreenService.showMessage("O valor da porcentagem sobre capital total deve estar entre 0 e 100.", "warning");
				return false;
			}
			if((parteInteira == 100) && (parteDecimal > 0)){
				ScreenService.showMessage("O valor da porcentagem sobre capital total deve estar entre 0 e 100.", "warning");
				return false;
			}
			widget.currentRow.VRPERCAPTOT = parteInteira + '.' + parteDecimal;
			widget.currentRow.VRPERCAPTOT = parseFloat(widget.currentRow.VRPERCAPTOT);
		}
		if((widget.currentRow.VRPERCAPVOT != '') && (widget.currentRow.VRPERCAPVOT != null)){
			if(typeof widget.getField('VRPERCAPVOT').value() != 'string'){
				widget.currentRow.VRPERCAPVOT = widget.currentRow.VRPERCAPVOT + '';
				if(widget.currentRow.VRPERCAPVOT.indexOf(".") != -1){
					widget.currentRow.VRPERCAPVOT = widget.currentRow.VRPERCAPVOT.replace(".", ",");
				}
			}
			var parteInteira2 = widget.currentRow.VRPERCAPVOT.slice(0 , widget.currentRow.VRPERCAPVOT.length -3);
			var parteDecimal2 = widget.currentRow.VRPERCAPVOT.slice(widget.currentRow.VRPERCAPVOT.length -2, widget.currentRow.VRPERCAPVOT.length); 
			if(parteInteira2.indexOf(".") != -1){
				parteInteira2 = parteInteira2.replace('.', '');
			}
			
			parteInteira2 = parseFloat(parteInteira2);
			parteDecimal2 = parseFloat(parteDecimal2);
			
			if(!((parteInteira2 >= 0) && (parteInteira2 <= 100)) ){
				ScreenService.showMessage("O valor da porcentagem sobre capital volante deve estar entre 0 e 100.", "warning");
				return false;
			}
			
			if((parteInteira2 == 100) && (parteDecimal2 > 0)){
				ScreenService.showMessage("O valor da porcentagem sobre capital volante deve estar entre 0 e 100.", "warning");
				return false;
			}
			widget.currentRow.VRPERCAPVOT = parteInteira2 + '.' + parteDecimal2;
			widget.currentRow.VRPERCAPVOT = parseFloat(widget.currentRow.VRPERCAPVOT);
		}
		return true;
	};
	
	self.verificaData = function(widget){
		if((moment(widget.currentRow.DTFIMSOC, 'DD/MM/YYYY')) > (moment(widget.currentRow.DTALTSOC, 'DD/MM/YYYY'))){
			ScreenService.showMessage("Data final de participação do quadro societário deve ser menor que a data de alteração do quadro societário.", "warning");
			return false;
		}
		return true;
	};
	
	self.habilitaSocioQualificacao = function(widget){
		widget.currentRow.__is_new = true;
		widget.currentRow.NRSEQSOCEMPR = "";
		var empresa = widget.currentRow.NMEMPRESA;
		if(empresa != null){
			widget.getField('IDQUALIY600').readOnly = false;
			widget.getField('NMREG').readOnly = false;
		}
	};
	
}

Configuration(function (ContextRegister) {
	ContextRegister.register('RegistroY600SociosPorEmpresa_Controller', RegistroY600SociosPorEmpresa_Controller);
});

// FILE: ./assets/modules/saldos/assets/js/controllers/Ctb13000_RecalculoSaldoFiscal_Controller.js
var Ctb13000_RecalculoSaldoFiscal_Controller = function(ScreenService, General) {

    // Armazena a máscar de conta contábil retornada da PARAMGERAL.
    var contctblMask;

    /*
     * Função chamada por máscaras dos campos de conta contábil.
     * Retorna a máscara de conta contábil setada previamente na variável.
     */
    this.getContctblMask = function() {
        return contctblMask;
    };

    this.recalcularSaldoFiscal = function(recalculoWidget) {
        // Verifica se todos os campos obrigatórios foram preenchidos.
        if (recalculoWidget.isValid()) {
            var currentRow = recalculoWidget.currentRow;
            // Verifica se a conta final é igual ou maior do que a conta inicial.
            if (currentRow.CDCONTCTBLFIN < currentRow.CDCONTCTBLINI) {
                ScreenService.showMessage("Conta inicial deve ser menor ou igual à conta final.");
                return;
            }

            // Verifica se a data final foi preenchida, setando o valor NULL caso contrário.
            currentRow.DTFINAL = currentRow.DTFINAL ? currentRow.DTFINAL : null;

            // Verifica se a data final foi preenchida e é igual ou maior do que a data inicial.
            if (currentRow.DTFINAL !== null && moment(currentRow.DTFINAL, 'DD/MM/YYYY').isBefore(moment(currentRow.DTINICIAL, 'DD/MM/YYYY'))) {
                ScreenService.showMessage("A Data Final, quando informada, deve ser maior ou igual à data inicial informada.");
                return;
            }

            // Muda a mensagem de carregamento para uma mensagem personalizada.
            ScreenService.changeLoadingMessage("Recalculando os saldos...");

            // Chama a rota para efetuar a rotina de recálculo.
            General.callRestEngine("ctb#/recalculoSaldoFiscal", "Row", currentRow)
            .then(function() {
                ScreenService.showMessage("O recálculo de saldo fiscal foi realizado com sucesso.");
            })
            .catch(function(error) {
                // Mensagem padrão em caso de timeout.
                var errorMessage = 'Timeout';

                // Verifica se houve alguma resposta da requisição.
                if (error.data) {
                    // Caso haja alguma resposta, atribui a mensagem de erro.
                    errorMessage = error.data.error;
                }

                // Imprime a mensagem.
                ScreenService.showMessage(errorMessage);
            })
            .finally(function() {
                // Restaura a mensagem original.
                ScreenService.restoreDefaultLoadingMessage();
            });
        }
    };

    /*
     * Função chamada pela tela ao ser aberta.
     * Seta a máscara de conta contábil buscada da PARAMGERAL na variável.
     */
    this.setContctblMask = function() {
        // Chama a rota que retorna os dados da PARAMGERAL.
        General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []).then(function(response) {
            // Busca o primeiro dado retornado, que será o único registro da parametrização.
            var paramgeral = response.dataset.paramgeral[0];

            // Armazena o valor da máscara na variável.
            contctblMask = paramgeral.CDPICTCCTB;
        });
    };

};

Configuration(function(ContextRegister){
    ContextRegister.register('Ctb13000_RecalculoSaldoFiscal_Controller', Ctb13000_RecalculoSaldoFiscal_Controller);
});

// FILE: ./assets/modules/saldos/assets/js/controllers/Ctb17000_Implantacao_Saldo_Controller.js
var Ctb17000_Implantacao_Saldo_Controller = function(Ctb17000_Implantacao_Saldo_Service, General, ScreenService, templateManager, Messages_Contabil){

    this.edit = function(widget){
        General.edit(widget);
        this.setDadosSaldo(widget);
    };
    
    this.new = function(widget){
        widget.newRow();
        this.setDadosSaldo(widget);
    };

    this.setMask = function(widget){
         Ctb17000_Implantacao_Saldo_Service.getMask().then(function(success){
           var stMask = success.dataset.paramgeral[0].CDPICTCCTB;
            var mask = {
                "type": "fix",
                "params": {
                    "mask": stMask
                }
            };

            /* Atualiza a máscara da tela principal */
            widget.getField('NMCONTCTBLINI').fields[0].mask = mask;
            widget.getField('NMCONTCTBLFIN').fields[0].mask = mask;
            widget.getField('NMCONTCTBL').fields[0].mask = mask;
        });
     };

   this.ultimoDia = function(widget){
       var dtImpSaldo = widget.currentRow.DTSALDO;
        if (dtImpSaldo) {
            dtImpSaldo = moment(dtImpSaldo, "DD/MM/YYYY");
            dtImpSaldo = dtImpSaldo.endOf("month").format("DD/MM/YYYY");
            widget.currentRow.DTSALDO = dtImpSaldo;
        }
   };

   this.setSequencial = function (widget){
       Ctb17000_Implantacao_Saldo_Service.getSequencial().then(function (retorno) {
            var inSequencial = retorno.dataset.dataSetSequencial.NRSEQUENCIAL;
            widget.currentRow.NRIMPLSALDO = inSequencial;
            this.setDadosSaldo(widget);
        }.bind(this), function (error) {
            ScreenService.showMessage(error.data.error);
        });
   };

   this.setDadosSaldo = function(widget){
       widget.currentRow.CDEMPRESA = widget.appliedFilter.FILTER_ROW.CDEMPRESA;
       widget.currentRow.NMRAZSOCEMPR = widget.appliedFilter.FILTER_ROW.NMRAZSOCEMPR;
       widget.currentRow.DTSALDO = widget.appliedFilter.FILTER_ROW.DTSALDO;
       widget.currentRow.DTIMPSALDO = widget.currentRow.DTSALDO;
   };
   
    this.salvar = function(widget) {
        if (widget.isValid()) {
            widget.currentRow.__columns_to_return = widget.__columns_to_return;
            Ctb17000_Implantacao_Saldo_Service.salvar(widget.currentRow).then(function(retorno){
                ScreenService.showMessage(Messages_Contabil.CADASTRADO_COM_SUCESSO);
                widget.view();
                if(widget.currentRow.__is_new){
                    widget.currentRow.__is_new = false;
                    widget.currentRow.NRORG = retorno.dataset.columnsToReturn.NRORG;
                }
            }, function(error){
                if (error.data.error === 'JA_CADASTRADO'){
                    ScreenService.showMessage(Messages_Contabil.SALDO_JA_IMPLANTADO);
                } else{
                    ScreenService.showMessage(error.data.error);
                }
            });
        }
    };
};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ctb17000_Implantacao_Saldo_Controller', Ctb17000_Implantacao_Saldo_Controller);
});

// FILE: ./assets/modules/saldos/assets/js/controllers/Ctb22000_RazaoOficial_Controller.js
var Ctb22000_RazaoOficial_Controller = function(ScreenService, General) {

    this.preparaFiltroRazaoOficial = function(widget, preference){
        var filtro = preference.FILTER_ROW;
        var i = 0;
        var posData = [];
        widget.dataSourceFilter.forEach(function(filter){
            switch(filter.name){
                case 'CDEMPRESA': filter.value = filtro.CDEMPRESA;
                    break;
                case 'CDCONTCTBLINI': filter.value = filtro.CDCONTCTBLINI;
                    break;
                case 'CDCONTCTBLFIN': filter.value = filtro.CDCONTCTBLFIN;
                    break;
                case 'DTINICIAL': filter.value = filtro.DTLANCCONT.start;
                    break;
                case 'DTFINAL': filter.value = filtro.DTLANCCONT.end;
                    break;
                case 'DTLANCCONT': posData.push(i);
                    break;
                case 'NMEMPRESA': posData.push(i);
                    break;
                case 'NMCONTCTBLINI': posData.push(i);
                    break;
                case 'NMCONTCTBLFIN': posData.push(i);
                    break;
                
            }
            i++;
        });
        posData.sort();
        var qtde = posData.length;
        for (var j = 1; qtde > j; j++){
            widget.dataSourceFilter.splice(posData[qtde - j], 1);
        }
    };
    
    /*
     * Função chamada pela tela ao ser aberta.
     * Seta a máscara de conta contábil buscada da PARAMGERAL na variável.
     */
    this.setContctblMask = function() {
        // Chama a rota que retorna os dados da PARAMGERAL.
        General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []).then(function(response) {
            // Busca o primeiro dado retornado, que será o único registro da parametrização.
            var paramgeral = response.dataset.paramgeral[0];

            // Armazena o valor da máscara na variável.
            contctblMask = paramgeral.CDPICTCCTB;
        });
    };

};

Configuration(function(ContextRegister){
    ContextRegister.register('Ctb22000_RazaoOficial_Controller', Ctb22000_RazaoOficial_Controller);
});

// FILE: ./assets/modules/saldos/assets/js/controllers/Ctb22100_RazaoGerencial_Controller.js
var Ctb22100_RazaoGerencial_Controller = function(ScreenService, General, templateManager) {

    var contctblMask = "";

    this.setContctblMask = function() {
        General.callRestEngine("ctb#/crud/paramgeral", "FilterData", []).then(function(response) {
            var paramgeral = response.dataset.paramgeral[0];

            contctblMask = paramgeral.CDPICTCCTB;
        });
    };

    this.getContctblMask = function() {
        return contctblMask;
    };

    this.preparaFiltroRazaoGerencial = function(args) {
    	var widget    = templateManager.container.getWidget('RazaoGerencialGrid');
    	var filterRow = args.e.preference.FILTER_ROW;
    	
    	args.e.preference.FILTER_ROW = {};
    	args.e.preference.CUSTOM_FILTER_ROW = {};
    	
    	General.callRestEngine('ctb#/geraRazaoGerencial', 'Row', filterRow).then(function (response) {
    		var nrctbtemp = response.dataset.ctbtemp[0];
    		
    		var filtro = [
    			{
    				"name": "NRCTBTEMP",
    				"operator": "=",
    				"value": nrctbtemp
    			}
    		];
    		
    		args.e.preference.FILTER_ROW = {"NRCTBTEMP" : nrctbtemp};
    		widget.dataSourceFilter = filtro;
    		widget.reload();
    	}).catch(function(erro){
    		ScreenService.showMessage(erro.data.error);
    	});
    };

};

Configuration(function(ContextRegister){
    ContextRegister.register('Ctb22100_RazaoGerencial_Controller', Ctb22100_RazaoGerencial_Controller);
});

// FILE: ./assets/modules/saldos/assets/js/controllers/Ctb68000_RecalculoSaldosGerenciais_Controller.js
function Ctb68000_RecalculoSaldosGerenciais_Controller(ScreenService, Ctb68000_RecalculoSaldosGerenciais_Service){
    
    var messages = {
        DATA_INICIO_FORA_PERIODO_CONTABIL :  "Data início deve estar dentro do período contábil.",
        REQUEST_SUCCESS: 'Operação realizada com sucesso.',
        DATA_NAO_POSSUI_MES: 'Data Passada não possui mês.'
    };
    
    var paramMessages = {
        CAMPO_VAZIO : function(params){
            var message = 'O campo ? está vazio.';
            return message.replace('?', fieldNames[params[0]]);
        }
    };
    
     var fieldNames = {
            CDEMPRESA : 'Empresa',
            DTSALDO: 'Data início'
        };
    
    function message(messageCode, params){
        if(params === undefined){
            return messages[messageCode];
        }
        else{
            return  paramMessages[messageCode](params);
        }
    }
    
    function requestSuccess(){
        return function(response){
            var messageCode = 'REQUEST_SUCCESS';
            ScreenService.showMessage(message(messageCode), 'SUCCESS');
        };
    }
    
    function requestError(){
        return function(response){
            var errorMessage = 'Timeout';
			if (response.data){
				errorMessage = message(response.data.error, response.data.messageParams);
			}
            ScreenService.showMessage(errorMessage);
        };
    }
    
    function rowValidForValidatePeriodoContabil(row){
        return (row.CDEMPRESA && row.DTSALDO);
    }
    
    this.recalcularSaldo = function(widget){
        if(widget.isValid()){
            Ctb68000_RecalculoSaldosGerenciais_Service.recalcularSaldo(widget.currentRow).then(
                requestSuccess(),
                requestError()
            );
        }
    };
    
    this.validatePeriodoContabil = function(currentRow){
        if(rowValidForValidatePeriodoContabil(currentRow)){
            Ctb68000_RecalculoSaldosGerenciais_Service.validatePeriodoContabil(currentRow).then(
                function(success){},
                requestError()
            );
        }
    };
    
}
Configuration(function(ContextRegister) {
    ContextRegister.register("Ctb68000_RecalculoSaldosGerenciais_Controller", Ctb68000_RecalculoSaldosGerenciais_Controller);
});

// FILE: ./assets/modules/saldos/assets/js/controllers/Ctb72800_RecalculoSaldosComerciais_Controller.js
function Ctb72800_RecalculoSaldosComerciais_Controller(ScreenService, Ctb72800_RecalculoSaldosComerciais_Service){
    
    var messages = {
        DATA_INICIO_FORA_PERIODO_CONTABIL :  "Data início deve estar dentro do período contábil.",
        REQUEST_SUCCESS: 'Operação realizada com sucesso.',
        DATA_NAO_POSSUI_MES: 'Data Passada não possui mês.'
    };
    
    var paramMessages = {
        CAMPO_VAZIO : function(params){
            var message = 'O campo ? está vazio.';
            return message.replace('?', fieldNames[params[0]]);
        }
    };
    
     var fieldNames = {
            CDEMPRESA : 'Empresa',
            DTSALDO: 'Data início'
        };
    
    function message(messageCode, params){
        if(params === undefined){
            return messages[messageCode];
        }
        else{
            return  paramMessages[messageCode](params);
        }
    }
    
    function requestSuccess(){
        return function(response){
            var messageCode = 'REQUEST_SUCCESS';
            ScreenService.showMessage(message(messageCode), 'SUCCESS');
        };
    }
    
    function requestError(){
        return function(response){
            var errorMessage = 'Timeout';
			if (response.data){
				errorMessage = message(response.data.error, response.data.messageParams);
			}
            ScreenService.showMessage(errorMessage);
        };
    }
    
    function rowValidForValidatePeriodoContabil(row){
        return (row.CDEMPRESA && row.DTSALDO);
    }
    
    this.recalcularSaldo = function(widget){
        if(widget.isValid()){
            Ctb72800_RecalculoSaldosComerciais_Service.recalcularSaldo(widget.currentRow).then(
                requestSuccess(),
                requestError()
            );
        }
    };
    
    this.validatePeriodoContabil = function(currentRow){
        if(rowValidForValidatePeriodoContabil(currentRow)){
            Ctb72800_RecalculoSaldosComerciais_Service.validatePeriodoContabil(currentRow).then(
                function(success){},
                requestError()
            );
        }
    };
    
}
Configuration(function(ContextRegister) {
    ContextRegister.register("Ctb72800_RecalculoSaldosComerciais_Controller", Ctb72800_RecalculoSaldosComerciais_Controller);
});
